@@ -368,7 +368,7 @@ namespace clad {
       DropArgs_AddCON((, ...)); // Declares all the specializations
 
   template <class T, class R> struct OutputParamType {
-    using type = array_ref<R>;
+    using type = array_ref<typename std::remove_pointer<R>::type>;
   };
 
   template <class T, class R>
@@ -384,7 +384,7 @@ namespace clad {
   // GradientDerivedFnTraits specializations for pure function pointer types
   template <class ReturnType, class... Args>
   struct GradientDerivedFnTraits<ReturnType (*)(Args...)> {
-    using type = void (*)(Args..., OutputParamType_t<Args, ReturnType>...);
+    using type = void (*)(Args..., OutputParamType_t<Args, void>...);
   };
 
   /// These macro expansions are used to cover all possible cases of
@@ -399,8 +399,9 @@ namespace clad {
 #define GradientDerivedFnTraits_AddSPECS(var, cv, vol, ref, noex)              \
   template <typename R, typename C, typename... Args>                          \
   struct GradientDerivedFnTraits<R (C::*)(Args...) cv vol ref noex> {          \
-    using type = void (C::*)(Args...,                                          \
-                             OutputParamType_t<Args, R>...) cv vol ref noex;   \
+    using type =                                                               \
+        void (C::*)(Args..., OutputParamType_t<C, void>,                       \
+                    OutputParamType_t<Args, void>...) cv vol ref noex;         \
   };
 
 #if __cpp_noexcept_function_type > 0
@@ -449,6 +450,84 @@ namespace clad {
     using type = NoFunction*;
   };
 
+  /// This specific specialization is for error estimation calls.
+  template <class T, class = void> struct GradientDerivedEstFnTraits {};
+
+  // GradientDerivedEstFnTraits is used to deduce type of the derived functions
+  // derived using reverse modes
+  template <class T>
+  using GradientDerivedEstFnTraits_t = typename GradientDerivedEstFnTraits<
+      T>::type;
+
+  // GradientDerivedEstFnTraits specializations for pure function pointer types
+  template <class ReturnType, class... Args>
+  struct GradientDerivedEstFnTraits<ReturnType (*)(Args...)> {
+    using type = void (*)(Args..., OutputParamType_t<Args, Args>...,
+                          double&);
+  };
+
+  /// These macro expansions are used to cover all possible cases of
+  /// qualifiers in member functions when declaring GradientDerivedFnTraits.
+  /// They need to be read from bottom to top. Starting from the use of AddCON,
+  /// the call to which is used to pass the cases with and without C-style
+  /// varargs, then as the macro name AddCON says it adds cases of const
+  /// qualifier. The AddVOL and AddREF macro similarly add cases for volatile
+  /// qualifier and reference respectively. The AddNOEX adds cases for noexcept
+  /// qualifier only if it is supported and finally AddSPECS declares the
+  /// function with all the cases
+#define GradientDerivedEstFnTraits_AddSPECS(var, cv, vol, ref, noex)           \
+  template <typename R, typename C, typename... Args>                          \
+  struct GradientDerivedEstFnTraits<R (C::*)(Args...) cv vol ref noex> {       \
+    using type = void (C::*)(Args..., OutputParamType_t<Args, Args>...,           \
+                             double&) cv vol ref noex;                         \
+  };
+
+#if __cpp_noexcept_function_type > 0
+#define GradientDerivedEstFnTraits_AddNOEX(var, con, vol, ref)                 \
+  GradientDerivedEstFnTraits_AddSPECS(var, con, vol, ref, )                    \
+      GradientDerivedEstFnTraits_AddSPECS(var, con, vol, ref, noexcept)
+#else
+#define GradientDerivedEstFnTraits_AddNOEX(var, con, vol, ref)                 \
+  GradientDerivedEstFnTraits_AddSPECS(var, con, vol, ref, )
+#endif
+
+#define GradientDerivedEstFnTraits_AddREF(var, con, vol)                       \
+  GradientDerivedEstFnTraits_AddNOEX(var, con, vol, )                          \
+      GradientDerivedEstFnTraits_AddNOEX(var, con, vol, &)                     \
+          GradientDerivedEstFnTraits_AddNOEX(var, con, vol, &&)
+
+#define GradientDerivedEstFnTraits_AddVOL(var, con)                            \
+  GradientDerivedEstFnTraits_AddREF(var, con, )                                \
+      GradientDerivedEstFnTraits_AddREF(var, con, volatile)
+
+#define GradientDerivedEstFnTraits_AddCON(var)                                 \
+  GradientDerivedEstFnTraits_AddVOL(var, )                                     \
+      GradientDerivedEstFnTraits_AddVOL(var, const)
+
+  GradientDerivedEstFnTraits_AddCON(()); // Declares all the specializations
+
+  /// Specialization for class types
+  /// If class have exactly one user defined call operator, then defines
+  /// member typedef `type` same as the type of the derived function of the
+  /// call operator, otherwise defines member typedef `type` as the type of
+  /// `NoFunction*`.
+  template <class F>
+  struct GradientDerivedEstFnTraits<
+      F, typename std::enable_if<
+             std::is_class<remove_reference_and_pointer_t<F>>::value &&
+             has_call_operator<F>::value>::type> {
+    using ClassType = typename std::decay<
+        remove_reference_and_pointer_t<F>>::type;
+    using type = GradientDerivedEstFnTraits_t<decltype(&ClassType::operator())>;
+  };
+  template <class F>
+  struct GradientDerivedEstFnTraits<
+      F, typename std::enable_if<
+             std::is_class<remove_reference_and_pointer_t<F>>::value &&
+             !has_call_operator<F>::value>::type> {
+    using type = NoFunction*;
+  };
+
   template <class... Args> struct SelectLast;
 
   template <class... Args>
@@ -734,4 +813,4 @@ namespace clad {
   };
 } // namespace clad
 
-#endif // FUNCTION_TRAITS
\ No newline at end of file
+#endif // FUNCTION_TRAITS
