@@ -1,6 +1,6 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
@@ -13,11 +13,11 @@ sap.ui.define([
 	'sap/ui/events/isSpecialKey',
 	'sap/ui/events/isMouseEventDelayed',
 	'sap/ui/events/F6Navigation',
-	'sap/ui/events/jquery/EventExtension',
 	'sap/ui/events/jquery/EventSimulation',
 	'sap/ui/events/KeyCodes',
-	'sap/base/util/defineCoupledProperty'
-], function(jQuery, ControlEvents, PseudoEvents, fnCheckMouseEnterOrLeave, fnIsSpecialKey, fnIsMouseEventDelayed, F6Navigation, EventExtension, EventSimulation, KeyCodes, defineCoupledProperty) {
+	'sap/base/util/defineCoupledProperty',
+	'sap/ui/events/jquery/EventExtension' // implicit dependency
+], function(jQuery, ControlEvents, PseudoEvents, fnCheckMouseEnterOrLeave, fnIsSpecialKey, fnIsMouseEventDelayed, F6Navigation, EventSimulation, KeyCodes, defineCoupledProperty) {
 	"use strict";
 
 
@@ -519,19 +519,15 @@ sap.ui.define([
 			// note: the keypress event should be fired only when a character key is pressed,
 			// unfortunately some browsers fire the keypress event for other keys. e.g.:
 			//
-			// Firefox fire it for:
+			// Firefox < 65 fire it for:
 			// BREAK, ARROW_LEFT, ARROW_RIGHT, INSERT, DELETE,
 			// F1, F2, F3, F5, F6, F7, F8, F9, F10, F11, F12
 			// BACKSPACE, ESCAPE
 			//
-			// Internet Explorer fire it for:
-			// ESCAPE
+			// Safari fire it for:
+			// BACKSPACE, ESCAPE
 			case "keypress":
-
-				// note: in Firefox, almost all noncharacter keys that fire the keypress event have a key code of 0,
-				// with the exception of BACKSPACE (key code of 8).
-				// note: in IE the ESCAPE key is also fired for the keypress event
-				return (iKeyCode === 0 || // in Firefox, almost all noncharacter keys that fire the keypress event have a key code of 0, with the exception of BACKSPACE (key code of 8)
+				return (iKeyCode === 0 || // in Firefox < 65, almost all noncharacter keys that fire the keypress event have a key code of 0, with the exception of BACKSPACE (key code of 8)
 					iKeyCode === KeyCodes.BACKSPACE ||
 					iKeyCode === KeyCodes.ESCAPE ||
 					iKeyCode === KeyCodes.ENTER /* all browsers */) || false;
@@ -599,4 +595,4 @@ sap.ui.define([
 	jQuery.sap._refreshMouseEventDelayedFlag(navigator);
 
 	return jQuery;
-});
\ No newline at end of file
+});
