@@ -1,14 +1,10 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
 sap.ui.define([], function() {
 	"use strict";
 
-	if (!window.Promise) {
-		sap.ui.requireSync("sap/ui/thirdparty/es6-promise");
-	}
-
 });
