@@ -1,6 +1,6 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
@@ -27,7 +27,7 @@ sap.ui.define([
 	 *
 	 *
 	 * @class text
-	 * @version 1.82.2
+	 * @version 1.98.0
 	 * @private
 	 * @since 1.38
 	 * @alias HeaderAdapter
@@ -227,7 +227,7 @@ sap.ui.define([
 	 * Constructor for an sap.m.Fiori20Adapter.
 	 *
 	 * @class text
-	 * @version 1.82.2
+	 * @version 1.98.0
 	 * @private
 	 * @since 1.38
 	 * @alias sap.m.Fiori20Adapter
@@ -393,7 +393,7 @@ sap.ui.define([
 	// attaches listener for changes in the adaptable content
 	Fiori20Adapter._attachAdaptableContentChange = function(oControl, oAdaptOptions) {
 
-		if (!oControl._getAdaptableContent || !jQuery.isFunction(oControl._getAdaptableContent)) {
+		if (typeof oControl._getAdaptableContent !== "function") {
 			return;
 		}
 
@@ -538,7 +538,7 @@ sap.ui.define([
 
 	Fiori20Adapter._getNodeChildren = function(oControl) {
 
-		if (oControl._getAdaptableContent && jQuery.isFunction(oControl._getAdaptableContent)) {
+		if (typeof oControl._getAdaptableContent === "function") {
 			var aChildren = [oControl._getAdaptableContent()];
 			if (isInstanceOf(oControl, "sap/m/Page")) {
 				aChildren = aChildren.concat(oControl.getContent()); //page content can contain other pages that are subject to adaptation
