@@ -1,6 +1,6 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
@@ -22,6 +22,9 @@ sap.ui.define([],
 				}
 			},
 			actions: {
+				remove: {
+					changeType: "hideControl"
+				},
 				split: {
 					changeType: "splitMenuButton",
 					changeOnRelevantContainer : true,
