@@ -1,6 +1,6 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
@@ -11,7 +11,6 @@ sap.ui.define([
 	'sap/ui/model/Filter',
 	'sap/ui/model/Sorter',
 	"sap/base/Log",
-	'sap/base/util/ObjectPath',
 	"sap/base/util/JSTokenizer",
 	"sap/base/util/resolveReference"
 ], function(
@@ -20,7 +19,6 @@ sap.ui.define([
 		Filter,
 		Sorter,
 		Log,
-		ObjectPath,
 		JSTokenizer,
 		resolveReference
 	) {
