@@ -1,6 +1,6 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 /**
@@ -12,9 +12,10 @@ sap.ui.define([
 	"./rules/Model.support",
 	"./rules/View.support",
 	"./rules/App.support",
-	"./rules/Rendering.support"
+	"./rules/Rendering.support",
+	"./rules/Theming.support"
 ],
-	function(MiscSupport, ConfigSupport, ModelSupport, ViewSupport, AppSupport, RenderingSupport) {
+	function(MiscSupport, ConfigSupport, ModelSupport, ViewSupport, AppSupport, RenderingSupport, ThemingSupport) {
 	"use strict";
 
 	return {
@@ -26,7 +27,8 @@ sap.ui.define([
 			ModelSupport,
 			ViewSupport,
 			AppSupport,
-			RenderingSupport
+			RenderingSupport,
+			ThemingSupport
 		]
 	};
 }, true);
\ No newline at end of file
