@@ -1,6 +1,6 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
@@ -12,9 +12,9 @@ sap.ui.define([
 	'sap/ui/base/ManagedObject',
 	'sap/ui/core/mvc/ControllerMetadata',
 	'sap/ui/core/mvc/ControllerExtension',
+	'sap/ui/core/mvc/ControllerExtensionProvider',
 	'sap/ui/core/mvc/OverrideExecution',
-	"sap/base/Log",
-	"sap/ui/thirdparty/jquery"
+	"sap/base/Log"
 ], function(
 	ObjectPath,
 	extend,
@@ -22,23 +22,26 @@ sap.ui.define([
 	ManagedObject,
 	ControllerMetadata,
 	ControllerExtension,
+	ControllerExtensionProvider,
 	OverrideExecution,
-	Log,
-	jQuery
+	Log
 ) {
 	"use strict";
 
 		var mRegistry = {};
-		var mExtensionProvider = {};
+
 		/**
-		 * Instantiates a (MVC-style) controller. Consumers should call the constructor only in the
-		 * typed controller scenario. In the generic controller use case, they should use
-		 * {@link sap.ui.controller} instead.
+		 * Instantiates a (MVC-style) controller.
 		 *
 		 * @class A generic controller implementation for the UI5 Model-View-Controller concept.
 		 *
-		 * Can either be used as a generic controller which is enriched on the fly with methods
-		 * and properties (see {@link sap.ui.controller}) or  as a base class for typed controllers.
+		 * Can be used as a base class for typed controllers.
+		 *
+		 * <b>Typed Controller Scenario</b>:
+		 * <ul>
+		 * <li>use {@link sap.ui.core.mvc.Controller.extend Controller.extend} to define the controller class</li>
+		 * <li>use {@link sap.ui.core.mvc.Controller.create Controller.create} to create an instance</li>
+		 * </ul>
 		 *
 		 * @param {string|object[]} sName The name of the controller to instantiate. If a controller is defined as real sub-class,
 		 *                                    the "arguments" of the sub-class constructor should be given instead.
@@ -81,6 +84,7 @@ sap.ui.define([
 				this["_sapui_Extensions"] = {};
 				Controller.extendByMember(this, false);
 				this._sapui_isExtended = false;
+				this._aDestroyables = [];
 			},
 			/**
 			 * Wether a controller is extended or not
@@ -121,7 +125,7 @@ sap.ui.define([
 		 * Apply extension to controller
 		 *
 		 * @param {sap.ui.core.mvc.Controller} oController The controller to extend
-		 * @param {sap.ui.core.mvc.ControllerExtension|object} oCustomControllerDef The controller extension
+		 * @param {sap.ui.core.mvc.ControllerExtension|object} oExtension The controller extension
 		 * @param {string} [sLocalNamespace] Extensions could be applied to a local namespace. Do so if passed
 		 * @private
 		 */
@@ -187,27 +191,27 @@ sap.ui.define([
 							Log.error("Method '" + sOverrideMember + "' does not exist in controller " + oController.getMetadata().getName() + " and cannot be overridden");
 						}
 					}
-					//handle non member extension overrides
-					if (oOverrides.extension) {
-						//allow to override methods of other controller extensions
-						for (var sExtensionNamespace in oOverrides.extension) {
-							oOrigExtensionMetadata = oExtensions[sExtensionNamespace].extension.getMetadata();
-							var oOrigExtensionInterface = ObjectPath.create(sExtensionNamespace, oController.extension);
-							var oOrigExtension = oExtensions[sExtensionNamespace].extension;
-							var oExtensionOverrides = oOverrides.extension[sExtensionNamespace];
-							for (sExtensionOverride in oExtensionOverrides) {
-								if (!oOrigExtensionMetadata.isMethodFinal(sExtensionOverride)) {
-									//override interface
-									ControllerExtension.overrideMethod(sExtensionOverride, oOrigExtensionInterface, oExtensionOverrides, oExtension, oOrigExtensionMetadata.getOverrideExecution(sExtensionOverride));
-									//override Extension so 'this' is working for overrides
-									ControllerExtension.overrideMethod(sExtensionOverride, oOrigExtension, oExtensionOverrides, oExtension, oOrigExtensionMetadata.getOverrideExecution(sExtensionOverride));
-								} else {
-									Log.error("Method '" + sExtensionOverride + "' of extension '" + sExtensionNamespace + "' is flagged final and cannot be overridden by extension '" + sNamespace + "'");
-								}
+					oExtensionInfo.reloadNeeded = true;
+				}
+				//handle non member extension overrides
+				if (oOverrides && oOverrides.extension) {
+					//allow to override methods of other controller extensions
+					for (var sExtensionNamespace in oOverrides.extension) {
+						oOrigExtensionMetadata = oExtensions[sExtensionNamespace].extension.getMetadata();
+						var oOrigExtensionInterface = ObjectPath.create(sExtensionNamespace, oController.extension);
+						var oOrigExtension = oExtensions[sExtensionNamespace].extension;
+						var oExtensionOverrides = oOverrides.extension[sExtensionNamespace];
+						for (sExtensionOverride in oExtensionOverrides) {
+							if (!oOrigExtensionMetadata.isMethodFinal(sExtensionOverride)) {
+								//override interface
+								ControllerExtension.overrideMethod(sExtensionOverride, oOrigExtensionInterface, oExtensionOverrides, oExtension, oOrigExtensionMetadata.getOverrideExecution(sExtensionOverride));
+								//override Extension so 'this' is working for overrides
+								ControllerExtension.overrideMethod(sExtensionOverride, oOrigExtension, oExtensionOverrides, oExtension, oOrigExtensionMetadata.getOverrideExecution(sExtensionOverride));
+							} else {
+								Log.error("Method '" + sExtensionOverride + "' of extension '" + sExtensionNamespace + "' is flagged final and cannot be overridden by extension '" + sNamespace + "'");
 							}
 						}
 					}
-					oExtensionInfo.reloadNeeded = true;
 				}
 			}
 
@@ -290,51 +294,13 @@ sap.ui.define([
 					}
 				});
 			} else if (!ControllerClass) {
-				ControllerClass = sap.ui.requireSync(sControllerName);
+				ControllerClass = sap.ui.requireSync(sControllerName); // legacy-relevant: Sync path
 				return resolveClass(ControllerClass);
 			} else {
 				return ControllerClass;
 			}
 		}
 
-		/* load extension provider
-		 *
-		 * @param {sap.ui.core.mvc.Controller} oController The controller instance
-		 * @param {boolean} bAsync Load async or not
-		 * @return {ExtensionProvider|Promise|undefined} ExtensionProvider <code>Promise</code> in case of asynchronous loading
-		 *           or the <code>ExtensionProvider</code> in case of synchronous loading or undefined in case no provider exists
-		 */
-		function loadExtensionProvider(oController, bAsync) {
-			var sProviderName = Controller._sExtensionProvider.replace(/\./g, "/"),
-				oProvider = mExtensionProvider[sProviderName];
-			if (bAsync) {
-				return new Promise(function(resolve, reject) {
-					if (sProviderName) {
-						if (oProvider){
-							resolve(oProvider);
-						} else {
-							sap.ui.require([sProviderName], function(ExtensionProvider) {
-								oProvider = new ExtensionProvider();
-								mExtensionProvider[sProviderName] = oProvider;
-								resolve(oProvider);
-							}, reject);
-						}
-					} else {
-						resolve();
-					}
-				});
-			} else if (sProviderName) {
-				if (oProvider) {
-					return oProvider;
-				} else {
-					var ExtensionProvider = sap.ui.requireSync(sProviderName);
-					oProvider = new ExtensionProvider();
-					mExtensionProvider[sProviderName] = oProvider;
-					return oProvider;
-				}
-			}
-		}
-
 		/*
 		 * Instantiation of a controller
 		 *
@@ -359,9 +325,11 @@ sap.ui.define([
 		}
 
 		/**
-		 * apply extension if passed as a member of the controller
+		 * Apply extension if passed as a member of the controller
+		 *
 		 * @param {sap.ui.core.mvc.Controller} oController The controller instance
 		 * @param {boolean} bAsync Wether extend async or not
+		 * @returns {Promise|sap.ui.core.mvc.Controller} If <code>bAsync</code> is <code>true</code> a promise which resolves with the extended <code>oController</code>, otherwise the extended <code>oController</code>
 		 * @private
 		 */
 		Controller.extendByMember = function(oController, bAsync) {
@@ -390,145 +358,103 @@ sap.ui.define([
 		};
 
 		/*
-		 * This function can be used to extend a controller with controller
-		 * extensions defined in the Customizing configuration.
-		 *
-		 * @param {object|sap.ui.core.mvc.Controller} Controller to extend
-		 * @param {string} Name of the controller
-		 * @param {boolean} If set to true, extension will be run in async mode
-		 * @return {sap.ui.core.mvc.Controller|Promise} A <code>Promise</code> in case of asynchronous extend
-		 *           or the <code>controller</code> in case of synchronous extend
-		 *
-		 * @private
-		 */
-		Controller.extendByCustomizing = function(oController, sName, bAsync) {
-			var CustomizingConfiguration = sap.ui.require('sap/ui/core/CustomizingConfiguration');
-
-			if (!CustomizingConfiguration) {
-				return bAsync ? Promise.resolve(oController) : oController;
-			}
-
-			function extendAsync(sCustomControllerName, oController) {
-				return loadControllerClass(sCustomControllerName, bAsync)
-					.then(function(oCustomControllerDef) {
+		* This function can be used to extend a controller with controller
+		* extensions returned by controller extension provider.
+		*
+		* @param {object|sap.ui.core.mvc.Controller} oController Controller to extend
+		* @param {string} sName Name of the controller
+		* @param {sap.ui.core.ID|undefined} sOwnerId the ID of the owner component to which this controller belongs,
+		*                                            or undefined if the controller is not associated to a component
+		* @param {sap.ui.core.ID|undefined} sViewId the ID of the corresponding View for <code>oController</code>, or undefined if the controller is created via the the factory
+		* @param {boolean} bAsync If set to true, extension will be run in async mode
+		* @return {sap.ui.core.mvc.Controller|Promise} A <code>Promise</code> in case of asynchronous extend
+		*           or the <code>controller</code> in case of synchronous extend
+		* @private
+		*/
+		Controller.applyExtensions = function(oController, sName, sOwnerId, sViewId, bAsync) {
+			/**
+			 * Retrieves the controller-extension with the given name
+			 * @param {boolean} bAsync whether to retrieve the controller extension async or sync
+			 * @param {string} sControllerName the extension controller class name
+			 */
+			function fnGetExtensionController(bAsync, sControllerName) {
+				if (bAsync) {
+					return loadControllerClass(sControllerName, true).then(function(oExtControllerDef) {
 						// loadControllerClass resolves with the base sap/ui/core/mvc/Controller class,
-						// in case 'sCustomControllerName' is not a module but was defined with sap.ui.controller("...", {})
-						oCustomControllerDef = mRegistry[sCustomControllerName] || oCustomControllerDef;
-
-						if (oCustomControllerDef !== undefined) {
-							if (oCustomControllerDef.getMetadata && oCustomControllerDef.getMetadata().isA("sap.ui.core.mvc.Controller")) {
-								Log.warning("Attempt to load Extension Controller " + sCustomControllerName + " was not successful", "Controller extension should be a plain object.", null, function() {
+						// in case 'sControllerName' is not a module but was defined with sap.ui.controller("...", {})
+						oExtControllerDef = mRegistry[sControllerName] || oExtControllerDef;
+						if (oExtControllerDef !== undefined) {
+							if (oExtControllerDef.getMetadata && oExtControllerDef.getMetadata().isA("sap.ui.core.mvc.Controller")) {
+								Log.warning("Attempt to load Extension Controller " + sControllerName + " was not successful", "Controller extension should be a plain object.", null, function() {
 									return {
 										type: "ControllerExtension",
-										name: sCustomControllerName
+										name: sControllerName
 									};
 								});
-							} else {
-								mixinControllerDefinition(oController, oCustomControllerDef);
 							}
-							return oController;
+							return oExtControllerDef;
 						}
 
 					}, function(err) {
-						Log.error("Attempt to load Extension Controller " + sCustomControllerName + " was not successful - is the Controller correctly defined in its file?");
+						Log.error("Attempt to load Extension Controller " + sControllerName + " was not successful - is the Controller correctly defined in its file?");
 					});
-			}
+				} else {
+					// sync load Controller extension if necessary
+					if (!mRegistry[sControllerName] && !sap.ui.require(sControllerName)) {
+						loadControllerClass(sControllerName);
+					}
 
-			var oCustomControllerDef,
-				aControllerNames = [],
-				sExtControllerName,
-				vController = bAsync ? Promise.resolve(oController) : oController,
-				controllerExtensionConfig = CustomizingConfiguration.getControllerExtension(sName, ManagedObject._sOwnerId);
-
-			if (controllerExtensionConfig) {
-				sExtControllerName = typeof controllerExtensionConfig === "string" ? controllerExtensionConfig : controllerExtensionConfig.controllerName;
-
-				// create a list of controller names which will be used to extend this controller
-				aControllerNames = controllerExtensionConfig.controllerNames || [];
-				if (sExtControllerName) {
-					aControllerNames.unshift(sExtControllerName);
-				}
-			}
-
-			for (var i = 0, l = aControllerNames.length; i < l; i++) {
-				var sControllerName = aControllerNames[i];
-
-				// avoid null values for controllers to be handled here!
-				if (typeof sControllerName === "string") {
-					Log.info("Customizing: Controller '" + sName + "' is now extended by '" + sControllerName + "'");
-
-					if (bAsync) {
-						//chain controllers as the order of processing is relevant
-						vController = vController.then(extendAsync.bind(null, sControllerName, oController));
+					// retrieve legacy controller from registry
+					if (mRegistry[sControllerName] !== undefined) {
+						return mRegistry[sControllerName];
 					} else {
-						//load Controller extension
-						if (!mRegistry[sControllerName] && !sap.ui.require(sControllerName)) {
-							loadControllerClass(sControllerName);
-						}
-						if ((oCustomControllerDef = mRegistry[sControllerName]) !== undefined) { //variable init, not comparison!
-							mixinControllerDefinition(oController, oCustomControllerDef);
-						} else {
-							/* eslint-disable no-loop-func */
-							Log.error("Attempt to load Extension Controller " + sControllerName + " was not successful - is the Controller correctly defined in its file?", null, function() {
-								return {
-									type: "ControllerExtension",
-									name: sControllerName
-								};
-							});
-							/* eslint-enable no-loop-func */
-						}
+						/* eslint-disable no-loop-func */
+						Log.error("Attempt to load Extension Controller " + sControllerName + " was not successful - is the Controller correctly defined in its file?", null, function() {
+							return {
+								type: "ControllerExtension",
+								name: sControllerName
+							};
+						});
+						/* eslint-enable no-loop-func */
+						return {};
 					}
 				}
 			}
-			return vController;
-		};
 
-		/*
-		 * This function can be used to extend a controller with controller
-		 * extensions returned by controller extension provider.
-		 *
-		 * @param {object|sap.ui.core.mvc.Controller} Controller to extend
-		 * @param {string} Name of the controller
-		 * @param {boolean} If set to true, extension will be run in async mode
-		 * @return {sap.ui.core.mvc.Controller|Promise} A <code>Promise</code> in case of asynchronous extend
-		 *           or the <code>controller</code> in case of synchronous extend
-		 * @private
-		 */
-		Controller.extendByProvider = function(oController, sName, sOwnerId, bAsync) {
-			if (!Controller._sExtensionProvider) {
-				return bAsync ? Promise.resolve(oController) : oController;
-			}
-			Log.info("Customizing: Controller '" + sName + "' is now extended by Controller Extension Provider '" + Controller._sExtensionProvider + "'");
-
-			var oExtensions,
-				oExtensionProvider;
 
 			if (bAsync) {
-				return loadExtensionProvider(oController, bAsync)
-					.then(function (oExtensionProvider) {
-						return oExtensionProvider.getControllerExtensions(sName /* controller name */, sOwnerId /* component ID / clarfiy if this is needed? */, bAsync);
-					})
-					.then(function (aControllerExtensions) {
-						if (aControllerExtensions && aControllerExtensions.length) {
-							for (var i = 0, l = aControllerExtensions.length; i < l; i++) {
-								mixinControllerDefinition(oController, aControllerExtensions[i]);
+				return ControllerExtensionProvider.getControllerExtensions(sName, sOwnerId, sViewId, bAsync)
+					.then(function (mControllers) {
+						// load customizing controllers async
+						var aCustomizingControllerPromises = mControllers.customizingControllerNames.map(function(sControllerName) {
+							return fnGetExtensionController(true, sControllerName);
+						});
+
+						return Promise.all(aCustomizingControllerPromises).then(function(aCustomizingControllers) {
+							// order of extensions: 1. customizing, 2. provider
+							// the order is fixed as defined in the manifest, and as returned by the external provider
+							var aAllExtensions = aCustomizingControllers.concat(mControllers.providerControllers);
+
+							for (var i = 0, l = aAllExtensions.length; i < l; i++) {
+								mixinControllerDefinition(oController, aAllExtensions[i]);
 							}
-						}
-						return oController;
+
+							return oController;
+						});
 					}, function(err){
 						Log.error("Controller Extension Provider: Error '" + err + "' thrown in " + Controller._sExtensionProvider + "; extension provider ignored.");
 						return oController;
 					});
-			} else  {
-				oExtensionProvider = loadExtensionProvider(oController, bAsync);
-				oExtensions = oExtensionProvider.getControllerExtensions(sName /* controller name */, sOwnerId /* component ID / clarfiy if this is needed? */, bAsync);
-				if (oExtensions && Array.isArray(oExtensions)) {
-					// in sync mode, oExtensions is an array of controller extensions
-					for (var i = 0, l = oExtensions.length; i < l; i++) {
-						mixinControllerDefinition(oController, oExtensions[i]);
-					}
-				} else {
-					Log.error("Controller Extension Provider: Error in ExtensionProvider.getControllerExtensions: " + Controller._sExtensionProvider + " - no valid extensions returned");
+			} else {
+				var mControllers = ControllerExtensionProvider.getControllerExtensions(sName, sOwnerId, sViewId, bAsync);
+
+				// load and apply customizing controllers
+				var aCustomizingControllers = mControllers.customizingControllerNames.map(fnGetExtensionController.bind(null, false));
+
+				// apply controller-extensions from the external provider
+				var aAllExtensions = aCustomizingControllers.concat(mControllers.providerControllers);
+				for (var i = 0, l = aAllExtensions.length; i < l; i++) {
+					mixinControllerDefinition(oController, aAllExtensions[i]);
 				}
 			}
 
@@ -547,7 +473,7 @@ sap.ui.define([
 		 * @since 1.56.0
 		 */
 		Controller.create = function (mOptions) {
-			return controllerFactory(mOptions.name, undefined, true);
+			return controllerFactory(mOptions.name, undefined, true, mOptions._viewId);
 		};
 
 		/**
@@ -567,12 +493,12 @@ sap.ui.define([
 		 * @return {void | sap.ui.core.mvc.Controller | Promise} void, the new controller instance or a Promise
 		 * 	resolving with the controller in async case
 		 * @static
-		 * @deprecated Since 1.56, use {@link sap.ui.core.mvc.Controller.create Controller.create} or
-		 *  {@link sap.ui.core.mvc.Controller.extend Controller.extend} instead.
+		 * @deprecated Since 1.56, use {@link sap.ui.core.mvc.Controller.extend Controller.extend} to define the controller class
+		 * and {@link sap.ui.core.mvc.Controller.create Controller.create} to create controller instances. For further information, see {@link sap.ui.core.mvc.Controller}.
 		 * @public
 		 * @ui5-global-only
 		 */
-		sap.ui.controller = function (sName, oControllerImpl, bAsync) {
+		sap.ui.controller = function (sName, oControllerImpl, bAsync, sViewId /* privately used view-id, internally used for instance-specific controller extensions */) {
 			if (bAsync) {
 				Log.info("Do not use deprecated factory function 'sap.ui.controller(" + sName + ")'. Use 'sap.ui.core.mvc.Controller.create(...)' instead.", "sap.ui.controller", null, function () {
 					return {
@@ -594,7 +520,7 @@ sap.ui.define([
 		/*
 		 * Old controller factory implementation
 		 */
-		function controllerFactory(sName, oControllerImpl, bAsync) {
+		function controllerFactory(sName, oControllerImpl, bAsync, sViewId) {
 			var oController,
 				ControllerClass,
 				sOwnerId = ManagedObject._sOwnerId;
@@ -611,19 +537,16 @@ sap.ui.define([
 							return instantiateController(ControllerClass, sName);
 						})
 						.then(function(oController) {
-							return Controller.extendByCustomizing(oController, sName, bAsync);
+							return Controller.applyExtensions(oController, sName, sOwnerId, sViewId, bAsync);
 						})
 						.then(function(oController) {
-							return Controller.extendByProvider(oController, sName, sOwnerId, bAsync);
-						}).then(function(oController) {
 							oController._sapui_isExtended = true;
 							return oController;
 						});
 				} else {
 					ControllerClass = loadControllerClass(sName, bAsync);
 					oController = instantiateController(ControllerClass, sName);
-					oController = Controller.extendByCustomizing(oController, sName, bAsync);
-					oController = Controller.extendByProvider(oController, sName, sOwnerId, bAsync);
+					oController = Controller.applyExtensions(oController, sName, sOwnerId, sViewId, bAsync);
 					//if controller is created via the factory all extensions are already mixed in
 					oController._sapui_isExtended = true;
 				}
@@ -636,10 +559,11 @@ sap.ui.define([
 		}
 
 		/**
-		 * Returns a list of public methods of the controller. If <code>bWithExtensions</code> is
-		 * set to true the public methods of the extensions are also returned
+		 * Returns a map of public methods of the controller. If <code>bWithExtensions</code> is
+		 * set to <code>true</code> the public methods of the extensions are included in the result
 		 *
 		 * @private
+		 * @returns {Map<string,object>} A map containing all methods (key) and their metadata
 		 */
 		Controller.prototype.getPublicMethods = function() {
 			var mPublicFunctions = {},
@@ -672,16 +596,60 @@ sap.ui.define([
 			return mPublicFunctions;
 		};
 
+		/**
+		 * Returns the list of Promises for which an automatic destroy is scheduled.
+		 * Logs an error in case the application controller is missing a mandatory
+		 * constructor super call.
+		 * For compatibility reason we must not fail in this obviously broken scenario!
+		 *
+		 * @private
+		 */
+		Controller.prototype._getDestroyables = function() {
+			if (!this._aDestroyables) {
+				Log.error("Mandatory super constructor not called for Controller: '" + this.getMetadata().getName() + "'.",
+					null,
+					"sap.ui.support",
+					function() {
+						return { type: "missingSuperConstructor" };
+					});
+				this._aDestroyables = [];
+			}
+			return this._aDestroyables;
+		};
+
+		/**
+		 * Takes care of async destruction of fragments created with {@link sap.ui.core.Controller.loadFragment loadFragment}
+		 *
+		 * @private
+		 */
+		Controller.prototype.destroyFragments = function() {
+			function fnDestroy(vContent) {
+				vContent = Array.isArray(vContent) ? vContent : [vContent];
+				for (var i = 0; i < vContent.length; i++) {
+					if (!vContent[i].isDestroyed()) {
+						vContent[i].destroy();
+					}
+				}
+			}
+			// chain each cancelable to trigger an async destroy
+			var aDestroyables = this._getDestroyables();
+			for (var i = 0; i < aDestroyables.length; i++ ) {
+				aDestroyables[i] = aDestroyables[i].then(fnDestroy);
+			}
+		};
+
 		/**
 		 * Fire event when destroying a controller to cleanup extensions
 		 * @private
 		 */
 		Controller.prototype.destroy = function() {
-			Object.keys(this["_sapui_Extensions"]).forEach(function(oExtensionInfo) {
-				ObjectPath.set(oExtensionInfo.location, null, this);
-			}.bind(this));
-			delete this["_sapui_Extensions"];
-			delete this["_sapui_Interface"];
+			if (this["_sapui_Extensions"]) {
+				Object.keys(this["_sapui_Extensions"]).forEach(function(sKey) {
+					var oExtensionInfo = this["_sapui_Extensions"][sKey];
+					ObjectPath.set(oExtensionInfo.location, null, this);
+				}.bind(this));
+				delete this["_sapui_Extensions"];
+			}
 			EventProvider.prototype.destroy.apply(this, arguments);
 		};
 
@@ -738,8 +706,12 @@ sap.ui.define([
 		 * @public
 		 */
 		Controller.prototype.getOwnerComponent = function () {
-			var Component = sap.ui.requireSync("sap/ui/core/Component");
-			return Component.getOwnerComponentFor(this.getView());
+			var Component = sap.ui.require("sap/ui/core/Component");
+			if (Component) {
+				return Component.getOwnerComponentFor(this.getView());
+			} else {
+				return undefined;
+			}
 		};
 
 
@@ -751,6 +723,9 @@ sap.ui.define([
 			}
 			if (this.onExit) {
 				oView.attachBeforeExit(this.onExit, this);
+				if (oView.bControllerIsViewManaged) {
+					oView.attachBeforeExit(this.destroyFragments, this);
+				}
 			}
 			if (this.onAfterRendering) {
 				oView.attachAfterRendering(this.onAfterRendering, this);
@@ -758,9 +733,114 @@ sap.ui.define([
 			if (this.onBeforeRendering) {
 				oView.attachBeforeRendering(this.onBeforeRendering, this);
 			}
-			//oView.addDelegate(this);
 		};
 
+		/**
+		 * Loads a Fragment by {@link sap.ui.core.Fragment.load}.
+		 *
+		 * The fragment content will be added to the <code>dependents</code> aggregation of the view by default.
+		 * This behavior can be suppressed by setting <code>mOptions.addToDependents</code> to false.
+		 *
+		 * The controller is passed to the Fragment by default, so the (event handler) methods referenced in the
+		 * Fragment will be called on this Controller.
+		 *
+		 * If the controller has an owner component, it is passed to the fragment content.
+		 * By default the fragment content will be prefixed with the view ID to avoid duplicate ID issues.
+		 * The prefixing can be switched off with the <code>autoPrefixId</code> option.
+		 *
+		 * When <code>autoPrefixId</code> is enabled, the fragment content can be accessed by calling
+		 * {@link sap.ui.core.mvc.Controller.byId}.
+		 *
+		 * <b>Destroy behavior</b>:
+		 * Different scenarios concerning the destruction of the fragment's content exist,
+		 * of which some must be addressed by the caller, while others are handled automatically.
+		 * <ul>
+		 * <li>The controller instance is destroyed before the fragment content creation has finished:
+		 *     In this case, the controller instance takes care of asynchronously destroying the fragment content</li>
+		 * <li>The fragment content is aggregated within a control (e.g. <code>dependents</code> aggregation by default):
+		 *     In this case, the content will be destroyed during the regular destroy lifecycle.</li>
+		 * <li>The fragment content is not aggregated within a control:
+		 *     In this case, <em>it must be destroyed manually</em> in the exit hook of the controller.</li>
+		 * </ul>
+		 *
+		 * @example <caption>Loading a fragment with no <code>mOptions.id</code> given</caption>
+		 * // In the following, "this" is an instance of sap.ui.core.mvc.Controller
+		 * var pFragment = this.loadFragment({
+		 *     name: "myFragment"
+		 * }).then(function() {
+		 *     var myControl = this.byId("myFragment");
+		 * }.bind(this));
+		 *
+		 * @example <caption>Loading a fragment with an <code>mOptions.id</code> given</caption>
+		 * // In the following, "this" is an instance of sap.ui.core.mvc.Controller
+		 * var pFragment = this.loadFragment({
+		 *     name: "myFragment",
+		 *     id: "somePrefix"
+		 * }).then(function() {
+		 *     var myControl = this.byId("somePrefix--myFragment");
+		 * }.bind(this));
+		 *
+		 * @param {object} mOptions Options regarding fragment loading
+		 * @param {string} mOptions.name The Fragment name, which must correspond to a Fragment which can be loaded via the module system
+		 *    (fragmentName + suffix ".fragment.[typeextension]") and which contains the Fragment definition.
+		 * @param {object} [mOptions.addToDependents=true] Whether the fragment content should be added to the <code>dependents</code> aggregation of the view
+		 * @param {object} [mOptions.autoPrefixId=true] Whether the IDs of the fragment content will be prefixed by the view ID
+		 * @param {string} [mOptions.id] the ID of the Fragment
+		 * @param {string} [mOptions.type=XML] the Fragment type, e.g. "XML", "JS", or "HTML" (see above). Default is "XML"
+		 * @return {Promise} A Promise that resolves with the fragment content
+		 *
+		 * @since 1.93
+		 * @public
+		 */
+		Controller.prototype.loadFragment = function(mOptions) {
+			if (!this.getView()) {
+				throw new Error("Calling 'loadFragment' without a view attached is not supported!");
+			} else if (!mOptions || !mOptions.name) {
+				throw new Error("oOptions must provide at least a fragment name!");
+			}
+
+			var oOwnerComponent = this.getOwnerComponent();
+			var bAddToDependents = mOptions.addToDependents !== false;
+			var bAutoPrefixId = mOptions.autoPrefixId !== false;
+
+			var oFragmentOptions = {
+				name: mOptions.name,
+				type: mOptions.type,
+				id: mOptions.id,
+				controller: this
+			};
+
+			var aDestroyables = this._getDestroyables();
+
+			var pRequire = new Promise(function(resolve, reject) {
+				sap.ui.require(["sap/ui/core/Fragment"], function(Fragment) {
+					resolve(Fragment);
+				}, reject);
+			}).then(function(Fragment) {
+				if (!mOptions.id && bAutoPrefixId) {
+					oFragmentOptions.id = this.getView().getId();
+				} else if (bAutoPrefixId) {
+					oFragmentOptions.id = this.createId(mOptions.id);
+				}
+				if (oOwnerComponent) {
+					return oOwnerComponent.runAsOwner(function() {
+						return Fragment.load(oFragmentOptions);
+					});
+				} else {
+					return Fragment.load(oFragmentOptions);
+				}
+			}.bind(this)).then(function(vContent) {
+				if (bAddToDependents) {
+					this.getView().applySettings({"dependents": vContent});
+				}
+				/* if already resolved remove from bookkeeping. App needs to destroy or it is
+				implicitly destroyed via the dependents (or other) aggregation */
+				aDestroyables.splice(aDestroyables.indexOf(pRequire),1);
+				return vContent;
+			}.bind(this));
+			aDestroyables.push(pRequire);
+			return pRequire;
+		};
 
 		/**
 		 * Global extension provider name which will be used to create the
@@ -779,12 +859,12 @@ sap.ui.define([
 		 * The extension provider module provides the <code>getControllerExtensions</code> function
 		 * which returns either directly an array of objects or a Promise that returns an array
 		 * of objects when it resolves. These objects are object literals defining the
-		 * methods and properties of the controller in a similar way as {@link sap.ui.controller}.
+		 * methods and properties of the controller in a similar way as for {@link sap.ui.core.mvc.Controller Controller} subclasses.
 		 *
 		 *
 		 * <b>Example for a callback module definition (sync):</b>
 		 * <pre>
-		 * sap.ui.define("my/custom/sync/ExtensionProvider", ['jquery.sap.global'], function(jQuery) {
+		 * sap.ui.define("my/custom/sync/ExtensionProvider", [], function() {
 		 *   var ExtensionProvider = function() {};
 		 *   ExtensionProvider.prototype.getControllerExtensions = function(sControllerName, sComponentId, bAsync) {
 		 *     if (!bAsync && sControllerName == "my.own.Controller") {
@@ -803,13 +883,13 @@ sap.ui.define([
 		 *     }];
 		 *   };
 		 *   return ExtensionProvider;
-		 * }, true);
+		 * });
 		 * </pre>
 		 *
 		 *
 		 * <b>Example for a callback module definition (async):</b>
 		 * <pre>
-		 * sap.ui.define("my/custom/async/ExtensionProvider", ['jquery.sap.global'], function(jQuery) {
+		 * sap.ui.define("my/custom/async/ExtensionProvider", [], function() {
 		 *   var ExtensionProvider = function() {};
 		 *   ExtensionProvider.prototype.getControllerExtensions = function(sControllerName, sComponentId, bAsync) {
 		 *     if (bAsync && sControllerName == "my.own.Controller") {
@@ -833,7 +913,7 @@ sap.ui.define([
 		 *     };
 		 *   };
 		 *   return ExtensionProvider;
-		 * }, true);
+		 * });
 		 * </pre>
 		 *
 		 *
@@ -850,12 +930,13 @@ sap.ui.define([
 		 *
 		 * @param {string} sExtensionProvider the module name of the extension provider
 		 *
-		 * See {@link sap.ui.controller} for an overview of the available functions for controllers.
+		 * See {@link sap.ui.core.mvc.Controller} for an overview of the available functions for controllers.
 		 * @since 1.34.0
 		 * @public
 		 */
 		Controller.registerExtensionProvider = function(sExtensionProvider) {
 			Controller._sExtensionProvider = sExtensionProvider;
+			ControllerExtensionProvider.registerExtensionProvider(sExtensionProvider);
 		};
 
 
