@@ -1,6 +1,6 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
@@ -19,7 +19,7 @@ sap.ui.define([
 	"use strict";
 
 		/**
-		 * Instantiates an SAPUI5 Route
+		 * Instantiates a route
 		 *
 		 * @class
 		 * @param {sap.ui.core.routing.Router} oRouter
@@ -47,11 +47,9 @@ sap.ui.define([
 		 * <li>
 		 * rest as string parameters: "pattern" : ":all*:" - this pattern will define an optional variable that will pass the whole hash as string to the routing events. It may be used to define a catchall route, e. g. the following hashes would match: foo, product/5/3, product/5/detail/3/foo. You can also combine it with the other variables but make sure a variable with a * is the last one.</br>
 		 * </ul>
-		 * @param {boolean} [oConfig.greedy=false]
-		 *   @since 1.27: By default only the first route matching the hash, will fire events. If greedy is turned on
+		 * @param {boolean} [oConfig.greedy=false] Since 1.27. By default only the first route matching the hash, will fire events. If greedy is turned on
 		 *   for a route, its events will be fired even if another route has already matched.
-		 * @param {string} [oConfig.parent]
-		 *   @since 1.32 This property contains the information about the route which nests this route in the form:
+		 * @param {string} [oConfig.parent] Since 1.32. This property contains the information about the route which nests this route in the form:
 		 *   "[componentName:]routeName". The nesting routes pattern will be prefixed to this routes pattern and hence
 		 *   the nesting route also matches if this one matches.
 		 * @param {string|string[]} [oConfig.target]
@@ -72,17 +70,17 @@ sap.ui.define([
 		 *   the view created by a component, or if the Route is a subroute the view of the parent route is taken.
 		 *   You only need to specify this, if you are not using a router created by a component on your top level routes
 		 * @param {string} [oConfig.targetControl]
-		 *   <b>Deprecated since 1.28, use <code>target.controlId</code> instead.</b></br> Views will be put into a container Control, this might be a
-		 *   {@link sap.ui.ux3.Shell} control or a {@link sap.m.NavContainer} if working with mobile, or any other container.
+		 *   <b>Deprecated since 1.28, use <code>target.controlId</code> instead.</b></br> Views will be put into a container Control, this might be an
+		 *   {@link sap.ui.ux3.Shell} control or an {@link sap.m.NavContainer} if working with mobile, or any other container.
 		 *   The id of this control has to be put in here
 		 * @param {string} [oConfig.targetAggregation]
 		 *   <b>Deprecated since 1.28, use <code>target.controlAggregation</code> instead.</b></br> The name of an aggregation of the targetControl,
-		 *   that contains views. Eg: a {@link sap.m.NavContainer} has an aggregation "pages", another Example is the
+		 *   that contains views. Eg: an {@link sap.m.NavContainer} has an aggregation "pages", another Example is the
 		 *   {@link sap.ui.ux3.Shell} it has "content".
 		 * @param {boolean} [oConfig.clearTarget=false]
 		 *   <b>Deprecated since 1.28, use <code>target.clearControlAggregation</code> instead.</b></br> Defines a boolean that
-		 *   can be passed to specify if the aggregation should be cleared before adding the View to it. When using a
-		 *   {@link sap.ui.ux3.Shell} this should be true. For a {@link sap.m.NavContainer} it should be false
+		 *   can be passed to specify if the aggregation should be cleared before adding the View to it. When using an
+		 *   {@link sap.ui.ux3.Shell} this should be true. For an {@link sap.m.NavContainer} it should be false
 		 * @param {object} [oConfig.subroutes]
 		 *   <b>Deprecated since 1.28, use <code>targets.parent</code> instead.</b> one or multiple route configs taking all of these parameters again.
 		 *   If a subroute is hit, it will fire the routeMatched event for all its parents. The routePatternMatched event
@@ -232,6 +230,21 @@ sap.ui.define([
 				if (this._oRouter._oTargets) {
 					// suspend the targets which were displayed when the route was matched
 					this._oRouter._oTargets.suspend(this._oConfig.target);
+
+					// suspend the dynamic targets
+					if (this._oConfig.dynamicTarget) {
+						this._oRouter._oTargets.suspend(this._oConfig.dynamicTarget);
+					}
+				}
+			},
+
+			_resume: function() {
+				if (this._oRouter._oTargets) {
+					this._oRouter._oTargets.resume(this._oConfig.target);
+
+					if (this._oConfig.dynamicTarget) {
+						this._oRouter._oTargets.resume(this._oConfig.dynamicTarget);
+					}
 				}
 			},
 
@@ -431,7 +444,7 @@ sap.ui.define([
 			 *            [oListener] Context object to call the event handler with. Defaults to this
 			 *            <code>sap.ui.core.routing.Route</code> itself
 			 *
-			 * @returns {sap.ui.core.routing.Route} Reference to <code>this</code> in order to allow method chaining
+			 * @returns {this} Reference to <code>this</code> in order to allow method chaining
 			 * @public
 			 * @since 1.25.1
 			 */
@@ -447,7 +460,7 @@ sap.ui.define([
 			 *
 			 * @param {function} fnFunction The function to be called, when the event occurs
 			 * @param {object} [oListener] Context object on which the given function had to be called
-			 * @returns {sap.ui.core.routing.Route} Reference to <code>this</code> in order to allow method chaining
+			 * @returns {this} Reference to <code>this</code> in order to allow method chaining
 			 * @public
 			 * @since 1.25.1
 			 */
@@ -496,7 +509,7 @@ sap.ui.define([
 			 *            [oListener] Context object to call the event handler with. Defaults to this
 			 *            <code>Route</code> itself
 			 *
-			 * @returns {sap.ui.core.routing.Route} Reference to <code>this</code> in order to allow method chaining
+			 * @returns {this} Reference to <code>this</code> in order to allow method chaining
 			 * @public
 			 * @since 1.46.1
 			 */
@@ -512,7 +525,7 @@ sap.ui.define([
 			 *
 			 * @param {function} fnFunction The function to be called, when the event occurs
 			 * @param {object} [oListener] Context object on which the given function had to be called
-			 * @returns {sap.ui.core.routing.Route} Reference to <code>this</code> in order to allow method chaining
+			 * @returns {this} Reference to <code>this</code> in order to allow method chaining
 			 * @public
 			 * @since 1.46.1
 			 */
@@ -573,7 +586,7 @@ sap.ui.define([
 			 *            [oListener] Context object to call the event handler with. Defaults to this
 			 *            <code>Route</code> itself
 			 *
-			 * @returns {sap.ui.core.routing.Route} Reference to <code>this</code> in order to allow method chaining
+			 * @returns {this} Reference to <code>this</code> in order to allow method chaining
 			 * @public
 			 * @since 1.25.1
 			 */
@@ -589,7 +602,7 @@ sap.ui.define([
 			 *
 			 * @param {function} fnFunction The function to be called, when the event occurs
 			 * @param {object} [oListener] Context object on which the given function had to be called
-			 * @returns {sap.ui.core.routing.Route} Reference to <code>this</code> in order to allow method chaining
+			 * @returns {this} Reference to <code>this</code> in order to allow method chaining
 			 * @public
 			 * @since 1.25.1
 			 */
