@@ -1,6 +1,6 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
@@ -43,7 +43,7 @@ sap.ui.define([
 		var oRouters = {};
 
 		/**
-		 * Instantiates a SAPUI5 Router
+		 * Instantiates a router
 		 *
 		 * @class
 		 * @extends sap.ui.base.EventProvider
@@ -141,8 +141,8 @@ sap.ui.define([
 		 * </pre>
 		 *
 		 * Since the xmlTarget does not specify its viewType, XML is taken from the config object. The jsTarget is specifying it, so the viewType will be JS.
-		 * @param {object} [oConfig.bypassed] @since 1.28. Settings which are used when no route of the router is matched after a hash change.
-		 * @param {string|string[]} [oConfig.bypassed.target] @since 1.28. One or multiple names of targets that will be displayed, if no route of the router is matched.<br/>
+		 * @param {object} [oConfig.bypassed] Since 1.28. Settings which are used when no route of the router is matched after a hash change.
+		 * @param {string|string[]} [oConfig.bypassed.target] Since 1.28. One or multiple names of targets that will be displayed, if no route of the router is matched.<br/>
 		 * A typical use case is a not found page.<br/>
 		 * The current hash will be passed to the display event of the target.<br/>
 		 * <b>Example:</b>
@@ -164,18 +164,19 @@ sap.ui.define([
 		 *     {
 		 *          //same name as in the config.bypassed.target
 		 *          notFound: {
-		 *              viewName: "notFound",
+		 *              type: "View"
+		 *              name: "notFound",
 		 *              ...
 		 *              // more properties to place the view in the correct container
 		 *          }
 		 *     });
 		 * </pre>
-		 * @param {boolean} [oConfig.async=false] @since 1.34. Whether the views which are loaded within this router instance asyncly
+		 * @param {boolean} [oConfig.async=false] Since 1.34. Whether views are loaded asynchronously within this router instance.
+		 * As of 1.90 synchronous routing is deprecated. Therefore, you should explicitly set <code>oConfig.async</code> to <code>true</code>.
 		 * @param {sap.ui.core.UIComponent} [oOwner] the Component of all the views that will be created by this Router,<br/>
 		 * will get forwarded to the {@link sap.ui.core.routing.Views#constructor}.<br/>
 		 * If you are using the componentMetadata to define your routes you should skip this parameter.
-		 * @param {object} [oTargetsConfig]
-		 * available @since 1.28 the target configuration, see {@link sap.ui.core.routing.Targets#constructor} documentation (the options object).<br/>
+		 * @param {object} [oTargetsConfig] Since 1.28 the target configuration, see {@link sap.ui.core.routing.Targets#constructor} documentation (the options object).<br/>
 		 * You should use Targets to create and display views. Since 1.28 the route should only contain routing relevant properties.<br/>
 		 * <b>Example:</b>
 		 * <pre>
@@ -249,15 +250,23 @@ sap.ui.define([
 
 				if (oTargetsConfig) {
 					this._oTargets = this._createTargets(this._oConfig, oTargetsConfig);
+
+					// The router instance can't be forwarded to the target through the constructor parameter because
+					// the _createTargets method is overwritten in router subclasses, for example sap.m.routing.Router,
+					// without calling the parent's constructor
+					this._oTargets._setRouter(this);
+
 					this._oTargets.attachDisplay(function(oEvent) {
+						var bIsRouteRelevant = oEvent.getParameter("routeRelevant");
+
 						if (this.isInitialized() && !this._bMatchingProcessStarted) {
 							var oHashChanger = this.getHashChanger();
 							// check the type of oHashChanger before calling the function "resetHash"
 							// which only exists on RouterHashChanger
-							if (oHashChanger instanceof RouterHashChanger) {
+							if (oHashChanger instanceof RouterHashChanger && !bIsRouteRelevant) {
 								// reset the hash to allow the match with the previous route after
 								// displaying a target without involving the router
-								oHashChanger.resetHash();
+								oHashChanger.resetHash(this);
 							}
 						}
 					}, this);
@@ -293,8 +302,7 @@ sap.ui.define([
 				}
 				this.setHashChanger(oRouterHashChanger);
 
-				var oParentComponent = this._oOwner && Component.getOwnerComponentFor(this._oOwner);
-				var oParentRouter = oParentComponent && oParentComponent.getRouter();
+				var oParentRouter = this._getParentRouter();
 
 				if (oParentRouter) {
 					// attach titleChanged event and forward event parameters to parent router
@@ -373,9 +381,9 @@ sap.ui.define([
 			 *
 			 * See {@link sap.ui.core.routing.HashChanger}.
 			 *
-			 * @param {boolean} [bIgnoreInitialHash=false] @since 1.48.0 Whether the current URL hash shouldn't be parsed after the router is initialized
+			 * @param {boolean} [bIgnoreInitialHash=false] Since 1.48.0. Whether the current URL hash shouldn't be parsed after the router is initialized
 			 * @public
-			 * @returns {sap.ui.core.routing.Router} this for chaining.
+			 * @returns {this} this for chaining.
 			 */
 			initialize : function (bIgnoreInitialHash) {
 				var that = this,
@@ -415,6 +423,10 @@ sap.ui.define([
 					}
 				}
 
+				if (this.oHashChanger instanceof RouterHashChanger) {
+					this.oHashChanger._setActiveRouter(this);
+				}
+
 				this.oHashChanger.init();
 				sHash = this.oHashChanger.getHash();
 
@@ -424,10 +436,14 @@ sap.ui.define([
 				// shouldn't be processed.
 				this.oHashChanger.attachEvent("hashChanged", this.fnHashChanged);
 
-				// The HashChanger returns an InvalidHash when one of its ancestors is currently in
-				// the collect mode of preparing the next hash change. In this case, the Router should
-				// not be initialized and wait for the next 'hashChanged' event.
-				if (!bIgnoreInitialHash && sHash !== RouterHashChanger.InvalidHash) {
+				if (bIgnoreInitialHash) {
+					if (this._oMatchedRoute) {
+						this._oMatchedRoute._resume();
+					}
+				} else if (sHash !== RouterHashChanger.InvalidHash) {
+					// The HashChanger returns an InvalidHash when one of its ancestors is currently in
+					// the collect mode of preparing the next hash change. In this case, the Router should
+					// not parse the current hash and wait for the next 'hashChanged' event.
 					this.parse(sHash);
 				}
 
@@ -479,7 +495,6 @@ sap.ui.define([
 
 				if (this._oMatchedRoute) {
 					this._oMatchedRoute._routeSwitched();
-					this._oMatchedRoute = null;
 				}
 
 				this._bIsInitialized = false;
@@ -644,12 +659,19 @@ sap.ui.define([
 				}
 			},
 
+			/**
+			 * @typedef {Object} sap.ui.core.routing.RouteInfo
+			 * @property {string} name The route name
+			 * @property {Object.<string, string>} arguments The route data
+			 * @public
+			 */
+
 			/**
 			 * Returns a route info object containing the name and arguments of the route
 			 * which matches the given hash or <code>undefined</code>.
 			 *
 			 * @param {string} sHash The hash to be matched
-			 * @returns {object|undefined} An object containing the route <code>name</code> and the <code>arguments</code> or <code>undefined</code>
+			 * @returns {sap.ui.core.routing.RouteInfo|undefined} An object containing the route <code>name</code> and the <code>arguments</code> or <code>undefined</code>
 			 * @public
 			 * @since 1.75
 			 */
@@ -718,7 +740,7 @@ sap.ui.define([
 					viewName: sViewName,
 					type: sViewType,
 					id: sViewId
-				});
+				}, true);
 
 				this.fireViewCreated({
 					view: oView,
@@ -738,13 +760,24 @@ sap.ui.define([
 			 * @param {sap.ui.core.mvc.View} oView The view instance
 			 * @since 1.22
 			 * @public
-			 * @returns {sap.ui.core.routing.Router} @since 1.28 the this pointer for chaining
+			 * @returns {this} Since 1.28, the <code>this</code> pointer for chaining
 			 */
 			setView : function (sViewName, oView) {
 				this._oViews.setView(sViewName, oView);
 				return this;
 			},
 
+			/**
+			 * Determines the router instance of the parent component
+			 *
+			 * @private
+			 * @returns {sap.ui.core.routing.Router} The router of the parent component
+			 */
+			_getParentRouter : function(){
+				var oParentComponent = this._oOwner && Component.getOwnerComponentFor(this._oOwner);
+				return oParentComponent && oParentComponent.getRouter();
+			},
+
 			/**
 			 * Navigates to a specific route defining a set of parameters.
 			 *
@@ -803,7 +836,7 @@ sap.ui.define([
 			*             history. If set to <code>false</code>, the hash is set and the entry is stored in the browser
 			*             history.
 			 * @public
-			 * @returns {sap.ui.core.routing.Router} this for chaining.
+			 * @returns {this} this for chaining.
 			 */
 			navTo : function (sName, oParameters, oComponentTargetInfo, bReplace) {
 				var that = this,
@@ -811,6 +844,11 @@ sap.ui.define([
 					oRoute = this.getRoute(sName),
 					pComponentHashChange, sHash;
 
+				if (this.isStopped()){
+					Log.info("The router instance " + this._sId + " is stopped. No navigation can be performed.");
+					return this;
+				}
+
 				if (!oRoute) {
 					Log.warning("Route with name " + sName + " does not exist", this);
 					return this;
@@ -936,7 +974,7 @@ sap.ui.define([
 			 *            [oListener] Context object to call the event handler with, defaults to this
 			 *            <code>sap.ui.core.routing.Router</code> itself
 			 *
-			 * @returns {sap.ui.core.routing.Router} Reference to <code>this</code> in order to allow method chaining
+			 * @returns {this} Reference to <code>this</code> in order to allow method chaining
 			 * @public
 			 */
 			attachRouteMatched : function(oData, fnFunction, oListener) {
@@ -954,7 +992,7 @@ sap.ui.define([
 			 *            fnFunction The function to be called when the event occurs
 			 * @param {object}
 			 *            oListener Context object on which the given function had to be called
-			 * @returns {sap.ui.core.routing.Router} Reference to <code>this</code> in order to allow method chaining
+			 * @returns {this} Reference to <code>this</code> in order to allow method chaining
 			 * @public
 			 */
 			detachRouteMatched : function(fnFunction, oListener) {
@@ -967,7 +1005,7 @@ sap.ui.define([
 			 *
 			 * @param {object} [oParameters] Parameters to pass along with the event
 			 *
-			 * @returns {sap.ui.core.routing.Router} Reference to <code>this</code> in order to allow method chaining
+			 * @returns {this} Reference to <code>this</code> in order to allow method chaining
 			 * @protected
 			 */
 			fireRouteMatched : function(oParameters) {
@@ -1023,7 +1061,7 @@ sap.ui.define([
 			 *            [oListener] Context object to call the event handler with, defaults to this
 			 *            <code>sap.ui.core.routing.Router</code> itself
 			 *
-			 * @returns {sap.ui.core.routing.Router} Reference to <code>this</code> in order to allow method chaining
+			 * @returns {this} Reference to <code>this</code> in order to allow method chaining
 			 * @public
 			 */
 			attachBeforeRouteMatched : function(oData, fnFunction, oListener) {
@@ -1041,7 +1079,7 @@ sap.ui.define([
 			 *            fnFunction The function to be called when the event occurs
 			 * @param {object}
 			 *            oListener Context object on which the given function had to be called
-			 * @returns {sap.ui.core.routing.Router} Reference to <code>this</code> in order to allow method chaining
+			 * @returns {this} Reference to <code>this</code> in order to allow method chaining
 			 * @public
 			 */
 			detachBeforeRouteMatched : function(fnFunction, oListener) {
@@ -1054,7 +1092,7 @@ sap.ui.define([
 			 *
 			 * @param {object} [oParameters] Parameters to pass along with the event
 			 *
-			 * @returns {sap.ui.core.routing.Router} Reference to <code>this</code> in order to allow method chaining
+			 * @returns {this} Reference to <code>this</code> in order to allow method chaining
 			 * @protected
 			 */
 			fireBeforeRouteMatched : function(oParameters) {
@@ -1078,7 +1116,7 @@ sap.ui.define([
 			 *            [oListener] Context object to call the event handler with, defaults to this
 			 *            <code>sap.ui.core.routing.Router</code> itself
 			 *
-			 * @returns {sap.ui.core.routing.Router} Reference to <code>this</code> in order to allow method chaining
+			 * @returns {this} Reference to <code>this</code> in order to allow method chaining
 			 * @public
 			 * @deprecated Since 1.28 use {@link #getViews} instead.
 			 */
@@ -1097,7 +1135,7 @@ sap.ui.define([
 			 *            fnFunction The function to be called when the event occurs
 			 * @param {object}
 			 *            oListener Context object on which the given function had to be called
-			 * @returns {sap.ui.core.routing.Router} Reference to <code>this</code> in order to allow method chaining
+			 * @returns {this} Reference to <code>this</code> in order to allow method chaining
 			 * @public
 			 * @deprecated Since 1.28 use {@link #getViews} instead.
 			 */
@@ -1111,7 +1149,7 @@ sap.ui.define([
 			 *
 			 * @param {object} [oParameters] Parameters to pass along with the event
 			 *
-			 * @returns {sap.ui.core.routing.Router} Reference to <code>this</code> in order to allow method chaining
+			 * @returns {this} Reference to <code>this</code> in order to allow method chaining
 			 * @protected
 			 * @deprecated As of 1.28 use {@link #getViews} instead.
 			 */
@@ -1163,7 +1201,7 @@ sap.ui.define([
 			 *            [oListener] Context object to call the event handler with, defaults to this
 			 *            <code>sap.ui.core.routing.Router</code> itself
 			 *
-			 * @returns {sap.ui.core.routing.Router} Reference to <code>this</code> in order to allow method chaining
+			 * @returns {this} Reference to <code>this</code> in order to allow method chaining
 			 * @public
 			 */
 			attachRoutePatternMatched : function(oData, fnFunction, oListener) {
@@ -1184,7 +1222,7 @@ sap.ui.define([
 			 *            fnFunction The function to be called when the event occurs
 			 * @param {object}
 			 *            oListener Context object on which the given function had to be called
-			 * @returns {sap.ui.core.routing.Router} Reference to <code>this</code> in order to allow method chaining
+			 * @returns {this} Reference to <code>this</code> in order to allow method chaining
 			 * @public
 			 */
 			detachRoutePatternMatched : function(fnFunction, oListener) {
@@ -1200,7 +1238,7 @@ sap.ui.define([
 			 *
 			 * @param {object} [oParameters] Parameters to pass along with the event
 			 *
-			 * @returns {sap.ui.core.routing.Router} Reference to <code>this</code> in order to allow method chaining
+			 * @returns {this} Reference to <code>this</code> in order to allow method chaining
 			 * @protected
 			 */
 			fireRoutePatternMatched : function(oParameters) {
@@ -1238,7 +1276,7 @@ sap.ui.define([
 			 *            [oListener] Context object to call the event handler with, defaults to this
 			 *            <code>sap.ui.core.routing.Router</code> itself
 			 *
-			 * @returns {sap.ui.core.routing.Router} Reference to <code>this</code> in order to allow method chaining
+			 * @returns {this} Reference to <code>this</code> in order to allow method chaining
 			 * @public
 			 */
 			attachBypassed : function(oData, fnFunction, oListener) {
@@ -1257,7 +1295,7 @@ sap.ui.define([
 			 *            fnFunction The function to be called when the event occurs
 			 * @param {object}
 			 *            oListener Context object on which the given function had to be called
-			 * @returns {sap.ui.core.routing.Router} Reference to <code>this</code> in order to allow method chaining
+			 * @returns {this} Reference to <code>this</code> in order to allow method chaining
 			 * @public
 			 */
 			detachBypassed : function(fnFunction, oListener) {
@@ -1271,7 +1309,7 @@ sap.ui.define([
 			 *
 			 * @param {object} [oParameters] Parameters to pass along with the event
 			 *
-			 * @returns {sap.ui.core.routing.Router} Reference to <code>this</code> in order to allow method chaining
+			 * @returns {this} Reference to <code>this</code> in order to allow method chaining
 			 * @protected
 			 */
 			fireBypassed : function(oParameters) {
@@ -1330,7 +1368,7 @@ sap.ui.define([
 			 *            [oListener] Context object to call the event handler with, defaults to this
 			 *            <code>sap.ui.core.routing.Router</code> itself
 			 *
-			 * @returns {sap.ui.core.routing.Router} Reference to <code>this</code> in order to allow method chaining
+			 * @returns {this} Reference to <code>this</code> in order to allow method chaining
  			 * @public
  			 */
 			attachTitleChanged : function(oData, fnFunction, oListener) {
@@ -1348,7 +1386,7 @@ sap.ui.define([
 			 *            fnFunction The function to be called when the event occurs
 			 * @param {object}
 			 *            oListener Context object on which the given function had to be called
-			 * @returns {sap.ui.core.routing.Router} Reference to <code>this</code> in order to allow method chaining
+			 * @returns {this} Reference to <code>this</code> in order to allow method chaining
 			 * @public
 			 */
 			detachTitleChanged : function(fnFunction, oListener) {
@@ -1443,7 +1481,13 @@ sap.ui.define([
 				}
 
 				if (bImmediateFire) {
-					this.fireEvent(Router.M_EVENTS.TITLE_CHANGED, mParameters);
+					if (this._bMatchingProcessStarted && this._isAsync()) {
+						this.attachEventOnce("routeMatched", function(){
+							this.fireEvent(Router.M_EVENTS.TITLE_CHANGED, mParameters);
+						}, this);
+					} else {
+						this.fireEvent(Router.M_EVENTS.TITLE_CHANGED, mParameters);
+					}
 				}
 
 				return this;
@@ -1488,7 +1532,7 @@ sap.ui.define([
 			 * Use {@link sap.ui.core.routing.Router.getRouter Router.getRouter()} to retrieve the instance.
 			 *
 			 * @param {string} sName Name of the router instance
-			 * @returns {sap.ui.core.routing.Router} The router instance
+			 * @returns {this} The router instance
 			 * @public
 			 */
 			register : function (sName) {
