@@ -1,16 +1,17 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
 // Provides class sap.ui.core.support.plugins.Performance
 sap.ui.define([
-	'sap/ui/core/support/Plugin',
+	"sap/ui/core/Core",
+	"sap/ui/core/support/Plugin",
 	"sap/ui/performance/Measurement",
 	"sap/base/security/encodeXML"
 ],
-	function(Plugin, Measurement, encodeXML) {
+	function(Core, Plugin, Measurement, encodeXML) {
 		"use strict";
 
 		var _rawdata = [];
@@ -55,7 +56,7 @@ sap.ui.define([
 		 * With this plugIn the performance measurements are displayed
 		 *
 		 * @extends sap.ui.core.support.Plugin
-		 * @version 1.82.2
+		 * @version 1.98.0
 		 * @private
 		 * @alias sap.ui.core.support.plugins.Performance
 		 */
@@ -98,7 +99,7 @@ sap.ui.define([
 		};
 
 		function initInTools(oSupportStub) {
-			var rm = sap.ui.getCore().createRenderManager();
+			var rm = Core.createRenderManager();
 
 			//create the initial html for the performance tool
 			rm.write(_getPerformanceToolHTML());
@@ -115,7 +116,6 @@ sap.ui.define([
 		}
 
 		function getPerformanceData(oSupportStub) {
-			//var bActive = jQuery.sap.measure.getActive();
 			var aMeasurements = Measurement.getAllMeasurements(true);
 
 			this._oStub.sendEvent(this.getId() + "SetMeasurements", {"measurements": aMeasurements});
@@ -329,6 +329,7 @@ sap.ui.define([
 		}
 
 		function _getUID() {
+			// eslint-disable-next-line no-return-assign
 			return 'uID-' + (_getUID.id !== undefined ? ++_getUID.id : _getUID.id = 0);
 		}
 
@@ -419,10 +420,43 @@ sap.ui.define([
 			return stepsData;
 		}
 
+		/**
+		 * @param {sap.ui.core.RenderManager} rm Render Manager
+		 * @param {Object} step
+		 * @param {string} type - Type is 'duration' or 'time'
+		 * @private
+		 */
+		function _renderSubBarHTML(rm, step, type) {
+			/*
+				step = {
+					time: {
+						_total: 20ms,
+						rendering: 10ms,
+						require: 10ms
+					},
+					duration: {
+						_total: 20ms,
+						rendering: 10ms,
+						require: 10ms
+					}
+				}
+			*/
+
+			Object.keys(step.duration).sort().forEach(function (categoryType) {
+				if (categoryType !== '_total') {
+					var heightInPercent = (step[type][categoryType] / step[type]._total) * 100;
+
+					rm.openStart("div")
+						.class(_getBarClassType(categoryType))
+						.style("height", heightInPercent.toFixed(2) + "%")
+						.openEnd()
+						.close("div");
+				}
+			});
+		}
+
 		function _renderTimelineOverview(data) {
 			var domParent = document.querySelector('#sapUiSupportPerfHeaderTimelineOverview .timeline');
-
-			var HTML = '<ol>';
 			var copiedData = (JSON.parse(JSON.stringify(data)));
 
 			//TODO: optimise this logic to loop only once
@@ -457,68 +491,57 @@ sap.ui.define([
 			allTimeSum = topSumTimeStep.time._total;
 			allDurationSum = topSumDurationStep.duration._total;
 
-			/**
-			 *
-			 * @param {Object} step
-			 * @param {string} type - Type is 'duration' or 'time'
-			 * @param {string} html - html string to add to
-			 * @private
-			 */
-			function __getSubBarHTML(step, type) {
-				/*
-				 step = {
-				 time: {
-				 _total: 20ms,
-				 rendering: 10ms,
-				 require: 10ms
-				 },
-				 duration: {
-				 _total: 20ms,
-				 rendering: 10ms,
-				 require: 10ms
-				 }
-				 }
-				 */
-				var HTML = '';
+			var rm = Core.createRenderManager();
 
-				Object.keys(step.duration).sort().forEach(function (categoryType) {
-					if (categoryType !== '_total') {
-						var heightInPercent = (step[type][categoryType] / step[type]._total) * 100;
-						HTML += '<div class="' + _getBarClassType(categoryType) + '" style="height: ' + heightInPercent.toFixed(2) + '%;"></div>';
-					}
-				});
-
-				return HTML;
-			}
+			rm.openStart("ol").openEnd();
 
 			stepsData.forEach(function (step) {
 				var stepDurationInPercent = Math.ceil((step.duration._total / allDurationSum) * 100);
 				var stepTimeInPercent = Math.ceil((step.time._total / allTimeSum) * 100);
 
-				var stepDurationInPercentInlineStyle = 'height: ' + stepDurationInPercent + '%;';
+				rm.openStart("li").openEnd();
+
+				rm.openStart("div")
+					.class("bars-wrapper")
+					.attr("title", _getTimelineOverViewBarTitle(step.duration._total, step.time._total))
+					.openEnd();
+
+				rm.openStart("div")
+					.class("duration")
+					.style("height", stepDurationInPercent + "%");
+
 				if (stepDurationInPercent > 0) {
-					stepDurationInPercentInlineStyle += ' min-height: 1px;';
+					rm.style("min-height", "1px");
 				}
 
-				var stepTimeInPercentInlineStyle = 'height: ' + stepTimeInPercent + '%;';
+				rm.openEnd();
+
+				_renderSubBarHTML(rm, step, "duration");
+
+				rm.close("div"); // duration
+
+				rm.openStart("div")
+					.class("time")
+					.style("height", stepTimeInPercent + "%");
+
 				if (stepTimeInPercent > 0) {
-					stepTimeInPercentInlineStyle += ' min-height: 1px;';
+					rm.style("min-height", "1px");
 				}
 
-				HTML += '<li>';
-				HTML += '<div class="bars-wrapper" title="' + _getTimelineOverViewBarTitle(step.duration._total, step.time._total) + '">';
-				HTML += '<div class="duration" style="' + stepDurationInPercentInlineStyle + '">';
-				HTML += __getSubBarHTML(step, 'duration');
-				HTML += '</div>';
-				HTML += '<div class="time" style="' + stepTimeInPercentInlineStyle + '">';
-				HTML += __getSubBarHTML(step, 'time');
-				HTML += '</div>';
-				HTML += '</div></li>';
+				rm.openEnd();
+
+				_renderSubBarHTML(rm, step, "time");
+
+				rm.close("div"); // time
+
+				rm.close("div"); // bars-wrapper
+				rm.close("li");
 			});
 
-			HTML += '</ol>';
+			rm.close("ol");
 
-			domParent.innerHTML = HTML;
+			rm.flush(domParent);
+			rm.destroy();
 		}
 
 		/* =============================================================================================================
@@ -526,8 +549,8 @@ sap.ui.define([
 		 ============================================================================================================= */
 
 		function _render() {
-			var HTML = '<ol>';
-			var barInfoHTML = '<ol>';
+			var barRm = Core.createRenderManager();
+			var barInfoRm = Core.createRenderManager();
 
 			//get all data from the filter ui elements
 			var filterOptions = _getFilterOptions();
@@ -536,29 +559,82 @@ sap.ui.define([
 
 			//no data bar
 			if (data.length === 0) {
-				HTML += '<li class="line nodata" data-uid="' + -1 + '"></li>';
-				barInfoHTML += '<li class="line nodata" data-uid="' + -1 + '"><div class="info line">No data</div></li>';
+				barRm.openStart("li")
+					.class("line")
+					.class("nodata")
+					.attr("data-uid", -1)
+					.openEnd()
+					.close("li");
+
+				barInfoRm.openStart("li")
+					.class("line")
+					.class("nodata")
+					.attr("data-uid", -1)
+					.openEnd();
+
+				barInfoRm.openStart("div")
+					.class("info")
+					.class("line")
+					.openEnd()
+					.text("No data")
+					.close("div");
+
+				barInfoRm.close("li");
 			}
 
 			data.forEach(function (item) {
 				var rawItem = _getBarById(item.uid);
-				HTML += '<li data-uid="' + item.uid + '" class="line" title="' + _getBarTitle(rawItem) + '"' + _getBarDataAttributes(rawItem) + '  >';
-				HTML += '<div class="bar ' + _getBarColor(rawItem.duration) + '" style="width: ' + _calculateBarWidth(item.duration) + ' margin-left: ' + _calculateBarOffset(item, filterOptions.filterByTime.start) + '">';
-				HTML += '<div class="sub-bar ' + _getBarColor(rawItem.time) + '" style="width: ' + _calculateBarWidth(item.time) + '"></div>';
-				HTML += '</div>';
-				HTML += '</li>';
+				barRm.openStart("li")
+					.class("line")
+					.attr("data-uid", item.uid)
+					.attr("title", _getBarTitle(rawItem))
+					.attr("data-item-category", rawItem.categories[0])
+					.openEnd();
+
+				barRm.openStart("div")
+					.class("bar")
+					.class(_getBarColor(rawItem.duration))
+					.style("width", _calculateBarWidth(item.duration))
+					.style("margin-left", _calculateBarOffset(item, filterOptions.filterByTime.start))
+					.openEnd();
+
+				barRm.openStart("div")
+					.class("sub-bar")
+					.class(_getBarColor(rawItem.time))
+					.style("width", _calculateBarWidth(item.time))
+					.openEnd()
+					.close("div");
+
+				barRm.close("div"); // bar
+				barRm.close("li");
 
 				//render bar info ==================================================================================
-				barInfoHTML += '<li data-uid="' + item.uid + '" title="' + _getBarTitle(rawItem) + '" class="line ' + _getBarClassType(rawItem.categories[0]) + '" ' + _getBarDataAttributes(rawItem) + '>';
-				barInfoHTML += '<div class="info line">' + _formatInfo(rawItem) + ' (' + (rawItem.time).toFixed(0) + ' ms)</div>';
-				barInfoHTML += '</li>';
+				barInfoRm.openStart("li")
+					.class("line")
+					.class(_getBarClassType(rawItem.categories[0]))
+					.attr("data-uid", item.uid)
+					.attr("title", _getBarTitle(rawItem))
+					.attr("data-item-category", rawItem.categories[0])
+					.openEnd();
+
+				barInfoRm.openStart("div")
+					.class("line")
+					.class("info")
+					.openEnd()
+					.text(_formatInfo(rawItem) + " (" + (rawItem.time).toFixed(0) + " ms)")
+					.close("div");
+
+				barInfoRm.close("li");
 			});
 
-			HTML += '</ol>';
-			barInfoHTML += '</ol>';
+			barRm.close("ol");
+			barInfoRm.close("ol");
 
-			document.querySelector('#sapUiSupportPerfHeaderTimelineBarWrapper').innerHTML = HTML;
-			document.querySelector('#sapUiSupportPerfHeaderTimelineBarInfoWrapper').innerHTML = barInfoHTML;
+			barRm.flush(document.querySelector("#sapUiSupportPerfHeaderTimelineBarWrapper"));
+			barInfoRm.flush(document.querySelector("#sapUiSupportPerfHeaderTimelineBarInfoWrapper"));
+
+			barRm.destroy();
+			barInfoRm.destroy();
 
 			_createTimelineGrid(filterOptions);
 			_filterByCategory(); // Don't change the order, this is applying css styles on the rendered content
@@ -579,7 +655,7 @@ sap.ui.define([
 		}
 
 		function _getBarTitle(bar) {
-			return encodeXML(bar.info + '\nduration: ' + bar.duration.toFixed(2) + ' ms. \ntime: ' + bar.time.toFixed(2) + ' ms. \nstart: ' + bar.start.toFixed(2) + ' ms.\nend: ' + bar.end.toFixed(2) + ' ms.');
+			return bar.info + "\nduration: " + bar.duration.toFixed(2) + " ms. \ntime: " + bar.time.toFixed(2) + " ms. \nstart: " + bar.start.toFixed(2) + " ms.\nend: " + bar.end.toFixed(2) + " ms.";
 		}
 
 		function _formatInfo(bar) {
@@ -589,7 +665,7 @@ sap.ui.define([
 			barInfo = barInfo.substring(barInfo.lastIndexOf('sap.m.'), barInfo.length);
 			barInfo = barInfo.replace('Rendering of ', '');
 
-			return encodeXML(barInfo);
+			return barInfo;
 		}
 
 		function _getBarClassType(category) {
@@ -651,10 +727,6 @@ sap.ui.define([
 			return categories;
 		}
 
-		function _getBarDataAttributes(bar) {
-			return 'data-item-category = ' + bar.categories[0];
-		}
-
 		function _lineHover(e) {
 			var dom = e.srcElement;
 
