@@ -1,6 +1,6 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
@@ -9,15 +9,16 @@ sap.ui.define([
 	"sap/ui/thirdparty/jquery",
 	"sap/ui/base/Object",
 	"sap/ui/dt/Util",
+	"sap/ui/dt/DOMUtil",
 	"sap/ui/core/Element",
 	"sap/ui/core/Component",
 	"sap/base/util/isPlainObject",
 	"sap/ui/core/UIArea"
-],
-function(
+], function(
 	jQuery,
 	BaseObject,
 	Util,
+	DOMUtil,
 	Element,
 	Component,
 	isPlainObject,
@@ -31,7 +32,7 @@ function(
 	 * @class Utility functionality to work with elements, e.g. iterate through aggregations, find parents, ...
 	 *
 	 * @author SAP SE
-	 * @version 1.82.2
+	 * @version 1.98.0
 	 *
 	 * @private
 	 * @static
@@ -55,9 +56,6 @@ function(
 		}, this);
 	};
 
-	/**
-	 *
-	 */
 	ElementUtil.getElementInstance = function(vElement) {
 		if (typeof vElement === "string") {
 			var oElement = sap.ui.getCore().byId(vElement);
@@ -66,9 +64,6 @@ function(
 		return vElement;
 	};
 
-	/**
-	 *
-	 */
 	ElementUtil.hasAncestor = function(oElement, oAncestor) {
 		oAncestor = this.fixComponentContainerElement(oAncestor);
 		var oFixedParent;
@@ -86,17 +81,11 @@ function(
 		return !!oElement;
 	};
 
-	/**
-	 *
-	 */
 	ElementUtil.getClosestElementForNode = function(oNode) {
 		var $ClosestElement = jQuery(oNode).closest("[data-sap-ui]");
 		return $ClosestElement.length ? sap.ui.getCore().byId($ClosestElement.attr("data-sap-ui")) : undefined;
 	};
 
-	/**
-	 *
-	 */
 	ElementUtil.fixComponentParent = function(oElement) {
 		if (BaseObject.isA(oElement, "sap.ui.core.UIComponent")) {
 			var oComponentContainer = oElement.oContainer;
@@ -108,9 +97,6 @@ function(
 		}
 	};
 
-	/**
-	 *
-	 */
 	ElementUtil.fixComponentContainerElement = function(oElement) {
 		if (BaseObject.isA(oElement, "sap.ui.core.ComponentContainer")) {
 			// This happens when the compontentContainer has not been rendered yet
@@ -122,9 +108,6 @@ function(
 		return oElement;
 	};
 
-	/**
-	 *
-	 */
 	ElementUtil.getDomRef = function(oElement) {
 		if (oElement) {
 			var oDomRef;
@@ -138,9 +121,6 @@ function(
 		}
 	};
 
-	/**
-	 *
-	 */
 	ElementUtil.findAllSiblingsInContainer = function(oElement, oContainer) {
 		var oParent = oElement && oElement.getParent();
 		if (!oParent) {
@@ -173,11 +153,11 @@ function(
 			}
 
 			return {
-				get : sGetter,
-				add : oAggregationMetadata._sMutator,
-				remove : oAggregationMetadata._sRemoveMutator,
-				insert : oAggregationMetadata._sInsertMutator,
-				removeAll : oAggregationMetadata._sRemoveAllMutator
+				get: sGetter,
+				add: oAggregationMetadata._sMutator,
+				remove: oAggregationMetadata._sRemoveMutator,
+				insert: oAggregationMetadata._sInsertMutator,
+				removeAll: oAggregationMetadata._sRemoveAllMutator
 			};
 		}
 		return {};
@@ -193,7 +173,7 @@ function(
 			oValue = oElement.getAggregation(sAggregationName);
 		}
 		// ATTENTION:
-		// under some unknown circumstances the return oValue looks like an Array but jQuery.isArray() returned
+		// under some unknown circumstances the return oValue looks like an Array but Array.isArray() returned
 		// undefined => false
 		// that is why we use array ducktyping with a null check!
 		// reproducible with Windows and Chrome (currently 35), when creating a project and opening WYSIWYG editor
@@ -209,9 +189,6 @@ function(
 		return this.getAggregation(oParent, sAggregationName).indexOf(oElement);
 	};
 
-	/**
-	 *
-	 */
 	ElementUtil.addAggregation = function(oParent, sAggregationName, oElement) {
 		if (this.hasAncestor(oParent, oElement)) {
 			throw new Error("Trying to add an element to itself or its successors");
@@ -224,9 +201,6 @@ function(
 		}
 	};
 
-	/**
-	 *
-	 */
 	ElementUtil.removeAggregation = function(oParent, sAggregationName, oElement, bSuppressInvalidate) {
 		var sAggregationRemoveMutator = this.getAggregationAccessors(oParent, sAggregationName).remove;
 		if (sAggregationRemoveMutator) {
@@ -236,9 +210,6 @@ function(
 		}
 	};
 
-	/**
-	 *
-	 */
 	ElementUtil.insertAggregation = function(oParent, sAggregationName, oElement, iIndex) {
 		if (this.hasAncestor(oParent, oElement)) {
 			throw new Error("Trying to add an element to itself or its successors");
@@ -263,9 +234,6 @@ function(
 		}
 	};
 
-	/**
-	 *
-	 */
 	ElementUtil.isValidForAggregation = function(oParent, sAggregationName, oElement) {
 		var oAggregationMetadata = oParent.getMetadata().getAggregation(sAggregationName);
 
@@ -296,11 +264,11 @@ function(
 		var oAssociationMetadata = oMetadata.getAssociation(sAggregationName);
 		if (oAssociationMetadata) {
 			return {
-				get : oAssociationMetadata._sGetter,
-				add : oAssociationMetadata._sMutator,
-				remove : oAssociationMetadata._sRemoveMutator,
-				insert : oAssociationMetadata._sInsertMutator,
-				removeAll : oAssociationMetadata._sRemoveAllMutator
+				get: oAssociationMetadata._sGetter,
+				add: oAssociationMetadata._sMutator,
+				remove: oAssociationMetadata._sRemoveMutator,
+				insert: oAssociationMetadata._sInsertMutator,
+				removeAll: oAssociationMetadata._sRemoveAllMutator
 			};
 		}
 		return {};
@@ -327,9 +295,6 @@ function(
 			}, this);
 	};
 
-	/**
-	 *
-	 */
 	ElementUtil.hasInterface = function(oElement, sInterface) {
 		var aInterfaces = oElement.getMetadata().getInterfaces();
 		return aInterfaces.indexOf(sInterface) !== -1;
@@ -355,6 +320,27 @@ function(
 		return true;
 	};
 
+	/**
+	 * Checks whether specified Element is a direct template clone (e.g. the list items of a sap.m.ListItem)
+	 *
+	 * @param {sap.ui.base.Object} oObject - Object for validation
+	 * @returns {boolean} <code>true</code> if object is a direct clone of the template
+	 */
+	 ElementUtil.isElementDirectTemplateChild = function (oObject) {
+		var mLocationInTemplate = ElementUtil.getAggregationInformation(oObject);
+
+		if (mLocationInTemplate.templateId) {
+			var sTemplateId = ElementUtil.extractTemplateId(mLocationInTemplate);
+
+			// If the stack only has one element, this element is a direct child of the template aggregation
+			if (sTemplateId && mLocationInTemplate.stack.length === 1) {
+				return true;
+			}
+		}
+
+		return false;
+	};
+
 	/**
 	 * Checks whether specified Element is a valid ManagedObject. The allowed objects must be
 	 * descendants of sap.ui.core.Element or sap.ui.core.Component classes.
@@ -464,10 +450,10 @@ function(
 	 */
 
 	/**
-	 * Returns the element id and the aggregation name of the bound control for an Overlay which is part of an aggregation binding
-	 * The check is done recursively
-	 * @param  {sap.ui.dt.ElementOverlay} oElementOverlay Overlay being checked
-	 * @return {AggregationBindingStack}  Returns the {@link sap.ui.dt.ElementUtil.AggregationBindingStack} object
+	 * Returns the element ID and the aggregation name of the bound control for an element which is part of an aggregation binding.
+	 * The check is done recursively.
+	 * @param  {sap.ui.core.Element} oElement - Element being checked
+	 * @return {AggregationBindingStack} {@link sap.ui.dt.ElementUtil.AggregationBindingStack} object
 	 */
 	ElementUtil.getAggregationInformation = function(oElement) {
 		var aStack = [];
@@ -521,6 +507,17 @@ function(
 			);
 	};
 
+	/**
+	 * Getter for binding template if available.
+	 * @param {sap.ui.base.ManagedObject} oElement - Element to be checked for binding info with template attached
+	 * @param {string} sAggregationName - Aggregation name required to check binding info for this one aggregation
+	 * @returns {sap.ui.base.ManagedObject} Aggregation binding template for the given element and aggregation name
+	 */
+	ElementUtil.getAggregationBindingTemplate = function (oElement, sAggregationName) {
+		var oBinding = oElement && oElement.getBindingInfo(sAggregationName);
+		return oBinding && oBinding.template;
+	};
+
 	/**
 	 * Decrements passed index value by 1, if the source and target overlays for move belong to the same container and source index is less than the target index.
 	 * To compensate the fact that the lower source index is also removed during move.
@@ -537,5 +534,54 @@ function(
 		return iTargetIndex;
 	};
 
+	/**
+	 * Checks if an aggregation is valid for an element being moved
+	 *
+	 * @param {sap.ui.dt.AggregationOverlay} oAggregationOverlay - Aggregation overlay to be checked for target zone
+	 * @param {sap.ui.dt.ElementOverlay} oMovedOverlay - Overlay being moved
+	 * @param {boolean} bOverlayNotInDom - Flag defining if overlay is not in DOM
+	 * @returns {Promise.<boolean>} Resolved promise with <code>true</code> if the aggregation overlay is a valid target zone for the overlay
+	 */
+	 ElementUtil.checkTargetZone = function(oAggregationOverlay, oMovedOverlay, bOverlayNotInDom) {
+		var oGeometry = oAggregationOverlay.getGeometry();
+		var bGeometryVisible = oGeometry && oGeometry.size.height > 0 && oGeometry.size.width > 0;
+		var oParentElement = oAggregationOverlay.getElement();
+
+		var oMovedElement = oMovedOverlay.getElement();
+		var sAggregationName = oAggregationOverlay.getAggregationName();
+		if (!oMovedElement || !ElementUtil.isValidForAggregation(oParentElement, sAggregationName, oMovedElement)) {
+			return Promise.resolve(false);
+		}
+
+		// checks related to visibility
+		function fnCheckAggregationOverlayVisibility(oAggregationOverlay, oParentElement) {
+			// this function can get called on overlay registration, when there are no overlays in dom yet. In this case, DOMUtil.isVisible is always false.
+			var oAggregationOverlayDomRef = oAggregationOverlay.getDomRef();
+			var bAggregationOverlayVisibility = DOMUtil.isVisible(oAggregationOverlayDomRef);
+
+			// if there is no aggregation overlay domRef available the further check for domRef of the corresponding element is not required
+			if (!oAggregationOverlayDomRef) {
+				return bAggregationOverlayVisibility;
+			}
+			// additional check for corresponding element DomRef visibiltiy required for target zone checks during navigation mode.
+			// during navigation mode the domRef of valid overlays is given and the offsetWidth is 0. Therefor we need to check the visibility of the corresponding element additionally
+			var oParentElementDomRef = oParentElement && oParentElement.getDomRef && oParentElement.getDomRef();
+			var bAggregationElementVisibility = oParentElementDomRef ? DOMUtil.isVisible(oParentElementDomRef) : true;
+			return bAggregationOverlayVisibility || bAggregationElementVisibility;
+		}
+
+		if (
+			(bOverlayNotInDom && !bGeometryVisible)
+			|| !bOverlayNotInDom && !fnCheckAggregationOverlayVisibility(oAggregationOverlay, oParentElement)
+			|| !(oParentElement && oParentElement.getVisible && oParentElement.getVisible())
+			// an aggregation can still have visible = true even if it has been removed from its parent
+			|| !oParentElement.getParent()
+		) {
+			return Promise.resolve(false);
+		}
+
+		return Promise.resolve(true);
+	};
+
 	return ElementUtil;
 }, /* bExport= */true);
\ No newline at end of file
