@@ -1,15 +1,14 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
 sap.ui.define([
-	"sap/ui/fl/registry/ChangeRegistry",
+	"sap/ui/fl/initial/_internal/changeHandlers/ChangeHandlerStorage",
 	"sap/ui/fl/Utils",
-	"sap/ui/fl/LayerUtils",
+	"sap/ui/fl/Layer",
 	"sap/ui/fl/Change",
-	"sap/ui/fl/Variant",
 	"sap/ui/fl/ChangePersistenceFactory",
 	"sap/ui/fl/write/_internal/Versions",
 	"sap/ui/fl/apply/_internal/changes/Applier",
@@ -20,11 +19,10 @@ sap.ui.define([
 	"sap/ui/core/Component",
 	"sap/base/Log"
 ], function(
-	ChangeRegistry,
+	ChangeHandlerStorage,
 	Utils,
-	LayerUtils,
+	Layer,
 	Change,
-	Variant,
 	ChangePersistenceFactory,
 	Versions,
 	Applier,
@@ -37,23 +35,61 @@ sap.ui.define([
 ) {
 	"use strict";
 
+	function revertChangesAndUpdateVariantModel(oComponent, bSkipUrlUpdate, aChanges) {
+		return Promise.resolve()
+			.then(function () {
+				if (aChanges.length !== 0) {
+					// Always revert changes in reverse order
+					aChanges.reverse();
+					return Reverter.revertMultipleChanges(aChanges, {
+						appComponent: oComponent,
+						modifier: JsControlTreeModifier,
+						flexController: this
+					});
+				}
+			}.bind(this))
+			.then(function () {
+				if (oComponent) {
+					var oModel = oComponent.getModel(Utils.VARIANT_MODEL_NAME);
+					if (oModel) {
+						aChanges.forEach(function (oChange) {
+							var sVariantReference = oChange.getVariantReference();
+							if (sVariantReference) {
+								oModel.removeChange(oChange);
+							}
+						});
+
+						// Temporary fix, parameters generally should not be removed
+						if (!bSkipUrlUpdate) {
+							URLHandler.update({
+								parameters: [],
+								updateURL: true,
+								updateHashEntry: true,
+								model: oModel
+							});
+						}
+					}
+				}
+
+				return aChanges;
+			});
+	}
+
 	/**
 	 * Retrieves changes (LabelChange, etc.) for an sap.ui.core.mvc.View and applies these changes
 	 *
 	 * @param {string} sComponentName - Component name the flexibility controller is responsible for
-	 * @param {string} sAppVersion - Current version of the application
 	 * @constructor
 	 * @class
 	 * @alias sap.ui.fl.FlexController
 	 * @experimental Since 1.27.0
 	 * @author SAP SE
-	 * @version 1.82.2
+	 * @version 1.98.0
 	 */
-	var FlexController = function(sComponentName, sAppVersion) {
+	var FlexController = function(sComponentName) {
 		this._oChangePersistence = undefined;
 		this._sComponentName = sComponentName || "";
-		this._sAppVersion = sAppVersion || Utils.DEFAULT_APP_VERSION;
-		if (this._sComponentName && this._sAppVersion) {
+		if (this._sComponentName) {
 			this._createChangePersistence();
 		}
 	};
@@ -68,16 +104,6 @@ sap.ui.define([
 		return this._sComponentName;
 	};
 
-	/**
-	 * Returns the application version of the FlexController
-	 *
-	 * @returns {String} Application version
-	 * @public
-	 */
-	FlexController.prototype.getAppVersion = function() {
-		return this._sAppVersion;
-	};
-
 	/**
 	 * Sets the variant switch promise
 	 *
@@ -119,13 +145,6 @@ sap.ui.define([
 		oChangeSpecificData.reference = this.getComponentName(); //in this case the component name can also be the value of sap-app-id
 		oChangeSpecificData.packageName = "$TMP"; // first a flex change is always local, until all changes of a component are made transportable
 
-		// fallback in case no application descriptor is available (e.g. during unit testing)
-		oChangeSpecificData.validAppVersions = Utils.getValidAppVersions({
-			appVersion: this.getAppVersion(),
-			developerMode: oChangeSpecificData.developerMode,
-			scenario: oChangeSpecificData.scenario
-		});
-
 		oChangeFileContent = Change.createInitialFileContent(oChangeSpecificData);
 		oChange = new Change(oChangeFileContent);
 
@@ -145,13 +164,15 @@ sap.ui.define([
 		return this._getChangeHandler(oChange, sControlType, oControl, JsControlTreeModifier)
 			.then(function(oChangeHandler) {
 				if (oChangeHandler) {
-					oChangeHandler.completeChangeContent(oChange, oChangeSpecificData, {
+					return oChangeHandler.completeChangeContent(oChange, oChangeSpecificData, {
 						modifier: JsControlTreeModifier,
-						appComponent: oAppComponent
+						appComponent: oAppComponent,
+						view: Utils.getViewForControl(oControl)
 					});
-				} else {
-					throw new Error("Change handler could not be retrieved for change " + JSON.stringify(oChangeSpecificData) + ".");
 				}
+				throw new Error("Change handler could not be retrieved for change " + JSON.stringify(oChangeSpecificData) + ".");
+			})
+			.then(function () {
 				return oChange;
 			})
 			.catch(function(oError) {
@@ -249,6 +270,10 @@ sap.ui.define([
 				// so the propagation listener should ignore this change once
 				oChange._ignoreOnce = true;
 				this.addPreparedChange(oChange, oAppComponent);
+
+				// TODO this should go into an API that applied multiple changes, that does not yet exist
+				// all changes should be queued to apply before the first change gets applied
+				oChange.setQueuedForApply();
 				return oChange;
 			}.bind(this));
 	};
@@ -281,7 +306,7 @@ sap.ui.define([
 	 * @see {ChangePersistence#saveDirtyChanges};
 	 *
 	 * If the given change is already in the dirty changes and
-	 * has pending action 'NEW' it will be removed, assuming,
+	 * has the 'NEW' state it will be removed, assuming,
 	 * it has just been created in the current session;
 	 *
 	 * Otherwise it will be marked for deletion.
@@ -297,34 +322,30 @@ sap.ui.define([
 	};
 
 	/**
-	 * Creates a new change and applies it immediately.
+	 * Must ONLY be used together with FlexController.prototype.addChange.
+	 * Applies a change that was previously created, added to the map and queued.
 	 *
-	 * @param {object} oChangeSpecificData The data specific to the change, e.g. the new label for a RenameField change
+	 * @param {object} oChange Change Instance
 	 * @param {sap.ui.core.Control} oControl The control where the change will be applied to
 	 * @returns {Promise} Returns Promise resolving to the change that was created and applied successfully or a Promise reject with the error object
 	 * @public
 	 */
-	FlexController.prototype.createAndApplyChange = function(oChangeSpecificData, oControl) {
-		var oChange;
-		return this.addChange(oChangeSpecificData, oControl)
-			.then(function(oAddedChange) {
-				oChange = oAddedChange;
-				var mPropertyBag = {
-					modifier: JsControlTreeModifier,
-					appComponent: Utils.getAppComponentForControl(oControl),
-					view: Utils.getViewForControl(oControl)
-				};
-				oChange.setQueuedForApply();
-				return Applier.applyChangeOnControl(oChange, oControl, mPropertyBag);
-			})
-			.then(function(oReturn) {
-				if (!oReturn.success) {
-					var oException = oReturn.error || new Error("The change could not be applied.");
-					this._oChangePersistence.deleteChange(oChange, true);
-					throw oException;
-				}
-				return oChange;
-			}.bind(this));
+	FlexController.prototype.applyChange = function(oChange, oControl) {
+		var mPropertyBag = {
+			modifier: JsControlTreeModifier,
+			appComponent: Utils.getAppComponentForControl(oControl),
+			view: Utils.getViewForControl(oControl)
+		};
+
+		return Applier.applyChangeOnControl(oChange, oControl, mPropertyBag)
+		.then(function(oReturn) {
+			if (!oReturn.success) {
+				var oException = oReturn.error || new Error("The change could not be applied.");
+				this._oChangePersistence.deleteChange(oChange, true);
+				throw oException;
+			}
+			return oChange;
+		}.bind(this));
 	};
 
 	function checkDependencies(oChange, mDependencies, mChanges, oAppComponent, aRelevantChanges) {
@@ -359,18 +380,14 @@ sap.ui.define([
 	/**
 	 * Resolves with a promise after all the changes for all controls that are passed have been processed.
 	 *
-	 * @param {sap.ui.fl.Selector[]} vSelectors The control or an array of controls whose changes are being waited for
-	 * @returns {Promise} Returns a promise when all changes on the controls have been processed
+	 * @param {object[]} aSelectors - An array containing an object with {@link sap.ui.fl.Selector} and further configuration
+	 * @param {sap.ui.fl.Selector} aSelectors.selector - A {@link sap.ui.fl.Selector}
+	 * @param {string[]} [aSelectors.changeTypes] - An array containing the change types that will be considered. If empty no filtering will be done
+	 * @returns {Promise} Resolves when all changes on the controls have been processed
 	 */
-	FlexController.prototype.waitForChangesToBeApplied = function(vSelectors) {
-		var aSelectors;
-		if (Array.isArray(vSelectors)) {
-			aSelectors = vSelectors;
-		} else {
-			aSelectors = [vSelectors];
-		}
-		var aPromises = aSelectors.map(function(vSelector) {
-			return this._waitForChangesToBeApplied(vSelector);
+	FlexController.prototype.waitForChangesToBeApplied = function(aSelectors) {
+		var aPromises = aSelectors.map(function(mSelector) {
+			return this._waitForChangesToBeApplied(mSelector);
 		}.bind(this));
 		return Promise.all(aPromises)
 			.then(function() {
@@ -378,23 +395,33 @@ sap.ui.define([
 				return undefined;
 			});
 	};
+
 	/**
-	 * Resolves with a Promise after all the changes for this control have been processed.
+	 * Resolves with a Promise after all relevant changes for this control have been processed.
 	 *
-	 * @param {sap.ui.fl.Selector} vSelector The control whose changes are being waited for
-	 * @returns {Promise} Returns a promise when all changes on the control have been processed
+	 * @param {object} mPropertyBag - Object with control and list of change types
+	 * @param {sap.ui.fl.Selector} mPropertyBag.selector - A {@link sap.ui.fl.Selector}
+	 * @param {string[]} mPropertyBag.changeTypes - An array containing the change types that should be considered
+	 * @returns {Promise} Resolves when all changes on the control have been processed
 	 */
-	FlexController.prototype._waitForChangesToBeApplied = function(vSelector) {
-		var oControl = vSelector.id && sap.ui.getCore().byId(vSelector.id) || vSelector;
+	FlexController.prototype._waitForChangesToBeApplied = function(mPropertyBag) {
+		function filterChanges(oChange) {
+			return !oChange.isCurrentProcessFinished()
+			&& (mPropertyBag.changeTypes.length === 0 || mPropertyBag.changeTypes.includes(oChange.getChangeType()));
+		}
+
+		mPropertyBag.changeTypes = mPropertyBag.changeTypes || [];
+		var oControl = mPropertyBag.selector.id && sap.ui.getCore().byId(mPropertyBag.selector.id) || mPropertyBag.selector;
 		var mChangesMap = this._oChangePersistence.getChangesMapForComponent();
 		var aPromises = [];
 		var mDependencies = Object.assign({}, mChangesMap.mDependencies);
 		var mChanges = mChangesMap.mChanges;
 		var aChangesForControl = mChanges[oControl.getId()] || [];
-		var aNotYetProcessedChanges = aChangesForControl.filter(function(oChange) {
-			return !oChange.isCurrentProcessFinished();
-		}, this);
-		var oAppComponent = vSelector.appComponent || Utils.getAppComponentForControl(oControl);
+
+		// filter out already applied changes and, if given, filter by change type
+		var aNotYetProcessedChanges = aChangesForControl.filter(filterChanges);
+
+		var oAppComponent = mPropertyBag.selector.appComponent || Utils.getAppComponentForControl(oControl);
 		var aRelevantChanges = [];
 		aNotYetProcessedChanges.forEach(function(oChange) {
 			var aChanges = checkDependencies(oChange, mDependencies, mChangesMap.mChanges, oAppComponent, []);
@@ -416,17 +443,35 @@ sap.ui.define([
 		return Promise.all(aPromises);
 	};
 
+	FlexController.prototype._removeOtherLayerChanges = function(oAppComponent, sLayer, bRemoveOtherLayerChanges) {
+		if (bRemoveOtherLayerChanges && sLayer) {
+			var aLayersToReset = Object.values(Layer).filter(function(sLayerToCheck) {
+				return sLayerToCheck !== sLayer;
+			});
+			return this.removeDirtyChanges(aLayersToReset, oAppComponent, undefined, undefined, undefined, true);
+		}
+		return Promise.resolve();
+	};
+
 	/**
 	 * Saves all changes of a persistence instance.
 	 *
 	 * @param {sap.ui.core.UIComponent} [oAppComponent] - AppComponent instance
 	 * @param {boolean} [bSkipUpdateCache=false] - Indicates the cache should not be updated
 	 * @param {boolean} [bDraft=false] - Indicates if changes should be written as a draft
+	 * @param {string} [sLayer] - Layer for which the changes should be saved
+	 * @param {boolean} [bRemoveOtherLayerChanges=false] - Whether to remove changes on other layers before saving
 	 * @returns {Promise} resolving with an array of responses or rejecting with the first error
 	 * @public
 	 */
-	FlexController.prototype.saveAll = function(oAppComponent, bSkipUpdateCache, bDraft) {
-		return this._oChangePersistence.saveDirtyChanges(oAppComponent, bSkipUpdateCache, undefined, bDraft)
+	FlexController.prototype.saveAll = function(oAppComponent, bSkipUpdateCache, bDraft, sLayer, bRemoveOtherLayerChanges) {
+		var sParentVersion = bDraft ? Versions.getVersionsModel({
+			reference: Utils.normalizeReference(this._sComponentName),
+			layer: Layer.CUSTOMER // only the customer layer has draft active
+		}).getProperty("/persistedVersion") : undefined;
+
+		return this._removeOtherLayerChanges(oAppComponent, sLayer, bRemoveOtherLayerChanges)
+			.then(this._oChangePersistence.saveDirtyChanges.bind(this._oChangePersistence, oAppComponent, bSkipUpdateCache, undefined, sParentVersion))
 			.then(function(oResult) {
 				if (bDraft && oResult && oResult.response) {
 					var vChangeDefinition = oResult.response;
@@ -472,32 +517,19 @@ sap.ui.define([
 	};
 
 	/**
-	 * Retrieves the <code>sap.ui.fl.registry.ChangeRegistryItem</code> for the given change and control
+	 * Retrieves the change handler for the given change and control
 	 *
 	 * @param {sap.ui.fl.Change} oChange - Change instance
 	 * @param {string} sControlType - Mame of the ui5 control type i.e. sap.m.Button
 	 * @param {sap.ui.core.Control} oControl - Control for which to retrieve the change handler
 	 * @param {sap.ui.core.util.reflection.BaseTreeModifier} oModifier - Control tree modifier
-	 * @returns {Promise.<sap.ui.fl.changeHandler.Base>} Change handler or undefined if not found, wrapped in a promise.
+	 * @returns {Promise} Change handler or undefined if not found, wrapped in a promise.
 	 * @private
 	 */
 	FlexController.prototype._getChangeHandler = function(oChange, sControlType, oControl, oModifier) {
 		var sChangeType = oChange.getChangeType();
 		var sLayer = oChange.getLayer();
-		return this._getChangeRegistry().getChangeHandler(sChangeType, sControlType, oControl, oModifier, sLayer);
-	};
-
-	/**
-	 * Returns the change registry
-	 *
-	 * @returns {sap.ui.fl.registry.ChangeRegistry} Instance of the change registry
-	 * @private
-	 */
-	FlexController.prototype._getChangeRegistry = function() {
-		var oInstance = ChangeRegistry.getInstance();
-		// make sure to use the most current flex settings that have been retrieved during processView
-		oInstance.initSettings();
-		return oInstance;
+		return ChangeHandlerStorage.getChangeHandler(sChangeType, sControlType, oControl, oModifier, sLayer);
 	};
 
 	/**
@@ -527,34 +559,6 @@ sap.ui.define([
 		return this._oChangePersistence.checkForOpenDependenciesForControl(oSelector, oComponent);
 	};
 
-	/**
-	 * Determines if an active personalization - user specific changes or variants - for the flexibility reference
-	 * of the controller instance (<code>this._sComponentName</code>) is in place.
-	 *
-	 * @param {map} [mPropertyBag] - Contains additional data needed for checking personalization, will be passed to FlexController.getComponentChanges
-	 * @param {string} [mPropertyBag.upToLayer=currentLayer] - layer to compare to which it is checked if changes exist
-	 * @param {boolean} [mPropertyBag.ignoreMaxLayerParameter] - Indicates that personalization shall be checked without layer filtering
-	 * @returns {Promise} Resolves with a boolean; true if a personalization change made using SAPUI5 flexibility services is active in the application
-	 * @public
-	 */
-	FlexController.prototype.hasHigherLayerChanges = function(mPropertyBag) {
-		mPropertyBag = mPropertyBag || {};
-		var sCurrentLayer = mPropertyBag.upToLayer || LayerUtils.getCurrentLayer(false);
-		//Always include smart variants when checking personalization
-		mPropertyBag.includeVariants = true;
-		//Also control variant changes are important
-		mPropertyBag.includeCtrlVariants = true;
-		return this.getComponentChanges(mPropertyBag).then(function(vChanges) {
-			var bHasHigherLayerChanges = vChanges === this._oChangePersistence.HIGHER_LAYER_CHANGES_EXIST
-				|| vChanges.some(function(oChange) {
-					//check layer (needs inverse layer filtering compared to max-layer)
-					return LayerUtils.compareAgainstCurrentLayer(oChange.getLayer(), sCurrentLayer) > 0;
-				});
-
-			return !!bHasHigherLayerChanges;
-		}.bind(this));
-	};
-
 	/**
 	 * Creates a new instance of sap.ui.fl.Persistence based on the current component and caches the instance in a private member
 	 *
@@ -562,7 +566,7 @@ sap.ui.define([
 	 * @private
 	 */
 	FlexController.prototype._createChangePersistence = function() {
-		this._oChangePersistence = ChangePersistenceFactory.getChangePersistenceForComponent(this.getComponentName(), this.getAppVersion());
+		this._oChangePersistence = ChangePersistenceFactory.getChangePersistenceForComponent(this.getComponentName());
 		return this._oChangePersistence;
 	};
 
@@ -581,59 +585,24 @@ sap.ui.define([
 	 */
 	FlexController.prototype.resetChanges = function(sLayer, sGenerator, oComponent, aSelectorIds, aChangeTypes) {
 		return this._oChangePersistence.resetChanges(sLayer, sGenerator, aSelectorIds, aChangeTypes)
-			.then(function(aChanges) {
-				if (aChanges.length !== 0) {
-					return Reverter.revertMultipleChanges(aChanges, {
-						appComponent: oComponent,
-						modifier: JsControlTreeModifier,
-						flexController: this
-					});
-				}
-			}.bind(this))
-			.then(function() {
-				if (oComponent) {
-					var oModel = oComponent.getModel(Utils.VARIANT_MODEL_NAME);
-					if (oModel) {
-						URLHandler.update({
-							parameters: [],
-							updateURL: true,
-							updateHashEntry: true,
-							model: oModel
-						});
-					}
-				}
-			});
+			.then(revertChangesAndUpdateVariantModel.bind(this, oComponent, undefined));
 	};
 
 	/**
-	 * Discard changes on the server. Still used by OVP
+	 * Removes unsaved changes and reverts these. If no control is provided, all dirty changes are removed.
 	 *
-	 * @param {array} aChanges array of {sap.ui.fl.Change} to be discarded
-	 * @param {boolean} bDiscardPersonalization - (optional) specifies that only changes in the USER layer are discarded
-	 * @returns {Promise} Promise that resolves without parameters
+	 * @param {string|string[]} vLayer - Layer or multiple layers for which changes shall be deleted
+	 * @param {sap.ui.core.Component} oComponent - Component instance
+	 * @param {sap.ui.core.Control} [oControl] - Control for which the changes should be removed
+	 * @param {string} [sGenerator] - Generator of changes (optional)
+	 * @param {string[]} [aChangeTypes] - Types of changes (optional)
+	 * @param {boolean} [bSkipUrlUpdate] - Whether to skip soft reload during variant model update
+	 *
+	 * @returns {Promise} Promise that resolves after the deletion took place
 	 */
-	FlexController.prototype.discardChanges = function(aChanges, bDiscardPersonalization) {
-		var sActiveLayer = LayerUtils.getCurrentLayer(!!bDiscardPersonalization);
-		var iIndex = 0;
-		var iLength;
-		var oChange;
-
-		iLength = aChanges.length;
-		while (iIndex < aChanges.length) {
-			oChange = aChanges[iIndex];
-			if (oChange && oChange.getLayer && oChange.getLayer() === sActiveLayer) {
-				this._oChangePersistence.deleteChange(oChange);
-			}
-			//the array may change during this loop, so if the length is the same, the index must increase
-			//otherwise the same index should be used (same index but different element in the array)
-			if (iLength === aChanges.length) {
-				iIndex++;
-			} else {
-				iLength = aChanges.length;
-			}
-		}
-
-		return this._oChangePersistence.saveDirtyChanges();
+	FlexController.prototype.removeDirtyChanges = function(vLayer, oComponent, oControl, sGenerator, aChangeTypes, bSkipUrlUpdate) {
+		return this._oChangePersistence.removeDirtyChanges(vLayer, oComponent, oControl, sGenerator, aChangeTypes)
+		.then(revertChangesAndUpdateVariantModel.bind(this, oComponent, bSkipUrlUpdate));
 	};
 
 	/**
@@ -686,7 +655,6 @@ sap.ui.define([
 	 */
 	FlexController.prototype.getResetAndPublishInfo = function(mPropertyBag) {
 		mPropertyBag.reference = this._sComponentName;
-		mPropertyBag.appVersion = this._sAppVersion;
 		return this._oChangePersistence.getResetAndPublishInfo(mPropertyBag);
 	};
 
