@@ -1,53 +1,46 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
 sap.ui.define([
-	"sap/ui/thirdparty/jquery",
-	"sap/ui/core/Component",
-	"sap/ui/core/util/reflection/BaseTreeModifier",
-	"sap/ui/thirdparty/hasher",
-	"sap/base/Log",
-	"sap/base/util/UriParameters",
-	"sap/base/util/uid",
 	"sap/base/strings/formatMessage",
+	"sap/base/util/isPlainObject",
+	"sap/base/util/uid",
+	"sap/base/util/UriParameters",
+	"sap/base/Log",
+	"sap/ui/base/SyncPromise",
 	"sap/ui/base/ManagedObject",
-	"sap/ui/core/mvc/View"
-],
-function(
-	jQuery,
-	Component,
-	BaseTreeModifier,
-	hasher,
-	Log,
-	UriParameters,
-	uid,
+	"sap/ui/core/util/reflection/BaseTreeModifier",
+	"sap/ui/core/Component",
+	"sap/ui/thirdparty/hasher",
+	"sap/ui/thirdparty/jquery"
+], function(
 	formatMessage,
+	isPlainObject,
+	uid,
+	UriParameters,
+	Log,
+	SyncPromise,
 	ManagedObject,
-	View
+	BaseTreeModifier,
+	Component,
+	hasher,
+	jQuery
 ) {
 	"use strict";
 
-	function appendComponentToString(sComponentName) {
-		if (sComponentName.length > 0 && sComponentName.indexOf(".Component") < 0) {
-			sComponentName += ".Component";
-		}
-		return sComponentName;
-	}
-
 	/**
 	 * Provides utility functions for the SAPUI5 flexibility library
 	 *
 	 * @namespace
 	 * @alias sap.ui.fl.Utils
 	 * @author SAP SE
-	 * @version 1.82.2
+	 * @version 1.98.0
 	 * @experimental Since 1.25.0
 	 */
 	var Utils = {
-		DEFAULT_APP_VERSION: "DEFAULT_APP_VERSION",
 		APP_ID_AT_DESIGN_TIME: "${pro" + "ject.art" + "ifactId}", //avoid replaced by content of sap.ui.fl placeholder at build steps
 		VARIANT_MODEL_NAME: "$FlexVariants",
 
@@ -65,85 +58,6 @@ function(
 			Log[sLogType](sLogMessage, sCallStack || "");
 		},
 
-		/**
-		 * Tries to retrieve the xsrf token from the controls OData Model. Returns empty string if retrieval failed.
-		 *
-		 * @param {sap.ui.core.Control} oControl - SAPUI5 control
-		 * @returns {String} XSRF Token
-		 * @public
-		 * @function
-		 * @name sap.ui.fl.Utils.getXSRFTokenFromControl
-		 */
-		getXSRFTokenFromControl: function(oControl) {
-			var oModel;
-			if (!oControl) {
-				return "";
-			}
-
-			// Get Model
-			if (oControl && typeof oControl.getModel === "function") {
-				oModel = oControl.getModel();
-				return Utils._getXSRFTokenFromModel(oModel);
-			}
-			return "";
-		},
-
-		/**
-		 * Returns XSRF Token from the Odata Model. Returns empty string if retrieval failed
-		 *
-		 * @param {sap.ui.model.odata.ODataModel} oModel - OData Model
-		 * @returns {String} XSRF Token
-		 * @private
-		 */
-		_getXSRFTokenFromModel: function(oModel) {
-			var mHeaders;
-			if (!oModel) {
-				return "";
-			}
-			if (typeof oModel.getHeaders === "function") {
-				mHeaders = oModel.getHeaders();
-				if (mHeaders) {
-					return mHeaders["x-csrf-token"];
-				}
-			}
-			return "";
-		},
-
-		/**
-		 * Returns the class name of the component the given control belongs to.
-		 *
-		 * @param {sap.ui.core.Control} oControl - SAPUI5 control
-		 *
-		 * @returns {String} The component class name, ending with ".Component"
-		 * @see sap.ui.core.Component.getOwnerIdFor
-		 * @public
-		 * @function
-		 * @name sap.ui.fl.Utils.getComponentClassName
-		 */
-		getComponentClassName: function(oControl) {
-			var oAppComponent;
-
-			// determine UI5 component out of given control
-			if (oControl) {
-				// always return the app component
-				oAppComponent = this.getAppComponentForControl(oControl);
-
-				// check if the component is an application variant and assigned an application descriptor then use this as reference
-				if (oAppComponent) {
-					var sVariantId = this._getComponentStartUpParameter(oAppComponent, "sap-app-id");
-					if (sVariantId) {
-						return sVariantId;
-					}
-
-					if (oAppComponent.getManifestEntry("sap.ui5") && oAppComponent.getManifestEntry("sap.ui5").appVariantId) {
-						return oAppComponent.getManifestEntry("sap.ui5").appVariantId;
-					}
-				}
-			}
-
-			return Utils.getComponentName(oAppComponent);
-		},
-
 		isVariantByStartupParameter: function(oControl) {
 			// determine UI5 component out of given control
 			if (oControl) {
@@ -156,22 +70,6 @@ function(
 			return false;
 		},
 
-		/**
-		 * Returns the class name of the application component owning the passed component or the component name itself if
-		 * this is already an application component.
-		 *
-		 * @param {sap.ui.core.Component} oComponent - SAPUI5 component
-		 * @returns {String} The component class name, ending with ".Component"
-		 * @see sap.ui.core.Component.getOwnerIdFor
-		 * @public
-		 * @since 1.40
-		 * @function
-		 * @name getAppComponentClassNameForComponent
-		 */
-		getAppComponentClassNameForComponent: function(oComponent) {
-			return Utils.getComponentClassName(oComponent);
-		},
-
 		/**
 		 * Returns the appDescriptor of the component for the given control
 		 *
@@ -202,37 +100,6 @@ function(
 			return oManifest;
 		},
 
-		/**
-		 * Returns the siteId of a component
-		 *
-		 * @param {sap.ui.core.Control} oControl - SAPUI5 control
-		 * @returns {string} siteId - that represent the found siteId
-		 * @public
-		 * @function
-		 * @name sap.ui.fl.Utils.getSiteId
-		 */
-		getSiteId: function(oControl) {
-			var sSiteId = null;
-			var oAppComponent = null;
-
-			// determine UI5 component out of given control
-			if (oControl) {
-				oAppComponent = this.getAppComponentForControl(oControl);
-
-				// determine siteId from ComponentData
-				if (oAppComponent) {
-					//Workaround for back-end check: isApplicationPermitted
-					//As long as FLP does not know about appDescriptorId we have to pass siteID and applicationID.
-					//With startUpParameter hcpApplicationId we will get a concatenation of “siteId:applicationId”
-
-					//sSiteId = this._getComponentStartUpParameter(oComponent, "scopeId");
-					sSiteId = this._getComponentStartUpParameter(oAppComponent, "hcpApplicationId");
-				}
-			}
-
-			return sSiteId;
-		},
-
 		/**
 		 * Returns the siteId of a component when you already have the component data.
 		 *
@@ -249,40 +116,35 @@ function(
 		/**
 		 * Indicates if the property value represents a binding
 		 *
-		 * @param {object} sPropertyValue - Property value
+		 * @param {object} vPropertyValue - Property value
 		 * @returns {boolean} true if value represents a binding
 		 * @public
 		 * @function
 		 * @name sap.ui.fl.Utils.isBinding
 		 */
-		isBinding: function(sPropertyValue) {
-			var bIsBinding = false;
-			if (sPropertyValue && typeof sPropertyValue === "string" && sPropertyValue.substring(0, 1) === "{" && sPropertyValue.slice(-1) === "}") {
-				bIsBinding = true;
-			}
-			return bIsBinding;
-		},
-
-		/**
-		 * Indicates if the current application is a variant of an existing one
-		 *
-		 * @param {sap.ui.core.Control} oControl - SAPUI5 control
-		 * @returns {boolean} true if it's an application variant
-		 * @public
-		 * @function
-		 * @name sap.ui.fl.Utils.isApplicationVariant
-		 */
-		isApplicationVariant: function(oControl) {
-			var sFlexReference = Utils.getComponentClassName(oControl);
-			var oAppComponent = Utils.getAppComponentForControl(oControl);
-			var sComponentName = Utils.getComponentName(oAppComponent);
-			return sFlexReference !== sComponentName;
+		isBinding: function(vPropertyValue) {
+			return (
+				(
+					typeof vPropertyValue === "string"
+					&& !!ManagedObject.bindingParser(vPropertyValue)
+				)
+				|| (
+					isPlainObject(vPropertyValue)
+					&& (
+						(
+							vPropertyValue.hasOwnProperty("path")
+							|| vPropertyValue.hasOwnProperty("parts")
+						)
+						&& !vPropertyValue.hasOwnProperty("ui5object")
+					)
+				)
+			);
 		},
 
 		/**
 		 * Determines if the passed change is related to control variants.
 		 * @see sap.ui.fl.variants.VariantManagement
-		 * @params {sap.ui.fl.Change} oChange Change object
+		 * @param {sap.ui.fl.Change} oChange Change object
 		 * @returns {boolean} If the passed change is a variant management change
 		 * @public
 		 * @name sap.ui.fl.Utils.isChangeRelatedToVariants
@@ -322,21 +184,6 @@ function(
 			}
 		},
 
-		/**
-		 * Gets the component name for a component instance.
-		 *
-		 * @param {sap.ui.core.Component} oComponent component instance
-		 * @returns {String} component name
-		 * @public
-		 */
-		getComponentName: function(oComponent) {
-			var sComponentName = "";
-			if (oComponent) {
-				sComponentName = oComponent.getMetadata().getName();
-			}
-			return appendComponentToString(sComponentName);
-		},
-
 		/**
 		 * Gets the component instance for a component ID.
 		 *
@@ -408,8 +255,7 @@ function(
 			var oAppComponent = this.getAppComponentForControl(oControl);
 			var oManifest = oAppComponent.getManifest();
 			return {
-				name: this.getAppIdFromManifest(oManifest),
-				version: this.getAppVersionFromManifest(oManifest)
+				name: this.getAppIdFromManifest(oManifest)
 			};
 		},
 
@@ -498,41 +344,6 @@ function(
 			}
 		},
 
-		hasControlAncestorWithId: function(sControlId, sAncestorControlId) {
-			var oControl;
-
-			if (sControlId === sAncestorControlId) {
-				return true;
-			}
-
-			oControl = sap.ui.getCore().byId(sControlId);
-			while (oControl) {
-				if (oControl.getId() === sAncestorControlId) {
-					return true;
-				}
-
-				if (typeof oControl.getParent === "function") {
-					oControl = oControl.getParent();
-				} else {
-					return false;
-				}
-			}
-
-			return false;
-		},
-
-		/**
-		 * Checks whether the provided control is a view
-		 *
-		 * @param {sap.ui.core.Control} oControl - SAPUI5 control
-		 * @returns {Boolean} Flag
-		 * @see sap.ui.core.Component.getOwnerIdFor
-		 * @private
-		 */
-		_isView: function(oControl) {
-			return oControl instanceof View;
-		},
-
 		/**
 		 * Returns OwnerId of the control
 		 *
@@ -705,70 +516,22 @@ function(
 		},
 
 		/**
-		 * Returns a map of technical parameters for the passed component.
-		 *
-		 * @param  {object} oComponent - Component instance used to get the technical parameters
-		 * @returns {object|undefined} Returns the requested technical parameter object or undefined if unavailable
-		 */
-		getTechnicalParametersForComponent: function(oComponent) {
-			return oComponent
-				&& oComponent.getComponentData
-				&& oComponent.getComponentData()
-				&& oComponent.getComponentData().technicalParameters;
-		},
-
-		/**
-		 * Returns URL hash when ushell container is available
+		 * Returns URL hash when ushell container is available synchronously.
 		 *
+		 * @param  {sap.ushell.services.URLParsing} oURLParsingService - The Unified Shell's internal URL parsing service
 		 * @returns {object} Returns the parsed URL hash object or an empty object if ushell container is not available
 		 */
-		getParsedURLHash: function() {
-			return Utils.ifUShellContainerThen(function(aServices) {
-				var oParsedHash = aServices[0].parseShellHash(hasher.getHash());
-				return oParsedHash || {};
-			}, ["URLParsing"]) || {};
-		},
-
-		/**
-		 * Calls the passed function with the desired ushell services, if ushell container is available
-		 *
-		 * @param {function} fnCallBack - Callback function
-		 * @param {string[]} aServiceNames - Array of ushell service names
-		 * @returns {any|undefined} Returns the Value from the callback
-		 */
-		ifUShellContainerThen: function(fnCallBack, aServiceNames) {
-			var oUShellContainer = Utils.getUshellContainer();
-			if (oUShellContainer) {
-				var aServices = aServiceNames.map(function(sServiceName) {
-					return oUShellContainer.getService(sServiceName);
-				});
-				return fnCallBack(aServices);
+		getParsedURLHash: function(oURLParsingService) {
+			if (oURLParsingService) {
+				return oURLParsingService.parseShellHash(hasher.getHash()) || {};
 			}
-		},
-
-		/**
-		 * Checks the SAPUI5 debug settings to determine whether all or at least the <code>sap.ui.fl</code> library is debugged.
-		 *
-		 * @returns {boolean} Returns a flag if the flexibility library is debugged
-		 * @public
-		 */
-		isDebugEnabled: function() {
-			var oUriParams = this._getUriParameters();
-			var sDebugParameters = oUriParams.get("sap-ui-debug") || "";
-
-			// true if SAPUI5 is in complete debug mode
-			if (sap.ui.getCore().getConfiguration().getDebug() || sDebugParameters === "true") {
-				return true;
-			}
-
-			var aDebugParameters = sDebugParameters.split(",");
-			return aDebugParameters.indexOf("sap/ui/fl") !== -1 || aDebugParameters.indexOf("sap/ui/fl/") !== -1;
+			return {};
 		},
 
 		/**
 		 * Returns the value of the specified url parameter of the current url
 		 *
-		 * @param {String} sParameterName - Name of the url parameter
+		 * @param {string} sParameterName - Name of the url parameter
 		 * @returns {string} url parameter
 		 * @private
 		 */
@@ -777,9 +540,9 @@ function(
 		},
 
 		/**
-		 * Returns ushell container if available
+		 * Returns UShell container if available
 		 *
-		 * @returns {object|undefined} Returns ushell container object if available or undefined
+		 * @returns {object|undefined} Returns UShell container object if available or undefined
 		 */
 		getUshellContainer: function() {
 			return sap.ushell && sap.ushell.Container;
@@ -793,7 +556,11 @@ function(
 			return sFileName;
 		},
 
-		createNamespace: function(oPropertyBag, sSubfolder) {
+		createNamespace: function(oPropertyBag, sFileType) {
+			var sSubfolder = "changes";
+			if (sFileType === "ctrl_variant") {
+				sSubfolder = "variants";
+			}
 			var sReferenceName = oPropertyBag.reference.replace('.Component', '');
 			var sNamespace = 'apps/' + sReferenceName + "/" + sSubfolder + "/";
 			return sNamespace;
@@ -847,47 +614,9 @@ function(
 			return sRootNamespace;
 		},
 
-
-		/** Generates a ValidAppVersions object for changes and variants; Depending on the parameters passed a 'to' field is included.
-		 *
-		 * @param {map} mPropertyBag
-		 * @param {string} mPropertyBag.appVersion Version to be filled into the validAppVersions object fields
-		 * @param {boolean} mPropertyBag.developerMode Flag if the creation of the object takes place in the developer mode
-		 * @param {sap.ui.fl.Scenario} mPropertyBag.scenario Depending on the scenario a 'to' field must be filled
-		 * @returns {{creation: string, from: string, to: (string|undefined)}}
-		 */
-		getValidAppVersions: function(mPropertyBag) {
-			var sAppVersion = mPropertyBag.appVersion;
-			var bDeveloperMode = mPropertyBag.developerMode;
-			var sScenario = mPropertyBag.scenario;
-			var oValidAppVersions = {
-				creation: sAppVersion,
-				from: sAppVersion
-			};
-			if (this._isValidAppVersionToRequired(sAppVersion, bDeveloperMode, sScenario)) {
-				oValidAppVersions.to = sAppVersion;
-			}
-			return oValidAppVersions;
-		},
-
-		/** Determines if a 'to' field is required in a validAppVersions object.
-		 *
-		 * @param sAppVersion
-		 * @param bDeveloperMode
-		 * @param sScenario
-		 * @returns {boolean}
-		 * @private
-		 */
-		_isValidAppVersionToRequired: function(sAppVersion, bDeveloperMode, sScenario) {
-			return !!sAppVersion
-				&& !!bDeveloperMode
-				&& sScenario !== sap.ui.fl.Scenario.AdaptationProject
-				&& sScenario !== sap.ui.fl.Scenario.AppVariant;
-		},
-
 		/** Returns the type of "sap.app" from the manifest object passed.
 		 * @param {sap.ui.core.Manifest} oManifest - Manifest object
-		 * @returns {string | undefined} Manifest object's "type" property for "sap.app" entry
+		 * @returns {string|undefined} Manifest object's <code>type</code> property for <code>sap.app</code> entry
 		 * @private
 		 */
 		_getComponentTypeFromManifest: function(oManifest) {
@@ -895,8 +624,8 @@ function(
 		},
 
 		/** Returns the type of "sap.app" from the manifest object passed.
-		 * @param {sap.ui.core.Manifest} oRawManifest - raw manifest object
-		 * @returns {string | undefined} Manifest object's "type" property for "sap.app" entry
+		 * @param {sap.ui.core.Manifest} oManifest - Raw manifest object
+		 * @returns {string|undefined} Manifest object's <code>type</code> property for <code>sap.app</code> entry
 		 * @private
 		 */
 		_getComponentTypeFromRawManifest: function(oManifest) {
@@ -932,36 +661,10 @@ function(
 			return oComponent instanceof Component && Utils._getComponentTypeFromManifest(oComponent.getManifestObject()) === "component";
 		},
 
-		/**
-		 * Returns the reference of a component, according to the following logic:
-		 * First appVariantId, if not, componentName + ".Component", if not appId + ".Component" (unless they already have ".Component" at the end).
-		 *
-		 * @param {object} oManifest - Manifest of the component
-		 * @returns {string} flex reference
-		 * @public
-		 */
-		getFlexReference: function(oManifest) {
-			if (oManifest) {
-				if (oManifest.getEntry("sap.ui5")) {
-					if (oManifest.getEntry("sap.ui5").appVariantId) {
-						return oManifest.getEntry("sap.ui5").appVariantId;
-					}
-					if (oManifest.getEntry("sap.ui5").componentName) {
-						return appendComponentToString(oManifest.getEntry("sap.ui5").componentName);
-					}
-				}
-				if (oManifest.getEntry("sap.app") && oManifest.getEntry("sap.app").id) {
-					return appendComponentToString(Utils.getAppIdFromManifest(oManifest));
-				}
-			}
-			Log.warning("No Manifest received.");
-			return "";
-		},
-
 		/**
 		 * Returns the descriptor Id, which is always the reference for descriptor changes
 		 *
-		 * @param {object} oManifest - Manifest of the component
+		 * @param {object|sap.ui.core.Manifest} oManifest - Manifest of the component
 		 * @returns {string} Version of application if it is available in the manifest, otherwise an empty string
 		 * @public
 		 */
@@ -969,8 +672,13 @@ function(
 			if (oManifest) {
 				var oSapApp = (oManifest.getEntry) ? oManifest.getEntry("sap.app") : oManifest["sap.app"];
 				var sAppId = oSapApp && oSapApp.id;
-				if (sAppId === Utils.APP_ID_AT_DESIGN_TIME && oManifest.getComponentName) {
-					sAppId = oManifest.getComponentName();
+				if (sAppId === Utils.APP_ID_AT_DESIGN_TIME) {
+					if (oManifest.getComponentName) {
+						return oManifest.getComponentName();
+					}
+					if (oManifest.name) {
+						return oManifest.name;
+					}
 				}
 				return sAppId;
 			}
@@ -978,90 +686,6 @@ function(
 			throw new Error("No Manifest received, descriptor changes are not possible");
 		},
 
-		/**
-		 * Returns the semantic application version using format: "major.minor.patch".
-		 *
-		 * @param {object} oManifest - Manifest of the component
-		 * @returns {string} Version of application if it is available in the manifest, otherwise an empty string
-		 * @public
-		 */
-		getAppVersionFromManifest: function(oManifest) {
-			var sVersion = "";
-			if (oManifest) {
-				var oSapApp = (oManifest.getEntry) ? oManifest.getEntry("sap.app") : oManifest["sap.app"];
-				if (oSapApp && oSapApp.applicationVersion && oSapApp.applicationVersion.version) {
-					sVersion = oSapApp.applicationVersion.version;
-				}
-			} else {
-				Log.warning("No Manifest received.");
-			}
-			return sVersion;
-		},
-
-		/**
-		 * Returns the uri of the main service specified in the app manifest
-		 *
-		 * @param {object} oManifest - Manifest of the component
-		 * @returns {string} Returns the uri if the manifest is available, otherwise an empty string
-		 * @public
-		 */
-		getODataServiceUriFromManifest: function(oManifest) {
-			var sUri = "";
-			if (oManifest) {
-				var oSapApp = (oManifest.getEntry) ? oManifest.getEntry("sap.app") : oManifest["sap.app"];
-				if (oSapApp && oSapApp.dataSources && oSapApp.dataSources.mainService && oSapApp.dataSources.mainService.uri) {
-					sUri = oSapApp.dataSources.mainService.uri;
-				}
-			} else {
-				Log.warning("No Manifest received.");
-			}
-			return sUri;
-		},
-
-		/**
-		 * Checks if the application version has the correct format: "major.minor.patch".
-		 *
-		 * @param {string} sVersion - Version of application
-		 * @returns {boolean} true if the format is correct, otherwise false
-		 * @public
-		 */
-		isCorrectAppVersionFormat: function(sVersion) {
-			// remove all whitespaces
-			sVersion = sVersion.replace(/\s/g, "");
-
-			// get version without snapshot
-			// we need to run the regex twice to avoid that version 1-2-3-SNAPSHOT will result in version 1.
-			var oRegexp1 = /\b\d{1,5}(.\d{1,5}){0,2}/g;
-			var oRegexp2 = /\b\d{1,5}(\.\d{1,5}){0,2}/g;
-			var nLength = sVersion.match(oRegexp1) ? sVersion.match(oRegexp1)[0].length : 0;
-			var nLenghtWithDot = sVersion.match(oRegexp2) ? sVersion.match(oRegexp2)[0].length : 0;
-
-			if (nLenghtWithDot < 1 || nLenghtWithDot !== nLength) {
-				return false;
-			}
-
-			//if the character after the version is also a number or a dot, it should also be a format error
-			if (nLenghtWithDot && sVersion !== sVersion.substr(0, nLenghtWithDot)) {
-				var cNextCharacter = sVersion.substr(nLenghtWithDot, 1);
-				var oRegexp = /^[0-9.]$/;
-				if (oRegexp.test(cNextCharacter)) {
-					return false;
-				}
-			}
-
-			// split into number-parts and check if there are max. three parts
-			var aVersionParts = sVersion.substr(0, nLenghtWithDot).split(".");
-			if (aVersionParts.length > 3) {
-				return false;
-			}
-
-			// 5 digits maximum per part
-			if (!aVersionParts.every(function(sPart) {return sPart.length <= 5;})) {
-				return false;
-			}
-			return true;
-		},
-
 		/**
 		 * Checks if an object is in an array or not and returns the index or -1
 		 *
@@ -1119,8 +743,9 @@ function(
 			}
 			var fnPromise = aPromiseQueue.shift();
 			if (typeof fnPromise === "function") {
+				var vResult;
 				try {
-					var vResult = fnPromise();
+					vResult = fnPromise();
 				} catch (e) {
 					vResult = Promise.reject(e);
 				}
@@ -1170,8 +795,7 @@ function(
 			var fnResolveOrReject = function(vParam, fn) {
 				try {
 					var vResolve = fn(vParam, Utils.FakePromise.fakePromiseIdentifier);
-					if (vResolve instanceof Promise ||
-						vResolve instanceof Utils.FakePromise) {
+					if (SyncPromise.isThenable(vResolve)) {
 						return vResolve;
 					}
 					return new Utils.FakePromise(vResolve);
@@ -1182,24 +806,27 @@ function(
 			};
 
 			/**
-			 * <code>then</code> function as for promise (es6), but without a rejection handler.
-			 * @param {function} fn - Resolve handler
+			 * <code>then</code> function as for promise (es6)
+			 * @param {function} fnSuccess - Resolve handler
+			 * @param {function} fnError - Reject handler
 			 * @returns {sap.ui.fl.Utils.FakePromise|Promise} <code>FakePromise</code> if no promise is returned by the resolve handler
 			 * @public
 			 */
-			Utils.FakePromise.prototype.then = function(fn) {
+			Utils.FakePromise.prototype.then = function(fnSuccess, fnError) {
 				if (!this.bContinueWithFakePromise) {
-					return Promise.resolve(fn(this.vValue));
+					return Promise.resolve(fnSuccess(this.vValue));
 				}
 
 				if (!this.vError) {
-					return fnResolveOrReject(this.vValue, fn);
+					return fnResolveOrReject(this.vValue, fnSuccess);
+				} else if (fnError) {
+					return fnResolveOrReject(this.vError, fnError);
 				}
 				return this;
 			};
 
 			/**
-			 * <code>catch</code> function as for promise (es6), but without a rejection handler.
+			 * <code>catch</code> function as for promise (es6)
 			 * @param {function} fn - Rejection handler
 			 * @returns {sap.ui.fl.Utils.FakePromise|Promise} <code>FakePromise</code> if no promise is returned by the rejection handler
 			 * @public
@@ -1248,6 +875,11 @@ function(
 		 */
 		requireAsync: function(sModuleName) {
 			//TODO: get rid of require async as soon as sap.ui.require has learned Promises as return value
+			var oModule = sap.ui.require(sModuleName);
+			// apply directly if class was already loaded
+			if (oModule) {
+				return Promise.resolve(oModule);
+			}
 			return new Promise(function(fnResolve, fnReject) {
 				sap.ui.require([sModuleName], function(oModule) {
 					fnResolve(oModule);
@@ -1259,7 +891,7 @@ function(
 
 		/**
 		 * Normalize reference, delete .Component at the end of the incoming string.
-		 * @param {string} reference
+		 * @param {string} sReference - Flex reference
 		 * @returns {string} Returns reference without .Component
 		 */
 		normalizeReference: function(sReference) {
@@ -1272,10 +904,11 @@ function(
 		 * @param  {string} sParameters - The URL parameters to be modified
 		 * @param  {string} sParameterName - The parameter name that can be removed or added
 		 * @param  {string} sParameterValue - The parameter value of the parameter name that can be removed or added
+		 * @param  {sap.ushell.services.URLParsing} oURLParsingService - The Unified Shell's internal URL parsing service
 		 * @returns {string} The modified URL
 		 */
-		handleUrlParameters: function(sParameters, sParameterName, sParameterValue) {
-			if (this.hasParameterAndValue(sParameterName, sParameterValue)) {
+		handleUrlParameters: function(sParameters, sParameterName, sParameterValue, oURLParsingService) {
+			if (this.hasParameterAndValue(sParameterName, sParameterValue, oURLParsingService)) {
 				if (sParameters.startsWith("?")) {
 					sParameters = sParameters.substr(1, sParameters.length);
 				}
@@ -1297,22 +930,23 @@ function(
 		 *
 		 * @param  {string} sParameterName - The parameter name to be checked
 		 * @param  {string} sParameterValue - The parameter value to be checked
+		 * @param  {sap.ushell.services.URLParsing} oURLParsingService - The Unified Shell's internal URL parsing service
 		 * @returns {boolean} <code>true</code> if the parameter and the given value are in the URL
 		 */
-		hasParameterAndValue: function(sParameterName, sParameterValue) {
-			return this.getParameter(sParameterName) === sParameterValue;
+		hasParameterAndValue: function(sParameterName, sParameterValue, oURLParsingService) {
+			return this.getParameter(sParameterName, oURLParsingService) === sParameterValue;
 		},
 
 		/**
 		 * Checks if the passed parameter name is contained in the URL and returns its value.
 		 *
 		 * @param  {string} sParameterName - The parameter name to be checked
+		 * @param  {sap.ushell.services.URLParsing} oURLParsingService - The Unified Shell's internal URL parsing service
 		 * @returns {string} The value of the given parameter or undefined
 		 */
-		getParameter: function (sParameterName) {
-			var oUshellContainer = this.getUshellContainer();
-			if (oUshellContainer) {
-				var mParsedHash = this.getParsedURLHash();
+		getParameter: function (sParameterName, oURLParsingService) {
+			if (oURLParsingService) {
+				var mParsedHash = Utils.getParsedURLHash(oURLParsingService);
 				return mParsedHash.params &&
 					mParsedHash.params[sParameterName] &&
 					mParsedHash.params[sParameterName][0];
@@ -1322,7 +956,89 @@ function(
 				return false;
 			}
 			return oUriParams.get(sParameterName);
+		},
+
+		/**
+		 * Searches in the control metadata for the aggregation defintion
+		 * @param {sap.ui.base.ManagedObject|Element} oControl - Control which has the aggregation
+		 * @param {string} sAggregationName - Aggregation name
+		 * @returns {object} Aggregation metadata
+		 */
+		findAggregation: function(oControl, sAggregationName) {
+			if (oControl) {
+				if (oControl.getMetadata) {
+					var oMetadata = oControl.getMetadata();
+					var oAggregations = oMetadata.getAllAggregations();
+					if (oAggregations) {
+						return oAggregations[sAggregationName];
+					}
+				}
+			}
+			return undefined;
+		},
+
+		/**
+		 * Returns aggregation content for the given aggregation name.
+		 * @param {sap.ui.base.ManagedObject|Element} oParent - Control which has the aggregation
+		 * @param {string} sAggregationName - Aggregation name
+		 * @returns {sap.ui.base.ManagedObject[]|Element[]} Aggregation content
+		 */
+		getAggregation: function (oParent, sAggregationName) {
+			var oAggregation = Utils.findAggregation(oParent, sAggregationName);
+			if (oAggregation) {
+				return oParent[oAggregation._sGetter]();
+			}
+			return undefined;
+		},
+
+		/**
+		 * Returns property value.
+		 * @param {sap.ui.base.ManagedObject|Element} oControl - Control representation
+		 * @param {string} sPropertyName - Property name
+		 * @returns {any} Value of the property
+		 */
+		getProperty: function (oControl, sPropertyName) {
+			var oMetadata = oControl.getMetadata().getPropertyLikeSetting(sPropertyName);
+			if (oMetadata) {
+				var sPropertyGetter = oMetadata._sGetter;
+				return oControl[sPropertyGetter]();
+			}
+			return undefined;
+		},
+
+		/**
+		 * Returns a Promise resolving with the requested Unified Shell service if available
+		 *
+		 * @param {string} sServiceName UShell service name (e.g. "URLParsing")
+		 * @returns {Promise<object|undefined>} Returns UShell service if available or undefined
+		 */
+		 getUShellService: function(sServiceName) {
+			if (sServiceName) {
+				var oUShellContainer = this.getUshellContainer();
+				if (oUShellContainer) {
+					return oUShellContainer.getServiceAsync(sServiceName);
+				}
+			}
+			return Promise.resolve();
+		},
+
+		/**
+		 * Gets the requested UShell Services from Ushell container, if container is available.
+		 * @param {array} aServiceNames - List of service names
+		 * @returns {Promise<object>} Resolves to an object with the requested ushell services
+		 */
+		getUShellServices: function (aServiceNames) {
+			var aServicePromises = aServiceNames.map(function (sServiceName) {
+				return this.getUShellService(sServiceName);
+			}.bind(this));
+			return Promise.all(aServicePromises).then(function (aServices) {
+				return aServiceNames.reduce(function (mServices, sService, iIndex) {
+					mServices[sService] = aServices && aServices[iIndex];
+					return mServices;
+				}, {});
+			});
 		}
+
 	};
 	return Utils;
 }, true);
