@@ -1,6 +1,6 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
@@ -19,6 +19,7 @@ sap.ui.define([
 	 * @param {object} [oSelector] Selector to calculate the ID for the control that is created
 	 * @param {string} [oSelector.id] Control ID targeted by the change
 	 * @param {boolean} [oSelector.isLocalId] <code>true</code> if the ID within the selector is a local ID or a global ID
+	 * @returns {Promise} Promise resolving with the created IFrame
 	 * @ui5-restricted sap.ui.fl
 	 */
 	return function (oChange, mPropertyBag, oSelector) {
@@ -32,7 +33,10 @@ sap.ui.define([
 			mIFrameSettings[sIFrameProperty] = vValue;
 			mIFrameSettings._settings[sIFrameProperty] = vValue;
 		});
-		var oIFrame = oModifier.createControl("sap.ui.fl.util.IFrame", oComponent, oView, oSelector, mIFrameSettings, false);
-		return oIFrame;
+
+		return Promise.resolve()
+			.then(function() {
+				return oModifier.createControl("sap.ui.fl.util.IFrame", oComponent, oView, oSelector, mIFrameSettings, false);
+			});
 	};
 });
