@@ -1,6 +1,6 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
@@ -21,6 +21,9 @@ sap.ui.define([
 		addToChangesMap: function(mProperties, sUniqueKey, oChange) {
 			if (!mProperties[sUniqueKey]) {
 				mProperties[sUniqueKey] = [oChange];
+				oChange.condenserState = "select";
+			} else {
+				oChange.condenserState = "delete";
 			}
 		}
 	};
