@@ -1,12 +1,12 @@
 /*
  * ! OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
 sap.ui.define([
 	"sap/base/util/merge",
-	"sap/ui/fl/write/_internal/connectors/ObjectStorageConnector"
+	"sap/ui/fl/write/api/connectors/ObjectStorageConnector"
 ], function(
 	merge,
 	ObjectStorageConnector
@@ -23,8 +23,17 @@ sap.ui.define([
 	 * @ui5-restricted sap.ui.fl.write._internal.Storage
 	 */
 	var SessionStorageConnector = merge({}, ObjectStorageConnector, /** @lends sap.ui.fl.write._internal.connectors.SessionStorageConnector */ {
-		oStorage: window.sessionStorage
+		storage: window.sessionStorage
 	});
 
+	SessionStorageConnector.loadFeatures = function() {
+		return ObjectStorageConnector.loadFeatures.apply(this, arguments).then(function(oFeatures) {
+			return merge({
+				isPublicLayerAvailable: true,
+				isVariantAdaptationEnabled: true
+			}, oFeatures);
+		});
+	};
+
 	return SessionStorageConnector;
 });
