@@ -1,6 +1,6 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
@@ -12,15 +12,20 @@ sap.ui.define(["./BaseContentRenderer"], function (BaseContentRenderer) {
 	 * @author SAP SE
 	 * @namespace
 	 */
-	var AnalyticalContentRenderer = BaseContentRenderer.extend("sap.ui.integration.cards.AnalyticalContentRenderer");
+	var AnalyticalContentRenderer = BaseContentRenderer.extend("sap.ui.integration.cards.AnalyticalContentRenderer", {
+		apiVersion: 2,
+		MIN_ANALYTICAL_CONTENT_HEIGHT: "14rem"
+	});
 
 	/**
 	 * @override
 	 */
 	AnalyticalContentRenderer.getMinHeight = function (oConfiguration, oContent) {
-		var MIN_ANALYTICAL_CONTENT_HEIGHT = "14rem";
+		if (oConfiguration.minHeight) {
+			return oConfiguration.minHeight;
+		}
 
-		return MIN_ANALYTICAL_CONTENT_HEIGHT;
+		return AnalyticalContentRenderer.MIN_ANALYTICAL_CONTENT_HEIGHT;
 	};
 
 	return AnalyticalContentRenderer;
