@@ -1,6 +1,6 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
@@ -29,7 +29,7 @@ sap.ui.define([], function () {
 			oRM.style("width", oControl.getWidth());
 		}
 
-		oControl.getGridLayoutConfiguration().renderSingleGridLayout(oRM);
+		oControl.getGridLayoutConfiguration().addGridStyles(oRM);
 
 		oRM.openEnd();
 
