@@ -1,6 +1,6 @@
 /*
  * ! OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 sap.ui.define([], function () {
@@ -18,17 +18,15 @@ sap.ui.define([], function () {
 	var ChartSettings = {
 
 		showPanel: function (oControl, sP13nType, oSource, aProperties) {
-			ChartSettings["showP13n" + sP13nType](oControl, oSource);
+			ChartSettings["showUI" + sP13nType](oControl, oSource);
 		},
 
-		showP13nChart: function (oControl, oSource) {
-			var oAdaptationController = oControl.getAdaptationController();
-			oAdaptationController.showP13n(oSource, "Item");
+		showUIChart: function (oControl, oSource) {
+			oControl.getEngine().uimanager.show(oControl, "Item");
 		},
 
-		showP13nSort: function(oControl, oSource){
-			var oAdaptationController = oControl.getAdaptationController();
-			oAdaptationController.showP13n(oSource, "Sort");
+		showUISort: function(oControl, oSource){
+			oControl.getEngine().uimanager.show(oControl, "Sort");
 		}
 
 	};
