@@ -1,25 +1,29 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
 */
 sap.ui.define([
 	'sap/ui/base/Object',
 	'sap/ui/model/Filter',
+	"sap/ui/model/FilterOperator",
 	'sap/ui/model/ParseException',
-	'sap/ui/Device',
 	'sap/base/Log',
 	'sap/base/util/ObjectPath',
+	'sap/base/util/merge',
+	'sap/base/util/deepEqual',
 	'./Condition',
 	'sap/ui/mdc/enum/ConditionValidated',
-	"sap/base/strings/escapeRegExp"
+	'sap/base/strings/escapeRegExp'
 ], function(
 		BaseObject,
 		Filter,
+		FilterOperator,
 		ParseException,
-		Device,
 		Log,
 		ObjectPath,
+		merge,
+		deepEqual,
 		Condition,
 		ConditionValidated,
 		escapeRegExp
@@ -33,52 +37,58 @@ sap.ui.define([
 		});
 
 		/**
+		 * @class
 		 * Creates an <code>sap.ui.mdc.condition.Operator</code> object.
-		 * This is used in the <code>FilterField</code> control to define which filter operators are supported.
+		 * This is used in the {@link sap.ui.mdc.FilterField FilterField} control to define which filter operators are supported.
 		 *
 		 * If a function or property is initial, the default implementation is used.
 		 *
 		 * @extends sap.ui.base.Object
-		 * @param {object} [oConfiguration] Properties of the operator
-		 * @param {string} [oConfiguration.name] Name of the operator used in the condition
-		 * @param {string} [oConfiguration.filterOperator] The operator's default filter operator that is created as defined in <code>sap.ui.model.FilterOperator</code>
-		 * @param {string} [oConfiguration.tokenParse] The string representation of the regular expression that is used by the operator to parse a value
+		 * @param {object} oConfiguration Properties of the operator
+		 * @param {string} oConfiguration.name Name of the operator used in the condition
+		 * @param {string} oConfiguration.filterOperator The operator's default filter operator that is created as defined in {@link sap.ui.model.FilterOperator FilterOperator}
+		 * @param {string} oConfiguration.tokenParse The string representation of the regular expression that is used by the operator to parse a value
 		 *                 to eliminate the operator and get the data string. A placeholder that refers to the translated tokenText can be used. <code>#tokenText#</code> refers to the
 		 *                 <code>oConfiguration.tokenText</code> property if given.
-		 * @param {string} [oConfiguration.tokenFormat] The string representation that is used by the operator to format a value
+		 * @param {string} oConfiguration.tokenFormat The string representation that is used by the operator to format a value
 		 *                 into an output string. For the value placeholder <code>{0}</code> and <code>{1}</code> are used.
 		 *                 A placeholder that refers to the translated tokenText can be used. <code>#tokenText#</code> refers to the <code>oConfiguration.tokenText</code> property if given.
-		 * @param {string[]} [oConfiguration.valueTypes] Array of type to be used. The length of the array defines the number of values that
-		 *                 need to be entered with the operator.
-		 *                 If set to Operator.ValueType.Self the <code>Type</code> of the <code>Field</code> or <code>FilterField</code> using the <code>Operator</code> is used.
-		 *                 If set to Operator.ValueType.Static a simple string type is used to display static text.
-		 *                 If set to a name of a data type an instance of this data type will be used.
+		 * @param {string[]|object[]} oConfiguration.valueTypes Array of type to be used. The length of the array defines the number of values that
+		 *                 need to be entered with the operator.<br>
+		 *                 If set to <code>Operator.ValueType.Self</code> the <code>Type</code> of the <code>Field</code> or <code>FilterField</code> using the <code>Operator</code> is used.<br>
+		 *                 If set to <code>Operator.ValueType.SelfNoParse</code> same as <code>Operator.ValueType.Self</code>, except that the input value parsing will not be called.<br>
+		 *                 If set to <code>Operator.ValueType.Static</code> a simple string type is used to display static text.<br>
+		 *                 If set to a name of a data type an instance of this data type will be used.<br>
 		 *                 If set to an object with the properties <code>name</code>, <code>formatOptions</code> and <code>constraints</code>
-		 *                 an instance of the corresponding data type will be used.
-		 * @param {string[]} [oConfiguration.paramTypes] Array of type parameters //TODO
-		 * @param {string} [oConfiguration.longText] String representation of the operator as a long text.
+		 *                 an instance of the corresponding data type will be used. The type given via <code>name</code> must be required by the application.<br>
+		 * @param {string[]} [oConfiguration.paramTypes] Array of type parameters regexp
+		 * @param {string} [oConfiguration.longText] String representation of the operator as a long text.<br>
 		 *                If longText is not given , it is looked up in the resource bundle of the <code>sap.ui.mdc</code> library by the key
 		 *                <code>operators.{oConfiguration.name}.longText</code>
-		 * @param {string} [oConfiguration.tokenText] String representation of the operator as a short text.
+		 * @param {string} [oConfiguration.tokenText] String representation of the operator as a short text.<br>
 		 *                If the token text is not given, it is looked up in the resource bundle of the <code>sap.ui.mdc</code> library by the key
 		 *                <code>operators.{oConfiguration.name}.tokenText</code>
-		 * @param {object} [oConfiguration.displayFormats] Pattern how different <code>displayFormats</code> are rendered
+		 * @param {object} [oConfiguration.displayFormats] Pattern how different {@link sap.ui.mdc.enum.FieldDisplay displayFormats} are rendered
 		 * @param {function} [oConfiguration.format] Function to format condition
 		 * @param {function} [oConfiguration.parse] Function to parse input into condition
 		 * @param {function} [oConfiguration.validate] Function to validate condition
 		 * @param {function} [oConfiguration.getModelFilter] Function create filter for a condition
 		 * @param {function} [oConfiguration.isEmpty] Function to check if condition is empty
-		 * @param {function} [oConfiguration.createControl] Function to create a control
-		 * @param {function} [oConfiguration.splitText] Function to split text // TODO remove
+		 * @param {function} [oConfiguration.createControl] Function to create a control to be used in {@link sap.ui.mdc.field.DefineConditionPanel DefineConditionPanel}
 		 * @param {function} [oConfiguration.getCheckValue] Function to get the value for condition compare
 		 * @param {function} [oConfiguration.getValues] Function to get the real values without operator symbol
-		 * @param {function} [oConfiguration.checkValidated] Function to check if a condition is validated (sets the <code>validated</code> flag
+		 * @param {function} [oConfiguration.checkValidated] Function to check if a condition is validated (sets the <code>validated</code> property)
 		 * @param {boolean} [oConfiguration.exclude] If set, the operator is handled as exclude filter when creating the filters of all conditions
 		 * @param {boolean} [oConfiguration.validateInput] If set, the user input for this operator needs to be validated using a field help
+		 * @param {string} [oConfiguration.additionalInfo] additionalInfo text for the operator. Will be shown in the operator suggest as second column. If not used (undefined) the Include or Exclude information of the operator is used.
 		 * @constructor
+		 * @author SAP SE
+		 * @version 1.98.0
 		 * @private
+		 * @ui5-restricted sap.fe
+		 * @MDC_PUBLIC_CANDIDATE
 		 * @alias sap.ui.mdc.condition.Operator
-		 * @version 1.73.0
+		 * @since 1.73.0
 		 * @author SAP SE
 		 */
 		var Operator = BaseObject.extend("sap.ui.mdc.condition.Operator", /** @lends sap.ui.mdc.condition.Operator.prototype */ {
@@ -98,6 +108,9 @@ sap.ui.define([
 				// map given properties
 				// TODO: for compatibility reasons just put to this.name... but is a API getName better at the end?
 				this.name = oConfiguration.name;
+				if (oConfiguration.alias) {
+					this.alias = oConfiguration.alias;
+				}
 				this.filterOperator = oConfiguration.filterOperator;
 				this.valueTypes = oConfiguration.valueTypes;
 				this.paramTypes = oConfiguration.paramTypes;
@@ -109,13 +122,14 @@ sap.ui.define([
 				this.longText = oConfiguration.longText || _getText(sLongTextKey) || "";
 				this.tokenText = oConfiguration.tokenText || _getText(sTokenTextKey) || "";
 				if (this.longText === sLongTextKey) {
-					//use the tokenText as longText and replace the {0} placeholder
+					//use the tokenText as longText and replace the {0} and {1} placeholder
 					//Example:
 					//#XTIT: token text for "last x days" operator
 					//operators.LASTDAYS.tokenText=Last {0} days
-					//#XTIT: token long text for "last x days" operator
-					//__operators.LASTDAYS.longText=Last x days
-					this.longText = this.tokenText.replace(/\{0\}/g, "x");
+					//#XTIT: token long text for "last X days" operator
+					//__operators.LASTDAYS.longText=Last X days
+					this.longText = this.tokenText.replace(/\{0\}/g, "X")
+						.replace(/\{1\}/g, "Y");
 				}
 				if (this.tokenText === sTokenTextKey) {
 					this.tokenText = this.longText;
@@ -127,9 +141,6 @@ sap.ui.define([
 					var sTokenText;
 					if (oConfiguration.tokenParse) {
 						sTokenText = escapeRegExp(this.tokenText);
-						if (Device.browser.msie) { // IE cannot replace single $, $$ will be replaced to $
-							sTokenText = sTokenText.replace(/\$/g, "$$$");
-						}
 
 						this.tokenParse = oConfiguration.tokenParse.replace(/#tokenText#/g, sTokenText);
 						for (var i = 0; i < this.valueTypes.length; i++) {
@@ -147,9 +158,6 @@ sap.ui.define([
 					// create token formatter
 					if (oConfiguration.tokenFormat) {
 						sTokenText = this.tokenText;
-						if (Device.browser.msie) { // IE cannot replace single $, $$ will be replaced to $
-							sTokenText = sTokenText.replace(/\$/g, "$$$");
-						}
 						this.tokenFormat = oConfiguration.tokenFormat.replace(/\#tokenText\#/g, sTokenText);
 					} else {
 						this.tokenFormat = this.tokenText; // static operator with no value (e.g. "THIS YEAR")
@@ -174,9 +182,6 @@ sap.ui.define([
 				if (oConfiguration.createControl) {
 					this.createControl = oConfiguration.createControl; // TODO move default implementation from DefineConditionPanel to here
 				}
-				if (oConfiguration.splitText) {
-					this.splitText = oConfiguration.splitText; // TODO as only used by EQ remove it from general api
-				}
 				if (oConfiguration.getCheckValue) {
 					this.getCheckValue = oConfiguration.getCheckValue;
 				}
@@ -186,14 +191,26 @@ sap.ui.define([
 				if (oConfiguration.checkValidated) {
 					this.checkValidated = oConfiguration.checkValidated;
 				}
+				if (oConfiguration.additionalInfo !== undefined) {
+					this.additionalInfo = oConfiguration.additionalInfo;
+				}
 
 				this.exclude = !!oConfiguration.exclude; // to have always a boolean value
 				this.validateInput = !!oConfiguration.validateInput; // to have always a boolean value
+
+				if (oConfiguration.group) {
+					this.group = oConfiguration.group;
+				} else {
+					this.group = {id: !this.exclude ? "1" : "2"};
+					if (!this.group.text) {
+						this.group.text = oMessageBundle.getText("VALUEHELP.OPERATOR.GROUP" + this.group.id);
+					}
+				}
 			}
 		});
 
 		/**
-		 * Defines whyt type is used for parse or format the operation
+		 * Defines what type is used for parse or format the operation
 		 *
 		 * @enum {string}
 		 * @private
@@ -213,7 +230,16 @@ sap.ui.define([
 				 *
 				 * @public
 				 */
-				Static: "static"
+				Static: "static",
+
+				/**
+				 * The <code>Type</code> of the <code>Field</code> or <code>FilterField</code> using the <code>Operator</code> is used
+				 * for validation, but the user input is used as value.
+				 *
+				 * @public
+				 * @since 1.86
+				 */
+				SelfNoParse: "selfNoParse"
 		};
 
 		function _getText(sKey, sType) {
@@ -221,13 +247,17 @@ sap.ui.define([
 			var key = sKey + (sType ? "." + sType : ""),
 				sText;
 
-			if (oMessageBundle.hasText(key)) {
-				sText = oMessageBundle.getText(key);
-			} else
-			if (sType) {
-				sText = oMessageBundle.getText(sKey);
-			} else {
-				sText = key;
+			// try to get the resource bundle text (the key might not exist)
+			sText = oMessageBundle.getText(key, undefined, true); // use bIgnoreKeyFallback=true to avoid assert messages in the console
+			if (sText === key || sText === undefined) {
+				if (sType) {
+					sText = oMessageBundle.getText(sKey, undefined, true);
+					if (sText === key || sText === undefined) {
+						sText = sKey;
+					}
+				} else {
+					sText = key;
+				}
 			}
 			return sText;
 
@@ -253,13 +283,15 @@ sap.ui.define([
 		/**
 		 * Creates a filter object for a condition.
 		 *
-		 * @param {object} oCondition Condition
+		 * @param {sap.ui.mdc.condition.ConditionObject} oCondition Condition
 		 * @param {string} sFieldPath Path of filter
- 		 * @param {sap.ui.model.Type} oType Data type of the used filter field
+		 * @param {sap.ui.model.Type} oType Data type of the used filter field
+		 * @param {boolean} [bCaseSensitive] creates a caseSensitive filter
 		 * @returns {sap.ui.model.Filter} filter object
-		 * @public
+		 * @private
+		 * @ui5-restricted sap.ui.mdc
 		 */
-		Operator.prototype.getModelFilter = function(oCondition, sFieldPath, oType) {
+		Operator.prototype.getModelFilter = function(oCondition, sFieldPath, oType, bCaseSensitive) {
 
 			var vValue = oCondition.values[0];
 			var oFilter;
@@ -269,21 +301,25 @@ sap.ui.define([
 			if (Array.isArray(vValue) && aFieldPaths.length > 1) {
 				vValue = vValue[0];
 				sFieldPath = aFieldPaths[0];
-				oFilterUnit = new Filter({path: aFieldPaths[1], operator: "EQ", value1: oCondition.values[0][1]});
+				oFilterUnit = new Filter({path: aFieldPaths[1], operator: FilterOperator.EQ, value1: oCondition.values[0][1]});
 			}
 			if (oFilterUnit && vValue === undefined) {
 				// filter only for unit
 				oFilter = oFilterUnit;
 				oFilterUnit = undefined;
-			} else if (this.valueTypes.length == 1) {
-				oFilter = new Filter({ path: sFieldPath, operator: this.filterOperator, value1: vValue });
+			} else if (!this.valueTypes[1]) {
+				if (!bCaseSensitive && oCondition.validated === ConditionValidated.Validated)  {
+					// for validated Item conditions we always set caseSensitive to true;
+					bCaseSensitive = true;
+				}
+				oFilter = new Filter({ path: sFieldPath, operator: this.filterOperator, value1: vValue, caseSensitive: bCaseSensitive === false ? false : undefined });
 			} else {
 				var vValue2 = oCondition.values[1];
 				if (Array.isArray(vValue2) && aFieldPaths.length > 1) {
 					vValue2 = vValue2[0];
 					// use same unit as for value1
 				}
-				oFilter = new Filter({ path: sFieldPath, operator: this.filterOperator, value1: vValue, value2: vValue2 });
+				oFilter = new Filter({ path: sFieldPath, operator: this.filterOperator, value1: vValue, value2: vValue2, caseSensitive: bCaseSensitive === false ? false : undefined });
 			}
 
 			if (oFilterUnit) {
@@ -294,9 +330,13 @@ sap.ui.define([
 			if (oCondition.inParameters) {
 				var aFilters = [oFilter];
 				for ( var sInPath in oCondition.inParameters) {
-					aFilters.push(new Filter({path: sInPath, operator: "EQ", value1: oCondition.inParameters[sInPath]}));
+					if (sInPath.startsWith("conditions/")) { // only use InParameters that are in the same ConditionModel (Parameters from outside might not be valid filters)
+						aFilters.push(new Filter({path: sInPath.slice(11), operator: FilterOperator.EQ, value1: oCondition.inParameters[sInPath]}));
+					}
+				}
+				if (aFilters.length > 1) {
+					oFilter = new Filter({ filters: aFilters, and: true });
 				}
-				oFilter = new Filter({ filters: aFilters, and: true });
 			}
 
 			return oFilter;
@@ -306,11 +346,12 @@ sap.ui.define([
 		/**
 		 * Checks if a condition is empty.
 		 *
-		 * @param {object} oCondition Condition
+		 * @param {sap.ui.mdc.condition.ConditionObject} oCondition Condition
 		 * @param {sap.ui.model.Type} oType Data type
 		 * @returns {boolean} true if empty
 		 *
-		 * @public
+		 * @private
+		 * @ui5-restricted sap.ui.mdc
 		 */
 		Operator.prototype.isEmpty = function(oCondition, oType) {
 
@@ -335,26 +376,31 @@ sap.ui.define([
 		/**
 		 * Formats a condition.
 		 *
-		 * @param {object} oCondition Condition
-		 * @param {sap.ui.model.Type} oType Data type
-		 * @param {string} sDisplay Display mode
+		 * @param {sap.ui.mdc.condition.ConditionObject} oCondition Condition
+		 * @param {sap.ui.model.Type} [oType] Data type
+		 * @param {string} [sDisplay] Display mode
+		 * @param {boolean} [bHideOperator=false] If set, only the value output is returned without any visible operator
 		 * @returns {string} formatted text
 		 * @throws {sap.ui.model.FormatException} if the values cannot be formatted
 		 *
-		 * @public
+		 * @private
+		 * @ui5-restricted sap.ui.mdc
 		 */
-		Operator.prototype.format = function(oCondition, oType, sDisplay) { // sDisplay needed in EQ formatter
+		Operator.prototype.format = function(oCondition, oType, sDisplay, bHideOperator) { // sDisplay needed in EQ formatter
 
 			var aValues = oCondition.values;
-			var sTokenText = this.tokenFormat;
 			var iCount = this.valueTypes.length;
+			var sTokenText = bHideOperator && iCount === 1 ? "{0}" : this.tokenFormat;
 			for (var i = 0; i < iCount; i++) {
 				if (this.valueTypes[i] !== Operator.ValueType.Static) {
-					var v = aValues[i] !== undefined && aValues[i] !== null ? aValues[i] : "";
 					if (this.valueTypes[i] !== Operator.ValueType.Self) {
-						oType = this._createLocalType(this.valueTypes[i]);
+						oType = this._createLocalType(this.valueTypes[i], oType);
 					}
-					var sReplace = oType ? oType.formatValue(v, "string") : v;
+					var vValue = aValues[i];
+					if (vValue === undefined || vValue === null) {
+						vValue = oType ? oType.parseValue("", "string") : ""; // for empty value use initial value of type
+					}
+					var sReplace = oType ? oType.formatValue(vValue, "string") : vValue;
 					// the regexp will replace placeholder like $0, 0$ and {0}
 					sTokenText = sTokenText.replace(new RegExp("\\$" + i + "|" + i + "\\$" + "|" + "\\{" + i + "\\}", "g"), sReplace);
 				}
@@ -368,12 +414,13 @@ sap.ui.define([
 		 *
 		 * @param {string} sText Text
 		 * @param {sap.ui.model.Type} oType Data type
-		 * @param {string} sDisplayFormat Display format
+		 * @param {sap.ui.mdc.enum.FieldDisplay} sDisplayFormat Display format
 		 * @param {boolean} bDefaultOperator If true, operator is used as default. In this case parsing without operator also works
 		 * @returns {any[]} array of values
 		 * @throws {sap.ui.model.ParseException} if the text cannot be parsed
 		 *
-		 * @public
+		 * @private
+		 * @ui5-restricted sap.ui.mdc
 		 */
 		Operator.prototype.parse = function(sText, oType, sDisplayFormat, bDefaultOperator) {
 
@@ -383,7 +430,7 @@ sap.ui.define([
 				aResult = [];
 				for (var i = 0; i < this.valueTypes.length; i++) {
 					if (this.valueTypes[i] && [Operator.ValueType.Self, Operator.ValueType.Static].indexOf(this.valueTypes[i]) === -1) {
-						oType = this._createLocalType(this.valueTypes[i]);
+						oType = this._createLocalType(this.valueTypes[i], oType);
 					}
 					try {
 						if (this.valueTypes[i] !== Operator.ValueType.Static) {
@@ -416,7 +463,7 @@ sap.ui.define([
 		 * @throws {sap.ui.model.ParseException} if the text cannot be parsed
 		 *
 		 * @private
-		 * ui5-restricted to be enhanced by operators inherit from operator
+		 * @ui5-restricted Operator subclasses
 		 */
 		Operator.prototype._parseValue = function(sValue, oType) { // needed in EQ operator to be accessed from outside
 
@@ -425,18 +472,18 @@ sap.ui.define([
 			}
 
 			var aCurrentValue;
-			if (oType instanceof sap.ui.model.CompositeType && oType._aCurrentValue && oType.getParseWithValues()) {
+			if (oType && oType.isA("sap.ui.model.CompositeType") && oType._aCurrentValue && oType.getParseWithValues()) {
 				aCurrentValue = oType._aCurrentValue;
 			}
 
 			var vValue = oType ? oType.parseValue(sValue, "string", aCurrentValue) : sValue;
 
-			if (aCurrentValue && Array.isArray(vValue)) {
+			if (oType && oType._aCurrentValue && Array.isArray(vValue)) {
 				// in case the user only entered a part of the CompositeType, we add the missing parts from aCurrentValue
 				// but add only the parts that have entries in array after parsing ( not set one-time parts)
 				for (var j = 0; j < vValue.length; j++) {
 					if (vValue[j] === undefined) {
-						vValue[j] = aCurrentValue[j];
+						vValue[j] = oType._aCurrentValue[j] === undefined ? null : oType._aCurrentValue[j]; // undefined not valid for formatting, needs to be null
 					}
 				}
 			}
@@ -452,18 +499,26 @@ sap.ui.define([
 		 * @param {sap.ui.model.Type} oType Data type
 		 * @throws {sap.ui.model.ValidateException} if the values are invalid
 		 *
-		 * @public
+		 * @private
+		 * @ui5-restricted sap.ui.mdc
 		 */
 		Operator.prototype.validate = function(aValues, oType) {
 
 			var iCount = this.valueTypes.length;
+
 			for (var i = 0; i < iCount; i++) {
-				var vValue = aValues[i] !== undefined && aValues[i] !== null ? aValues[i] : "";
 				if (this.valueTypes[i] && this.valueTypes[i] !== Operator.ValueType.Static) { // do not validate Description in EQ case
 					if ([Operator.ValueType.Self, Operator.ValueType.Static].indexOf(this.valueTypes[i]) === -1) {
-						oType = this._createLocalType(this.valueTypes[i]);
+						oType = this._createLocalType(this.valueTypes[i], oType);
+					}
+					if (aValues.length < i + 1) {
+						throw new Error("value " + i + " for operator " + this.getName() + " missing"); // no ValidateException as this error must not occur from user input
 					}
 					if (oType) {
+						var vValue = aValues[i];
+						if (vValue === undefined || vValue === null) {
+							vValue = oType ? oType.parseValue("", "string") : ""; // for empty value use initial value of type
+						}
 						oType.validateValue(vValue);
 					}
 				}
@@ -476,31 +531,67 @@ sap.ui.define([
 		/**
 		 * Creates a local type.
 		 *
-		 * @param {string} sType Type name
+		 * @param {string|object} vType Type name or object with type information
+		 * @param {sap.ui.model.Type} oType original data type
 		 * @returns {sap.ui.model.SimpleType} data type
 		 * @private
 		 * @ui5-restricted sap.ui.mdc.field.DefineConditionPanel
 		 */
-		Operator.prototype._createLocalType = function(vType) {
+		Operator.prototype._createLocalType = function(vType, oType) {
 
-			if (!this._oType) {
-				var sType;
-				var oFormatOptions;
-				var oConstraints;
-
-				if (typeof vType === "string") {
-					sType = vType;
-				} else if (vType && typeof vType === "object") {
-					sType = vType.name;
-					oFormatOptions = vType.formatOptions;
-					oConstraints = vType.constraints;
-				}
-
-				sap.ui.requireSync(sType.replace(/\./g, "/"));
-				var oTypeClass = ObjectPath.get(sType || "");
-				this._oType = new oTypeClass(oFormatOptions, oConstraints);
+			if (!this._aTypes) {
+				this._aTypes = []; // array as for SelfNoParse type depends on FilterField
 			}
-			return this._oType;
+
+			var sType;
+			var oFormatOptions;
+			var oConstraints;
+			var oUsedType;
+
+			if (vType === Operator.ValueType.SelfNoParse) {
+				// create "clone" of original type but do not change value in parse or format
+				sType = oType.getMetadata().getName(); // type is already loaded because instance is provided
+				oFormatOptions = merge({}, oType.getFormatOptions());
+				oConstraints = merge(oType.getConstraints());
+			} else if (typeof vType === "string") {
+				sType = vType;
+			} else if (vType && typeof vType === "object") {
+				sType = vType.name;
+				oFormatOptions = vType.formatOptions;
+				oConstraints = vType.constraints;
+			}
+
+			for (var i = 0; i < this._aTypes.length; i++) {
+				var oMyType = this._aTypes[i];
+				if (oMyType.name === sType && deepEqual(oMyType.formatOptions, oFormatOptions) && deepEqual(oMyType.constraints, oConstraints)) {
+					oUsedType = oMyType.type;
+					break;
+				}
+			}
+
+			if (!oUsedType) {
+				// The used type must be required from the application.
+				var TypeClass = ObjectPath.get(sType || "");
+				oUsedType = new TypeClass(oFormatOptions, oConstraints);
+				oUsedType._bCreatedByOperator = true; // to distinguish in Field between original type and Operator type on Operator change
+
+				if (vType === Operator.ValueType.SelfNoParse) {
+					oUsedType.parseValue = function(vValue, sSourceType) {
+						TypeClass.prototype.parseValue.apply(this, arguments); // to check for parse exception
+						return vValue;
+					};
+					oUsedType.validateValue = function(vValue) {
+						var sValue = TypeClass.prototype.parseValue.apply(this, [vValue, "string"]); // to check with parsed value
+						TypeClass.prototype.validateValue.apply(this, [sValue]);
+					};
+					oUsedType.formatValue = function(vValue, sTargetType) {
+						TypeClass.prototype.formatValue.apply(this, arguments); // to check for format exception
+						return vValue;
+					};
+				}
+				this._aTypes.push({name: sType, formatOptions: oFormatOptions, constraints: oConstraints, type: oUsedType});
+			}
+			return oUsedType;
 
 		};
 
@@ -510,7 +601,8 @@ sap.ui.define([
 		 * @param {string} sText Text
 		 * @returns {boolean} true valid
 		 *
-		 * @public
+		 * @private
+		 * @ui5-restricted sap.ui.mdc
 		 */
 		Operator.prototype.test = function(sText) {
 
@@ -524,11 +616,12 @@ sap.ui.define([
 		 * In this function no type validation takes place.
 		 *
 		 * @param {string} sText Text
-		 * @param {string} sDisplayFormat Display format
+		 * @param {sap.ui.mdc.enum.FieldDisplay} sDisplayFormat Display format
 		 * @param {boolean} bDefaultOperator If true, operator is used as default. In this case parsing without operator also works
 		 * @returns {string[]} array of value parts without operator sign
 		 *
-		 * @public
+		 * @private
+		 * @ui5-restricted sap.ui.mdc
 		 * @since 1.77.0
 		 */
 		Operator.prototype.getValues = function(sText, sDisplayFormat, bDefaultOperator) {
@@ -560,16 +653,17 @@ sap.ui.define([
 		 *
 		 * @param {string} sText Text
 		 * @param {sap.ui.model.Type} oType Data type
-		 * @param {string} sDisplayFormat Display format
+		 * @param {sap.ui.mdc.enum.FieldDisplay} sDisplayFormat Display format
 		 * @param {boolean} bDefaultOperator If true, operator is used as default. In this case parsing without operator also works
-		 * @returns {object} condition
+		 * @returns {sap.ui.mdc.condition.ConditionObject} The condition for the text
 		 * @throws {sap.ui.model.ParseException} if the text cannot be parsed
 		 *
-		 * @public
+		 * @private
+		 * @ui5-restricted sap.ui.mdc
 		 */
 		Operator.prototype.getCondition = function(sText, oType, sDisplayFormat, bDefaultOperator) {
 
-			if (this.test(sText) || (bDefaultOperator && sText)) {
+			if (this.test(sText) || (bDefaultOperator && sText && this.hasRequiredValues())) {
 				var aValues = this.parse(sText, oType, sDisplayFormat, bDefaultOperator);
 				if (aValues.length == this.valueTypes.length || this.valueTypes[0] === Operator.ValueType.Static
 						|| (aValues.length === 1 && this.valueTypes.length === 2 && !this.valueTypes[1])) { // EQ also valid without description
@@ -589,7 +683,7 @@ sap.ui.define([
 		 *
 		 * For example, an equal Operator has only one value, a between operator two.
 		 *
-		 * @returns {object} True if only one value is used.
+		 * @returns {boolean} <code>true</code> if only one value is used.
 		 * @since 1.75.0
 		 * @private
 		 * @ui5-restricted sap.ui.mdc.field.FieldBase
@@ -608,7 +702,7 @@ sap.ui.define([
 		/**
 		 * Creates an object containing information to compare conditions.
 		 *
-		 * @param {object} oCondition Condition to check
+		 * @param {sap.ui.mdc.condition.ConditionObject} oCondition Condition to check
 		 * @returns {object} Object with check information
 		 * @private
 		 * @since: 1.76.0
@@ -623,16 +717,34 @@ sap.ui.define([
 
 		};
 
+		/**
+		 * Creates an object containing information to compare conditions.
+		 *
+		 * @returns {boolean} Object with check information
+		 * @private
+		 * @since: 1.90.0
+		 */
+		 Operator.prototype.hasRequiredValues = function() {
+
+			if (this.valueTypes[0] && this.valueTypes[0] !== Operator.ValueType.Static) {
+				return true;
+			} else {
+				return false;
+			}
+
+		};
+
 		/**
 		 * Compares two conditions
 		 *
 		 * For EQ conditions, only the key part of the values is compared as the text part
 		 * might be different (if the translation is missing, for example).
 		 *
-		 * @param {object} oCondition1 Condition to check
-		 * @param {object} oCondition2 Condition to check
-		 * @returns {boolean} True if conditions are equal
-		 * @public
+		 * @param {sap.ui.mdc.condition.ConditionObject} oCondition1 Condition to check
+		 * @param {sap.ui.mdc.condition.ConditionObject} oCondition2 Condition to check
+		 * @returns {boolean} <code>true</code> if conditions are equal
+		 * @private
+		 * @ui5-restricted sap.ui.mdc
 		 * @since: 1.76.0
 		 */
 		Operator.prototype.compareConditions = function(oCondition1, oCondition2) {
@@ -677,8 +789,9 @@ sap.ui.define([
 		 *
 		 * For EQ set <code>validated</code> flag if a description is given.
 		 *
-		 * @param {object} oCondition condition to check
-		 * @public
+		 * @param {sap.ui.mdc.condition.ConditionObject} oCondition Condition to check
+		 * @private
+		 * @ui5-restricted sap.ui.mdc
 		 * @since: 1.78.0
 		 */
 		Operator.prototype.checkValidated = function(oCondition) {
