@@ -1,6 +1,6 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
@@ -13,6 +13,7 @@ sap.ui.define([
 	'sap/ui/model/type/String',
 	'sap/ui/mdc/enum/FieldDisplay',
 	'sap/ui/mdc/condition/FilterOperatorUtil',
+	'sap/ui/mdc/condition/Operator',
 	'sap/ui/mdc/condition/Condition',
 	'sap/ui/mdc/enum/BaseType',
 	'sap/ui/mdc/enum/ConditionValidated',
@@ -27,6 +28,7 @@ sap.ui.define([
 		StringType,
 		FieldDisplay,
 		FilterOperatorUtil,
+		Operator,
 		Condition,
 		BaseType,
 		ConditionValidated,
@@ -44,28 +46,34 @@ sap.ui.define([
 	 * @extends sap.ui.model.SimpleType
 	 *
 	 * @author SAP SE
-	 * @version 1.82.2
+	 * @version 1.98.0
 	 *
+	 * @since 1.62.0
 	 * @private
+	 * @ui5-restricted sap.ui.mdc.field.FieldBase, sap.fe
+	 * @MDC_PUBLIC_CANDIDATE
+	 *
 	 * @param {object} [oFormatOptions] Formatting options
 	 * @param {sap.ui.model.Type} [oFormatOptions.valueType] Type of the value of the condition (used for formatting and parsing)
 	 * @param {string[]} [oFormatOptions.operators] Possible operators to be used in the condition
-	 * @param {string} [oFormatOptions.display] DisplayFormat used to visualize value
-	 * @param {string} [oFormatOptions.fieldHelpID] ID of the field help, to determine key and description // TODO: async request????
+	 * @param {sap.ui.mdc.enum.FieldDisplay} [oFormatOptions.display] DisplayFormat used to visualize a value
+	 * @param {string} [oFormatOptions.fieldHelpID] ID of the field help to determine the key and description // TODO: async request????
 	 * @param {boolean} [oFormatOptions.hideOperator] If set, only the value of the condition is shown, but no operator //TODO
 	 * @param {int} [oFormatOptions.maxConditions] Maximum number of allowed conditions
-	 * @param {object} [oFormatOptions.bindingContext] BindingContext of field. Used to get key or description from the value help using in/out parameters. (In table, the value help might be connected to different row)
-	 * @param {sap.ui.model.Type} [oFormatOptions.originalDateType] Type used on field. E.g. for date types internally a different type is used internally to have different <code>formatOptions</code>
-	 * @param {boolean} [oFormatOptions.isUnit] If set, the type is used for the unit part of a field
+	 * @param {sap.ui.model.Context} [oFormatOptions.bindingContext] <code>BindingContext</code> of field. Used to get a key or description from the value help using in/out parameters. (In a table, the value help might be connected to a different row)
+	 * @param {sap.ui.model.Type} [oFormatOptions.originalDateType] Type used on field, for example, for date types; a different type is used internally to have different <code>formatOptions</code>
+	 * @param {sap.ui.model.Type} [oFormatOptions.additionalType] additional Type used on other part of a field. (This is the case for unit fields.)
 	 * @param {function} [oFormatOptions.getConditions] Function to get the existing conditions of the field. Only used if <code>isUnit</code> is set. // TODO: better solution
 	 * @param {function} [oFormatOptions.asyncParsing] Callback function to tell the <code>Field</code> the parsing is asynchronous.
-	 * @param {object} [oFormatOptions.navigateCondition] Condition of keyboard navigation. If this is filled, no real parsing is needed as the condition has already been determined. Just return it
+	 * @param {object} [oFormatOptions.navigateCondition] Condition of keyboard navigation. If this is filled, no real parsing is needed as the condition has already been determined and is just returned
 	 * @param {object} [oFormatOptions.delegate] Field delegate to handle model-specific logic
 	 * @param {object} [oFormatOptions.payload] Payload of the delegate
-	 * @param {boolean} [oFormatOptions.preventGetDescription] If set, description is not read by <code>formatValue</code> as it is known that no description exist or it might be set later
+	 * @param {boolean} [oFormatOptions.preventGetDescription] If set, description is not read by <code>formatValue</code> as it is known that no description exists or might be set later
+	 * @param {sap.ui.mdc.condition.ConditionModel} [oFormatOptions.conditionModel] <code>ConditionModel</code>, if bound to one
+	 * @param {string} [oFormatOptions.conditionModelName] Name of the <code>ConditionModel</code>, if bound to one
+	 * @param {string} [oFormatOptions.defaultOperatorName] Name of the default <code>Operator</code>
 	 * @param {object} [oConstraints] Value constraints
 	 * @alias sap.ui.mdc.field.ConditionType
-	 * @since 1.62.0
 	 */
 	var ConditionType = SimpleType.extend("sap.ui.mdc.field.ConditionType", /** @lends sap.ui.mdc.field.ConditionType.prototype */ {
 
@@ -73,6 +81,7 @@ sap.ui.define([
 			SimpleType.apply(this, arguments);
 			this.sName = "Condition";
 			this._oResourceBundle = sap.ui.getCore().getLibraryResourceBundle("sap.ui.mdc");
+			this._oCalls = {active: 0, last: 0, condition: undefined, exception: undefined}; // if Multiple async. calls, just use the last result
 		}
 
 	});
@@ -106,44 +115,45 @@ sap.ui.define([
 		}
 
 		var oType = _getValueType.call(this);
-		var oOriginalDateType = _getOriginalDateType.call(this);
-		var bIsUnit = this.oFormatOptions.isUnit;
+		var bIsUnit = _isUnit(oType);
 		var bPreventGetDescription = this.oFormatOptions.preventGetDescription;
 
-		_attachCurrentValueAtType.call(this, oCondition, oOriginalDateType); // use original condition
-
-		if (bIsUnit) {
-			// only use unit in condition
-			oCondition = merge({}, oCondition);
-			if (oCondition.values[0] && Array.isArray(oCondition.values[0])) {
-				oCondition.values[0] = oCondition.values[0][1];
-			}
-			if (oCondition.operator !== "EQ") {
-				// in the moment only single value supported
-				oCondition.operator = "EQ";
-				if (oCondition.values[1]) {
-					oCondition.values.splice(1,1);
-				}
-			}
-		}
-
-		_attachCurrentValueAtType.call(this, oCondition, oType);
+		_attachCurrentValueAtType.call(this, oCondition, oType); // use original condition
 
 		switch (this.getPrimitiveType(sInternalType)) {
 			case "string":
 			case "any":
 				var sDisplay = _getDisplay.call(this);
+				var aOperators = _getOperators.call(this);
+				var oEQOperator = FilterOperatorUtil.getEQOperator(aOperators);
+				if (!this.oFormatOptions.maxConditions || this.oFormatOptions.maxConditions === 1) { // as Tokens in FilterField using the same ConditionType, do not use the last value
+					this._oCalls.active++;
+					this._oCalls.last++;
+				}
+				var iCallCount = this._oCalls.last;
 
-				if (!bPreventGetDescription && oCondition.operator === "EQ" && sDisplay !== FieldDisplay.Value &&
-						oCondition.validated === ConditionValidated.Validated && !oCondition.values[1]) {
+				if (!bPreventGetDescription && sDisplay !== FieldDisplay.Value && oCondition.validated === ConditionValidated.Validated &&
+						(bIsUnit || (oCondition.operator === oEQOperator.name && !oCondition.values[1]))) {
 					// handle sync case and async case similar
 					var oBindingContext = this.oFormatOptions.bindingContext;
+					var oConditionModel = this.oFormatOptions.conditionModel;
+					var sConditionModelName = this.oFormatOptions.conditionModelName;
+					var vKey = bIsUnit ? oCondition.values[0][1] : oCondition.values[0];
 
 					return SyncPromise.resolve().then(function() {
-						return _getDescription.call(this, oCondition.values[0], oCondition.inParameters, oCondition.outParameters, oBindingContext);
+						return _getDescription.call(this, vKey, oCondition.inParameters, oCondition.outParameters, oBindingContext, oConditionModel, sConditionModelName);
 					}.bind(this)).then(function(vDescription) { // if description needs to be requested -> return if it is resolved
 						if (vDescription) {
 							oCondition = merge({}, oCondition); // do not manipulate original object
+							if (bIsUnit) {
+								// in unit case create "standard" condition using String type for text arrangement
+								oType = _getDefaultType.call(this);
+								oCondition.operator = oEQOperator.name;
+								if (typeof vDescription !== "object") {
+									vDescription = {key: vKey, description: vDescription};
+								}
+							}
+
 							if (typeof vDescription === "object") {
 								oCondition = _mapResultToCondition.call(this, oCondition, vDescription);
 							} else if (oCondition.values.length === 1) {
@@ -152,18 +162,19 @@ sap.ui.define([
 								oCondition.values[1] = vDescription;
 							}
 						}
-						return _formatToString.call(this, oCondition);
+						return _returnResult.call(this, oCondition, undefined, iCallCount, true, oType);
 					}.bind(this)).catch(function(oException) {
-						if (oException instanceof FormatException && _isInvalidInputAllowed.call(this)) {
+						var oMyException;
+						if (!(oException instanceof FormatException) || !_isInvalidInputAllowed.call(this)) {
 							// if "invalid" input is allowed don't fire an exception
-							return _formatToString.call(this, oCondition);
-						} else {
-							throw oException;
+							oMyException = oException;
 						}
+
+						return _returnResult.call(this, oCondition, oMyException, iCallCount, true, oType);
 					}.bind(this)).unwrap();
 				}
 
-				return _formatToString.call(this, oCondition);
+				return _returnResult.call(this, oCondition, undefined, iCallCount, true, oType);
 			default:
 				// operators can only be formatted to string. But other controls (like Slider) might just use the value
 				if (oType && oCondition.values.length >= 1) {
@@ -175,22 +186,59 @@ sap.ui.define([
 
 	};
 
-	function _formatToString(oCondition) {
+	function _formatToString(oCondition, oType) {
 
 		var sDisplay = _getDisplay.call(this);
-		var oType = _getValueType.call(this);
+		var bIsUnit = _isUnit(oType);
 
-		if (this.oFormatOptions.hideOperator && oCondition.values.length === 1) {
-			return oType.formatValue(oCondition.values[0], "string");
+		if (bIsUnit && oCondition.values.length > 1 && oCondition.values[0][1] === oCondition.values[1][1]) { // in Between case format only one unit
+			oCondition = merge({}, oCondition); // don't use same object
+			oCondition.operator = "EQ";
+			oCondition.values.splice(1);
 		}
 
+		var bHideOperator = (this.oFormatOptions.hideOperator && oCondition.values.length === 1) || bIsUnit;
 		var oOperator = FilterOperatorUtil.getOperator(oCondition.operator);
 
 		if (!oOperator) {
 			throw new FormatException("No valid condition provided, Operator wrong.");
 		}
 
-		return oOperator.format(oCondition, oType, sDisplay);
+		return oOperator.format(oCondition, oType, sDisplay, bHideOperator);
+
+	}
+
+	function _returnResult(oCondition, oException, iCallCount, bFormat, oType) {
+
+		if (this._oCalls.active > 0) {
+			this._oCalls.active--;
+		}
+		if (iCallCount < this._oCalls.last && (this._oCalls.condition !== undefined || this._oCalls.exception !== undefined)) {
+			// there is already a newer result
+			oCondition = this._oCalls.condition;
+			oException = this._oCalls.exception;
+		}
+
+		if (iCallCount === this._oCalls.last && this._oCalls.active > 0) {
+			this._oCalls.condition = merge({}, oCondition); // don't use same object
+			this._oCalls.exception = oException;
+		} else if (this._oCalls.active === 0 && this._oCalls.last > 0) { // no pending calls -> clean up
+			this._oCalls = {active: 0, last: 0, condition: undefined, exception: undefined};
+		}
+
+		if (oException) {
+			throw oException; // just throw exception
+		}
+
+		// finalize condition. If Exception occurs here just throw it
+		var vResult;
+		if (bFormat) {
+			vResult = _formatToString.call(this, oCondition, oType);
+		} else {
+			vResult = _finishParseFromString.call(this, oCondition, oType);
+		}
+
+		return vResult;
 
 	}
 
@@ -218,19 +266,18 @@ sap.ui.define([
 		var sDisplay = _getDisplay.call(this);
 		var bInputValidationEnabled = _isInputValidationEnabled.call(this);
 		var oType = _getValueType.call(this);
-		var oOriginalDateType = _getOriginalDateType.call(this);
+		var oOriginalType = _getOriginalType.call(this);
 		var aOperators = _getOperators.call(this);
-		var bIsUnit = this.oFormatOptions.isUnit;
+		var bIsUnit = _isUnit(oType);
 		var sDefaultOperator;
 
 		if (vValue === null || vValue === undefined || (vValue === "" && !bInputValidationEnabled)) { // check if "" is a key in FieldHelp
-			if (!_isCompositeType.call(this, oType) && !bIsUnit) {
+			if (!_isCompositeType.call(this, oType)) {
 				return null; // TODO: for all types???
 			}
 		}
 
 		_initCurrentValueAtType.call(this, oType);
-		_initCurrentValueAtType.call(this, oOriginalDateType);
 
 		switch (this.getPrimitiveType(sInternalType)) {
 			case "string":
@@ -247,61 +294,74 @@ sap.ui.define([
 
 					if (aMatchingOperators.length === 0) {
 						// use default operator if nothing found
-						oOperator = FilterOperatorUtil.getDefaultOperator(_getBaseType.call(this, oType)); // TODO: How to configure default for application
-						if (oOperator && aOperators.indexOf(oOperator.name) < 0) {
-							// default operator not valid -> cannot use
-							oOperator = undefined;
-						}
+						oOperator = _getDefaultOperator.call(this, aOperators, oType);
 
-						if (bInputValidationEnabled && !_isCompositeType.call(this, oType) && aOperators.indexOf("EQ") >= 0) {
+						if (bInputValidationEnabled && !_isCompositeType.call(this, oType)) {
 							// try first to use EQ and find it in FieldHelp. If not found try later with default operator
-							bCheckForDefault = !!oOperator && oOperator.name !== "EQ"; // only if default operator exists and is different
-							oOperator = FilterOperatorUtil.getEQOperator();
+							var oEQOperator = FilterOperatorUtil.getEQOperator(aOperators);
+							if (aOperators.indexOf(oEQOperator.name) >= 0) { // as EQ is returned if not in List
+								bCheckForDefault = !!oOperator && oOperator.name !== oEQOperator.name; // only if default operator exists and is different
+								oOperator = oEQOperator;
+							}
 						}
 
 						bUseDefaultOperator = true;
 					} else {
-						oOperator = aMatchingOperators[0]; // TODO: multiple matches?
+						//in case of multiple matches we use the first operators without ValueType (if exist) / at the moment we have two matching operators for "<empty>"" --> LT and EMPTY
+						var aOperatorsWithoutValueType = aMatchingOperators.filter(function(oOperator){ return oOperator.valueTypes.length === 0; });
+						if (aOperatorsWithoutValueType.length >= 1) {
+							oOperator = aOperatorsWithoutValueType[0];
+						} else {
+							oOperator = aMatchingOperators[0]; // TODO: use the first of the matching operators
+						}
 					}
 				}
 
 				if (oOperator) {
+					if (bIsUnit && oOperator !== FilterOperatorUtil.getEQOperator(aOperators)) {
+						throw new ParseException("unsupported operator");
+					}
 					var oCondition;
 					var bCompositeType = _isCompositeType.call(this, oType);
+					this._oCalls.active++;
+					this._oCalls.last++;
+					var iCallCount = this._oCalls.last;
 
-					if (!bCompositeType && oOperator.validateInput && bInputValidationEnabled) {
-						// use FieldHelp to determine condition
+					if ((!bCompositeType || bIsUnit) && oOperator.validateInput && bInputValidationEnabled) {
+						// use FieldHelp to determine condition (for unit part also if composite type used)
 						oCondition = _parseDetermineKeyAndDescription.call(this, oOperator, vValue, oType, bUseDefaultOperator, bCheckForDefault, aOperators, sDisplay, true);
 						if (oCondition instanceof Promise) {
 							return _fnReturnPromise.call(this, oCondition);
 						} else {
 							return oCondition;
 						}
-					} else if (vValue === "" && !bCompositeType) {
-						// nothing entered -> no condition ; but in unit case update existing condition
-						return _finishParseFromString.call(this, null, oType);
 					} else {
 						// just normal operator parsing
 						try {
-						if (vValue === "" && bCompositeType && bUseDefaultOperator) {
+							if (vValue === "" && bCompositeType && bUseDefaultOperator) {
 								// parse using unit part
 								oCondition = Condition.createCondition(oOperator.name, [oType.parseValue(vValue, "string", oType._aCurrentValue)], undefined, undefined, ConditionValidated.NotValidated);
 							} else {
 								oCondition = oOperator.getCondition(vValue, oType, sDisplay, bUseDefaultOperator);
 							}
 						} catch (oException) {
-							if (oException instanceof ParseException && oOriginalDateType) {
+							var oMyException = oException;
+							if (oMyException instanceof ParseException && oOriginalType) {
 								// As internal yyyy-MM-dd is used as pattern for dates (times similar) the
 								// parse exception might contain this as pattern. The user should see the pattern thats shown
 								// So try to parse date with the original type to get parseException with right pattern.
-								oOriginalDateType.parseValue(vValue, "string", oOriginalDateType._aCurrentValue);
+								try {
+									oOriginalType.parseValue(vValue, "string", oOriginalType._aCurrentValue);
+								} catch (oOriginalException) {
+									oMyException = oOriginalException;
+								}
 							}
-							throw oException;
+							return _returnResult.call(this, undefined, oMyException, iCallCount, false, oType); // to reuse it for pending calls
 						}
 					}
 
 					if (oCondition) {
-						return _finishParseFromString.call(this, oCondition, oType);
+						return _returnResult.call(this, oCondition, undefined, iCallCount, false, oType);
 					}
 				}
 
@@ -315,9 +375,8 @@ sap.ui.define([
 						// only one operator supported -> use it
 						sDefaultOperator = aOperators[0];
 					} else {
-						sDefaultOperator = FilterOperatorUtil.getDefaultOperator(_getBaseType.call(this, oType)).name;
-						if (sDefaultOperator && aOperators.indexOf(sDefaultOperator) < 0) {
-							// default operator not valid -> cannot use
+						sDefaultOperator = _getDefaultOperator.call(this, aOperators, oType).name;
+						if (aOperators.indexOf(sDefaultOperator) < 0) { // as EQ is returned if not in List
 							sDefaultOperator = undefined;
 						}
 					}
@@ -332,45 +391,25 @@ sap.ui.define([
 
 	function _finishParseFromString(oCondition, oType) {
 
-		var bIsUnit = this.oFormatOptions.isUnit;
-		var oOriginalDateType = _getOriginalDateType.call(this);
-		var sUnit = null; // default for empty unit
+		var bIsUnit = _isUnit(oType);
 
-		if (bIsUnit) {
-			var vMeasure;
-			if (oOriginalDateType._aCurrentValue) {
-				vMeasure = oOriginalDateType._aCurrentValue[0];
-			}
-
-			if (oCondition) {
-				if (oCondition.operator !== "EQ") {
-					throw new ParseException("unsupported operator");
-				}
-				sUnit = oCondition.values[0]; // use key of unit
-				oCondition.values = [[vMeasure, sUnit]];
-			} else {
-				// create a condition if no unit is entered
-				oCondition = Condition.createCondition("EQ", [[vMeasure, null]], undefined, undefined, ConditionValidated.NotValidated);
-			}
-			_attachCurrentValueAtType.call(this, oCondition, oOriginalDateType);
-		} else if (oCondition) {
+		if (oCondition && !bIsUnit) {
 			var sName = oType.getMetadata().getName();
 			var oDelegate = this.oFormatOptions.delegate;
 			var oPayload = this.oFormatOptions.payload;
 			if (oDelegate && oDelegate.getTypeUtil(oPayload).getBaseType(sName) === BaseType.Unit &&
 					!oCondition.values[0][1] && oType._aCurrentValue) {
 				// TODO: if no unit provided use last one
-				sUnit = oType._aCurrentValue[1] ? oType._aCurrentValue[1] : null; // if no unit set null
-				oCondition.values[0][1] = sUnit;
+				var sUnit = oType._aCurrentValue[1] ? oType._aCurrentValue[1] : null; // if no unit set null
+				oCondition.values[0][1] = oType._aCurrentValue[1] ? oType._aCurrentValue[1] : null; // if no unit set null
 				if (oCondition.operator === "BT") {
 					oCondition.values[1][1] = sUnit;
 				}
 			}
-
-			_attachCurrentValueAtType.call(this, oCondition, oType);
-			_attachCurrentValueAtType.call(this, oCondition, oOriginalDateType);
 		}
 
+		_attachCurrentValueAtType.call(this, oCondition, oType);
+
 		return oCondition;
 
 	}
@@ -385,6 +424,8 @@ sap.ui.define([
 		var vCheckValue;
 		var vCheckParsedValue;
 		var oBindingContext = this.oFormatOptions.bindingContext;
+		var oConditionModel = this.oFormatOptions.conditionModel;
+		var sConditionModelName = this.oFormatOptions.conditionModelName;
 		var aValues;
 
 		if (vValue === "") {
@@ -410,8 +451,14 @@ sap.ui.define([
 
 			if (!oException._bNotUnique) { // TODO: better solution?
 				// not unique -> don't try to use default operator or search again
-				// key and description entered -> check now description
+				if (vValue === "") {
+					// empty string might be parsed to something else for check (e.g. 0000) -> if nothing found this is not an error
+					// no empty key -> no condition
+					return null;
+				}
+
 				if (bFirstCheck && aValues[0] && aValues[1]) {
+					// key and description entered -> check now description
 					return _parseDetermineKeyAndDescription.call(this, oOperator, vValue, oType, bUseDefaultOperator, bCheckForDefault, aOperators, sDisplay, false);
 				}
 
@@ -428,7 +475,12 @@ sap.ui.define([
 
 		var fnSuccess = function(oResult) {
 			if (oResult) {
-				return Condition.createCondition(oOperator.name, [oResult.key, oResult.description], oResult.inParameters, oResult.outParameters, ConditionValidated.Validated);
+				var aValues = [oResult.key];
+				if (oOperator.valueTypes.length > 1 && oOperator.valueTypes[1] !== Operator.ValueType.Static) {
+					// description is supported
+					aValues.push(oResult.description);
+				}
+				return Condition.createCondition(oOperator.name, aValues, oResult.inParameters, oResult.outParameters, ConditionValidated.Validated);
 			} else if (vValue === "") {
 				// no empty key -> no condition
 				return null;
@@ -438,9 +490,42 @@ sap.ui.define([
 			}
 		};
 
+		var iCallCount = this._oCalls.last;
+
+		var fnGetResult = function(vResult, fnCheck) {
+			var oCondition;
+			var oMyException;
+			try {
+				oCondition = fnCheck.call(this, vResult);
+				if (_isUnit(oType)) {
+					// create condition based on type
+					if (oCondition) {
+						if (oCondition.operator !== "EQ") {
+							throw new ParseException("unsupported operator");
+						}
+						var vNumber = oType._aCurrentValue && oType._aCurrentValue[0] !== undefined ? oType._aCurrentValue[0] : null; // undefined not valid for formatting, needs to be null
+						var sUnit = oCondition.values[0]; // use key of unit
+						oCondition.values = [[vNumber, sUnit]];
+					} else if (vValue === "") {
+						// create a condition if no unit is entered (use type to parse)
+						oCondition = Condition.createCondition(oOperator.name, [oType.parseValue(vValue, "string", oType._aCurrentValue)], undefined, undefined, ConditionValidated.NotValidated);
+					}
+				}
+			} catch (oException) {
+				oMyException = oException; // to store for pending async calls
+			}
+			return _returnResult.call(this, oCondition, oMyException, iCallCount, false, oType);
+		};
+
 		try {
-			vCheckParsedValue = oType.parseValue(vCheckValue, "string");
-			oType.validateValue(vCheckParsedValue);
+			if (_isUnit(oType)) {
+				vCheckParsedValue = oType.parseValue(vCheckValue, "string", oType._aCurrentValue);
+				oType.validateValue(vCheckParsedValue);
+				vCheckParsedValue = vCheckParsedValue[1]; // use unit part
+			} else {
+				vCheckParsedValue = oType.parseValue(vCheckValue, "string");
+				oType.validateValue(vCheckParsedValue);
+			}
 		} catch (oException) {
 			if (oException && !(oException instanceof ParseException) && !(oException instanceof ValidateException)) {// FormatException could also occur
 				// unknown error -> just raise it
@@ -452,20 +537,18 @@ sap.ui.define([
 		}
 
 		return SyncPromise.resolve().then(function() {
-			return _getItemForValue.call(this, vCheckValue, vCheckParsedValue, oBindingContext, bCheckKeyFirst, bCheckKey, bCheckDescription);
+			return _getItemForValue.call(this, vCheckValue, vCheckParsedValue, oBindingContext, bCheckKeyFirst, bCheckKey, bCheckDescription, oConditionModel, sConditionModelName);
 		}.bind(this)).then(function(oResult) {
-			var oCondition = fnSuccess.call(this, oResult);
-			return _finishParseFromString.call(this, oCondition, oType);
+			return fnGetResult.call(this, oResult, fnSuccess);
 		}.bind(this)).catch(function(oException) {
-			var oCondition = fnError.call(this, oException);
-			return _finishParseFromString.call(this, oCondition, oType);
+			return fnGetResult.call(this, oException, fnError);
 		}.bind(this)).unwrap();
 
 	}
 
 	function _parseUseDefaultOperator(oType, aOperators, vValue, sDisplay) {
 
-		var oOperator = FilterOperatorUtil.getDefaultOperator(_getBaseType.call(this, oType));
+		var oOperator = _getDefaultOperator.call(this, aOperators, oType);
 		var oCondition;
 
 		if (oOperator && aOperators.indexOf(oOperator.name) >= 0) {
@@ -482,12 +565,18 @@ sap.ui.define([
 		// Field accepts values that are not found -> must be checked by caller
 		// if user input fits to the type, let the caller validate it
 		var oOperator;
-		if (aOperators.length === 1) {
+		if (_isUnit(oType)) {
+			// in unit case just use EQ operator
+			oOperator = FilterOperatorUtil.getEQOperator("EQ");
+		} else if (aOperators.length === 1) {
 			// just use the one supported type
 			oOperator = FilterOperatorUtil.getOperator(aOperators[0]);
-		} else if (aOperators.indexOf("EQ") >= 0) {
+		} else {
 			// use EQ operator
-			oOperator = FilterOperatorUtil.getOperator("EQ");
+			oOperator = FilterOperatorUtil.getEQOperator(aOperators);
+			if (aOperators.indexOf(oOperator.name) < 0) { // as EQ is returned if not in List
+				oOperator = undefined;
+			}
 		}
 
 		if (!oOperator) {
@@ -495,7 +584,15 @@ sap.ui.define([
 		}
 
 		var oCondition = oOperator.getCondition(vValue, oType, FieldDisplay.Value, true); // use display format Value as entered string should used as it is
-		oCondition.validated = ConditionValidated.NotValidated;
+
+		if (oCondition) {
+			oCondition.validated = ConditionValidated.NotValidated;
+			if (_isUnit(oType) && Array.isArray(oCondition.values[0])) {
+				// user input is valid for type -> just return unit for further processing
+				oCondition.values[0] = oCondition.values[0][1];
+			}
+		}
+
 		return oCondition;
 
 	}
@@ -503,9 +600,9 @@ sap.ui.define([
 	ConditionType.prototype.validateValue = function(oCondition) {
 
 		var oType = _getValueType.call(this);
-		var oOriginalDateType = _getOriginalDateType.call(this);
+		var oOriginalType = _getOriginalType.call(this);
 		var aOperators = _getOperators.call(this);
-		var bIsUnit = this.oFormatOptions.isUnit;
+		var bIsUnit = _isUnit(oType);
 
 		if (oCondition === undefined || this._bDestroyed) { // if destroyed do nothing
 			return null;
@@ -514,9 +611,9 @@ sap.ui.define([
 			if (FilterOperatorUtil.onlyEQ(aOperators)) {
 				// TODO: also for FilterField case?
 				try {
-					if (oType._sParsedEmptyString === "") { //TODO: find solution for all types
-						// empty string is parsed as empty string, so validate for this
-						oType.validateValue("");
+					if (oType.hasOwnProperty("_sParsedEmptyString") && oType._sParsedEmptyString !== null) { //TODO: find solution for all types
+						// empty string is parsed as empty string or "0", so validate for this
+						oType.validateValue(oType._sParsedEmptyString);
 					} else {
 						oType.validateValue(null);
 					}
@@ -542,10 +639,6 @@ sap.ui.define([
 
 		if (bIsUnit) {
 			// only use unit in condition
-			oCondition = merge({}, oCondition);
-			if (oCondition.values[0] && Array.isArray(oCondition.values[0])) {
-				oCondition.values[0] = oCondition.values[0][1];
-			}
 			oOperator = FilterOperatorUtil.getEQOperator(); // as only EQ is allowed for unit
 		}
 
@@ -556,11 +649,11 @@ sap.ui.define([
 		try {
 			oOperator.validate(oCondition.values, oType);
 		} catch (oException) {
-			if (oException instanceof ValidateException && oOriginalDateType) {
+			if (oException instanceof ValidateException && oOriginalType) {
 				// As internal yyyy-MM-dd is used as pattern for dates (times similar) the
 				// ValidateException might contain this as pattern. The user should see the pattern thats shown
 				// So try to validate date with the original type to get ValidateException with right pattern.
-				oOperator.validate(oCondition.values, oOriginalDateType);
+				oOperator.validate(oCondition.values, oOriginalType);
 			}
 			throw oException;
 		}
@@ -583,22 +676,35 @@ sap.ui.define([
 		var oType = this.oFormatOptions.valueType;
 		if (!oType) {
 			// no type provided -> use string type as default
-			if (!this._oDefaultType) {
-				this._oDefaultType = new StringType();
-			}
-			oType = this._oDefaultType;
+			oType = _getDefaultType.call(this);
 		}
 
 		return oType;
 
 	}
 
-	function _getOriginalDateType() {
+	function _getDefaultType() {
+
+		if (!this._oDefaultType) {
+			this._oDefaultType = new StringType();
+		}
+
+		return this._oDefaultType;
+
+	}
+
+	function _getOriginalType() {
 
 		return this.oFormatOptions.originalDateType;
 
 	}
 
+	function _getAdditionalType() {
+
+		return this.oFormatOptions.additionalType;
+
+	}
+
 	function _getOperators() {
 
 		var aOperators = this.oFormatOptions.operators;
@@ -615,7 +721,7 @@ sap.ui.define([
 		var sID = this.oFormatOptions.fieldHelpID;
 		if (sID) {
 			var oFieldHelp = sap.ui.getCore().byId(sID);
-			if (oFieldHelp && oFieldHelp.isUsableForValidation()) {
+			if (oFieldHelp && oFieldHelp.isValidationSupported()) {
 				return oFieldHelp;
 			}
 		}
@@ -630,18 +736,50 @@ sap.ui.define([
 
 	}
 
+	function _isUnit(oType) {
+
+		if (_isCompositeType(oType)) {
+			var oFormatOptions = oType.getFormatOptions();
+			var bShowMeasure = !oFormatOptions || !oFormatOptions.hasOwnProperty("showMeasure") || oFormatOptions.showMeasure;
+			var bShowNumber = !oFormatOptions || !oFormatOptions.hasOwnProperty("showNumber") || oFormatOptions.showNumber;
+			if (bShowMeasure && !bShowNumber) {
+				return true;
+			}
+		}
+
+		return false;
+
+	}
+
 	function _attachCurrentValueAtType(oCondition, oType) {
 
 		if (_isCompositeType.call(this, oType) && oCondition && oCondition.values[0]) {
-				oType._aCurrentValue = oCondition.values[0];
+			oType._aCurrentValue = oCondition.values[0];
+
+			var oAdditionalType = _getAdditionalType.call(this);
+			if (_isCompositeType.call(this, oAdditionalType)) { // store in corresponding unit or measure type too
+				oAdditionalType._aCurrentValue = oCondition.values[0];
+			}
+
+			var oOriginalType = _getOriginalType.call(this);
+			if (_isCompositeType.call(this, oOriginalType)) { // store in original type too (Currently not used in Unit/Currency type, but basically in CompositeType for parsing)
+				oOriginalType._aCurrentValue = oCondition.values[0];
+			}
 		}
 
 	}
 
 	function _initCurrentValueAtType(oType) {
 
-		if (_isCompositeType.call(this, oType) && !oType._aCurrentValue) {
-				oType._aCurrentValue = [];
+		if (_isCompositeType.call(this, oType)) {
+			var oAdditionalType = _getAdditionalType.call(this);
+			if (_isCompositeType.call(this, oAdditionalType)) {
+				if (!oAdditionalType._aCurrentValue) {
+					oAdditionalType._aCurrentValue = [];
+				}
+
+				oType._aCurrentValue = oAdditionalType._aCurrentValue; // to use before entered corresponding number or unit
+			}
 		}
 
 	}
@@ -674,8 +812,8 @@ sap.ui.define([
 	function _getBaseType(oType) {
 
 		var sType = oType.getMetadata().getName();
-		var oFormatOptions = oType.oFormatOptions;
-		var oConstraints = oType.oConstraints;
+		var oFormatOptions = oType.getFormatOptions();
+		var oConstraints = oType.getConstraints();
 		var oDelegate = this.oFormatOptions.delegate;
 		var oPayload = this.oFormatOptions.payload;
 		var sBaseType = oDelegate ? oDelegate.getTypeUtil(oPayload).getBaseType(sType, oFormatOptions, oConstraints) : BaseType.String;
@@ -718,34 +856,75 @@ sap.ui.define([
 
 	}
 
-	function _getItemForValue(vValue, vParsedValue, oBindingContext, bCheckKeyFirst, bCheckKey, bCheckDescription) {
+	function _getItemForValue(vValue, vParsedValue, oBindingContext, bCheckKeyFirst, bCheckKey, bCheckDescription, oConditionModel, sConditionModelName) {
 
 		var oFieldHelp = _getFieldHelp.call(this);
 		var oDelegate = this.oFormatOptions.delegate;
 		var oPayload = this.oFormatOptions.payload;
+		var oConfig = {
+				value: vValue,
+				parsedValue: vParsedValue,
+				inParameters: undefined, // TODO: needed?
+				outParameters: undefined, // TODO: needed?
+				bindingContext: oBindingContext,
+				checkKeyFirst: bCheckKeyFirst, // TODO: not longer needed?
+				checkKey: bCheckKey,
+				checkDescription: bCheckDescription,
+				conditionModel: oConditionModel,
+				conditionModelName: sConditionModelName,
+				exception: ParseException
+		};
 
 		if (oDelegate) {
-			return oDelegate.getItemForValue(oPayload, oFieldHelp, vValue, vParsedValue, oBindingContext, bCheckKeyFirst, bCheckKey, bCheckDescription);
+//			return oDelegate.getItemForValue(oPayload, oFieldHelp, vValue, vParsedValue, oBindingContext, bCheckKeyFirst, bCheckKey, bCheckDescription, oConditionModel, sConditionModelName);
+			return oDelegate.getItemForValue(oPayload, oFieldHelp, oConfig);
 		} else if (oFieldHelp) {
-			return oFieldHelp.getItemForValue(vValue, vParsedValue, undefined, undefined, oBindingContext, bCheckKeyFirst, bCheckKey, bCheckDescription);
+//			return oFieldHelp.getItemForValue(vValue, vParsedValue, undefined, undefined, oBindingContext, bCheckKeyFirst, bCheckKey, bCheckDescription, oConditionModel, sConditionModelName);
+			return oFieldHelp.getItemForValue(oConfig);
 		}
 
 	}
 
-	function _getDescription(vKey, oInParameters, oOutParameters, oBindingContext) {
+	function _getDescription(vKey, oInParameters, oOutParameters, oBindingContext, oConditionModel, sConditionModelName) {
 
 		var oFieldHelp = _getFieldHelp.call(this);
 		var oDelegate = this.oFormatOptions.delegate;
 		var oPayload = this.oFormatOptions.payload;
 
 		if (oDelegate) {
-			return oDelegate.getDescription(oPayload, oFieldHelp, vKey, oInParameters, oOutParameters, oBindingContext);
+			return oDelegate.getDescription(oPayload, oFieldHelp, vKey, oInParameters, oOutParameters, oBindingContext, oConditionModel, sConditionModelName);
 		} else if (oFieldHelp) {
-			return oFieldHelp.getTextForKey(vKey, oInParameters, oOutParameters, oBindingContext);
+			return oFieldHelp.getTextForKey(vKey, oInParameters, oOutParameters, oBindingContext, oConditionModel, sConditionModelName);
 		}
 
 	}
 
+	function _getDefaultOperator(aOperators, oType) {
+
+		var sDefaultOperatorName = this.oFormatOptions.defaultOperatorName;
+		var oOperator;
+		if (sDefaultOperatorName) {
+			oOperator = FilterOperatorUtil.getOperator(sDefaultOperatorName);
+		} else {
+			oOperator = FilterOperatorUtil.getDefaultOperator(_getBaseType.call(this, oType));
+		}
+
+		if (oOperator && aOperators.indexOf(oOperator.name) < 0) {
+			// default operator not valid -> cannot use -> use first include-operator
+			for (var i = 0; i < aOperators.length; i++) {
+				oOperator = FilterOperatorUtil.getOperator(aOperators[i]);
+				if (oOperator.exclude || !oOperator.hasRequiredValues()) {
+					oOperator = undefined;
+				} else {
+					break;
+				}
+			}
+		}
+
+		return oOperator;
+
+	}
+
 	return ConditionType;
 
 });
