@@ -1,6 +1,6 @@
 /*
  * ! OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
@@ -16,10 +16,23 @@ sap.ui.define([
 	};
 
 	oChartItemFlex.findItem = function(oModifier, aItems, sName) {
-		return aItems.find(function(oItem) {
-			var sKey = oModifier.getProperty(oItem, "key");
-			return sKey === sName;
-		});
+		return aItems.reduce(function(oPreviousPromise, oItem) {
+			return oPreviousPromise
+				.then(function(oFoundItem) {
+					if (!oFoundItem) {
+						return Promise.all([
+							oModifier.getProperty(oItem, "key"),
+							oModifier.getProperty(oItem, "name") // for chart remake
+						])
+						.then(function(aProperties) {
+							if (aProperties[0] === sName || aProperties[1] === sName) {
+								return oItem;
+							}
+						});
+					}
+					return oFoundItem;
+				});
+		}, Promise.resolve());
 	};
 
 	oChartItemFlex.addItem = oChartItemFlex.createAddChangeHandler();
@@ -28,4 +41,4 @@ sap.ui.define([
 
 	return oChartItemFlex;
 
-});
+});
\ No newline at end of file
