@@ -1,34 +1,24 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
-
+/*eslint-disable max-len */
 // Provides an abstract property binding.
 sap.ui.define([
-	'sap/ui/base/DataType',
-	'./BindingMode',
-	'./ChangeReason',
-	'./PropertyBinding',
-	'./CompositeType',
-	'./CompositeDataState',
-	"sap/ui/base/SyncPromise",
-	"sap/base/util/deepEqual",
+	"./BindingMode",
+	"./ChangeReason",
+	"./CompositeDataState",
+	"./CompositeType",
+	"./Context",
+	"./PropertyBinding",
 	"sap/base/assert",
-	"sap/base/Log"
-],
-	function(
-		DataType,
-		BindingMode,
-		ChangeReason,
-		PropertyBinding,
-		CompositeType,
-		CompositeDataState,
-		SyncPromise,
-		deepEqual,
-		assert,
-		Log
-	) {
+	"sap/base/Log",
+	"sap/base/util/deepEqual",
+	"sap/ui/base/DataType",
+	"sap/ui/base/SyncPromise"
+], function(BindingMode, ChangeReason, CompositeDataState, CompositeType, Context, PropertyBinding,
+		assert, Log, deepEqual, DataType, SyncPromise) {
 	"use strict";
 
 
@@ -38,28 +28,31 @@ sap.ui.define([
 	 * @class
 	 * Combines multiple property bindings (called 'parts') into a single one.
 	 *
-	 * A <code>CompositeBinding</code> combines the values from all its binding parts (each an instance of
-	 * <code>PropertyBinding</code>), either by calling a formatter function or by involving a
-	 * {@link sap.ui.model.CompositeType composite type}. When a formatter function is used, then the
-	 * composite binding is automatically limited to <code>OneWay</code> mode. When a type is used, the binding
-	 * can also operate in <code>TwoWay</code> mode.
+	 * A <code>CompositeBinding</code> combines the values from all its binding parts (each an
+	 * instance of <code>PropertyBinding</code>), either by calling a formatter function or by
+	 * involving a {@link sap.ui.model.CompositeType composite type}. When a formatter function is
+	 * used, the composite binding is automatically limited to <code>OneWay</code> mode. When a
+	 * type is used, the binding can also operate in <code>TwoWay</code> mode.
 	 *
-	 * Higher layers of the framework derive composite bindings from easy-to-write string representations
-	 * (the following features require complex binding syntax, e.g. <code>data-sap-ui-bindingSyntax="complex"</code>):
+	 * Higher layers of the framework derive composite bindings from easy-to-write string
+	 * representations (the following features require complex binding syntax, e.g.
+	 * <code>data-sap-ui-bindingSyntax="complex"</code>):
 	 *
 	 * XML views, for example, convert attribute values with nested curly braces like
 	 * <pre>
 	 *   text="{fullname} &amp;lt;{email}&amp;gt;"
 	 * </pre>
-	 * into a composite binding with two parts (one property binding for property "fullname" and one for
-	 * property "email") and with a generic formatter function that injects the values of the parts into
-	 * the string literal "{0} &lt;{1}&gt;" accordingly.
+	 * into a composite binding with two parts (one property binding for property "fullname" and one
+	 * for property "email") and with a generic formatter function that injects the values of the
+	 * parts into the string literal "{0} &lt;{1}&gt;" accordingly.
 	 *
-	 * Similarly, {@link topic:daf6852a04b44d118963968a1239d2c0 expression bindings} are parsed and converted
-	 * into composite bindings, too. The formatter function is created by the framework and executes the
-	 * calculations as defined by the expression string, taking the values from the binding parts as input.
+	 * Similarly, {@link topic:daf6852a04b44d118963968a1239d2c0 expression bindings} are parsed and
+	 * converted into composite bindings, too. The formatter function is created by the framework
+	 * and executes the calculations as defined by the expression string, taking the values from the
+	 * binding parts as input.
 	 *
-	 * <b>Note:</b> A nesting of composite bindings is currently not supported (albeit being helpful).
+	 * <b>Note:</b> A nesting of composite bindings is currently not supported (albeit being
+	 * helpful).
 	 *
 	 * @see {@link topic:a2fe8e763014477e87990ff50657a0d0}
 	 * @public
@@ -95,10 +88,10 @@ sap.ui.define([
 	});
 
 	CompositeBinding.prototype.destroy = function() {
-		PropertyBinding.prototype.destroy.apply(this);
 		this.aBindings.forEach(function(oBinding) {
 			oBinding.destroy();
 		});
+		PropertyBinding.prototype.destroy.apply(this);
 	};
 
 	CompositeBinding.prototype.getPath = function() {
@@ -123,11 +116,14 @@ sap.ui.define([
 	};
 
 	/**
-	 * Sets the optional type and internal type for the binding. The type and internal type are used to do the parsing/formatting correctly.
-	 * The internal type is the property type of the element which the value is formatted to.
+	 * Sets the optional type and internal type for the binding. The type and internal type are used
+	 * to do the parsing/formatting correctly. The internal type is the property type of the element
+	 * which the value is formatted to.
 	 *
-	 * @param {sap.ui.model.CompositeType} oType the type for the binding
-	 * @param {string} sInternalType the internal type of the element property which this binding is bound against.
+	 * @param {sap.ui.model.CompositeType} oType
+	 *   The type for the binding
+	 * @param {string} sInternalType
+	 *   The internal type of the element property which this binding is bound against.
 	 *
 	 * @public
 	 */
@@ -160,23 +156,54 @@ sap.ui.define([
 	};
 
 	/**
-	 * sets the context for each property binding in this composite binding
-	 * @param {object} oContext the new context for the bindings
+	 * Sets the context for the property bindings of this composite binding which are either checked
+	 * thruthy via <code>mParameters.fnIsBindingRelevant</code> or whose model is the given
+	 * context's model.
+	 *
+	 * @param {sap.ui.model.Context} oContext
+	 *   The new context for the bindings
+	 * @param {Object<string,any>} [mParameters]
+	 *   Additional map of binding specific parameters
+	 * @param {function} [mParameters.fnIsBindingRelevant]
+	 *   A callback function that checks whether the given context needs to be propagated to a
+	 *   property binding of this composite binding. It gets the index of a property binding as
+	 *   parameter and returns whether the given context needs to be propagated to that property
+	 *   binding.
 	 */
-	CompositeBinding.prototype.setContext = function(oContext) {
-		this.aBindings.forEach(function(oBinding) {
-			// null context could also be set
-			if (!oContext || oBinding.updateRequired(oContext.getModel())) {
+	CompositeBinding.prototype.setContext = function (oContext, mParameters) {
+		var bCheckUpdate, bForceUpdate,
+			aBindings = this.aBindings,
+			oModel = oContext && oContext.getModel(),
+			fnIsBindingRelevant = mParameters && mParameters.fnIsBindingRelevant
+				? mParameters.fnIsBindingRelevant
+				: function (i) {
+					// check if oModel is given since a context's model may have been destroyed
+					return !oContext || oModel && oModel === aBindings[i].getModel();
+				};
+
+		aBindings.forEach(function (oBinding, i) {
+			var oBindingContext;
+
+			if (fnIsBindingRelevant(i)) {
+				oBindingContext = oBinding.getContext();
+				bCheckUpdate = bCheckUpdate
+					|| oBinding.isRelative() && Context.hasChanged(oBindingContext, oContext);
+				bForceUpdate = bForceUpdate || (bCheckUpdate && oBindingContext !== oContext);
+
 				oBinding.setContext(oContext);
 			}
 		});
+
+		if (bCheckUpdate) {
+			this.checkUpdate(bForceUpdate && this.getDataState().getControlMessages().length);
+		}
 	};
 
 	/**
 	 * Sets the values. This will cause the setValue to be called for each nested binding, except
 	 * for undefined values in the array.
 	 *
-	 * @param {array} aValues the values to set for this binding
+	 * @param {array} aValues The values to set for this binding
 	 *
 	 * @public
 	 */
@@ -197,7 +224,7 @@ sap.ui.define([
 	/**
 	 * Returns the raw values of the property bindings in an array.
 	 *
-	 * @return {object} the values of the internal property bindings in an array
+	 * @return {object} The values of the internal property bindings in an array
 	 *
 	 * @public
 	 */
@@ -214,9 +241,10 @@ sap.ui.define([
 	};
 
 	/**
-	 * Returns the current external value of the bound target which is formatted via a type or formatter function.
+	 * Returns the current external value of the bound target which is formatted via a type or
+	 * formatter function.
 	 *
-	 * @return {object} the current value of the bound target
+	 * @return {object} The current value of the bound target
 	 *
 	 * @throws {sap.ui.model.FormatException}
 	 *
@@ -254,11 +282,15 @@ sap.ui.define([
 	};
 
 	/**
-	 * Sets the external value of a composite binding. If no CompositeType is assigned to the binding, the default
-	 * implementation assumes a space separated list of values. This will cause the setValue to be called for each
-	 * nested binding, except for undefined values in the array.
+	 * Sets the external value of a composite binding. If no CompositeType is assigned to the
+	 * binding, the default implementation assumes a space-separated list of values. This will cause
+	 * the setValue to be called for each nested binding, except for undefined values in the array.
 	 *
-	 * @param {object} oValue the value to set for this binding
+	 * @param {object} oValue The value to set for this binding
+	 * @return {undefined|Promise} A promise in case of asynchronous type parsing or validation
+	 *
+	 * @throws sap.ui.model.ParseException
+	 * @throws sap.ui.model.ValidateException
 	 *
 	 * @public
 	 */
@@ -268,10 +300,10 @@ sap.ui.define([
 
 		if (this.sInternalType === "raw") {
 			this.setRawValue(oValue);
-			return;
+			return undefined;
 		} else if (this.sInternalType === "internal") {
 			this.setInternalValue(oValue);
-			return;
+			return undefined;
 		}
 
 		oInternalType = this.sInternalType && DataType.getType(this.sInternalType);
@@ -279,7 +311,7 @@ sap.ui.define([
 		// No twoway binding when using formatters
 		if (this.fnFormatter) {
 			Log.warning("Tried to use twoway binding, but a formatter function is used");
-			return;
+			return undefined;
 		}
 
 		oDataState = this.getDataState();
@@ -334,10 +366,10 @@ sap.ui.define([
 	};
 
 	/**
-	 * Returns the current internal value of the bound target which is an array of the
-	 * internal (JS native) values of nested bindings
+	 * Returns the current internal value of the bound target which is an array of the internal (JS
+	 * native) values of nested bindings.
 	 *
-	 * @return {array} the current values of the nested bindings
+	 * @return {array} The current values of the nested bindings
 	 *
 	 * @public
 	 */
@@ -348,10 +380,11 @@ sap.ui.define([
 	};
 
 	/**
-	 * Sets the internal value of the bound target. Parameter must be an array of
-	 * values matching the internal (JS native) types of nested bindings.
+	 * Sets the internal value of the bound target. Parameter must be an array of values matching
+	 * the internal (JS native) types of nested bindings.
 	 *
 	 * @param {array} aValues the new values of the nested bindings
+	 * @return {undefined|Promise} A promise in case of asynchronous type parsing or validation
 	 *
 	 * @public
 	 */
@@ -397,10 +430,10 @@ sap.ui.define([
 	};
 
 	/**
-	 * Returns the current raw value of the bound target which is an array of the
-	 * raw (model) values of nested bindings
+	 * Returns the current raw value of the bound target which is an array of the raw (model)
+	 * values of nested bindings.
 	 *
-	 * @return {array} the current values of the nested bindings
+	 * @return {array} The current values of the nested bindings
 	 *
 	 * @public
 	 */
@@ -411,10 +444,11 @@ sap.ui.define([
 	};
 
 	/**
-	 * Sets the raw value of the bound target. Parameter must be an array of
-	 * values matching the raw (model) types of nested bindings.
+	 * Sets the raw value of the bound target. Parameter must be an array of values matching the raw
+	 * (model) types of nested bindings.
 	 *
 	 * @param {array} aValues the new values of the nested bindings
+	 * @return {undefined|Promise} A promise in case of asynchronous type parsing or validation
 	 *
 	 * @public
 	 */
@@ -486,6 +520,7 @@ sap.ui.define([
 	 * method always gets the full set of values to validate, even if partial updates are
 	 * used.
 	 *
+	 * @param {any[]} aValues Values to fill empty current values with
 	 * @return {array} Array of values used for validation
 	 *
 	 * @private
@@ -508,7 +543,7 @@ sap.ui.define([
 	/**
 	 * Returns the property bindings contained in this composite binding.
 	 *
-	 * @return {array} the property bindings in this composite binding
+	 * @return {array} The property bindings in this composite binding
 	 *
 	 * @public
 	 */
@@ -516,11 +551,11 @@ sap.ui.define([
 		return this.aBindings;
 	};
 
-
 	/**
 	 * {@see sap.ui.model.Binding#hasValidation}
 	 *
-	 * @returns {boolean} Returns true if the binding throws a validation exception when an invalid value is set on it.
+	 * @returns {boolean}
+	 *   Whether the binding throws a validation exception when an invalid value is set on it
 	 * @private
 	 */
 	CompositeBinding.prototype.hasValidation = function() {
@@ -546,11 +581,12 @@ sap.ui.define([
 	 * Attaches event handler <code>fnFunction</code> to the <code>change</code> event of this
 	 * <code>sap.ui.model.CompositeBinding</code>.
 	 *
-	 * When called, the context of the event handler (its <code>this</code>) will be bound to <code>oListener</code>
-	 * if specified, otherwise it will be bound to this <code>sap.ui.model.CompositeBinding</code> itself.
+	 * When called, the context of the event handler (its <code>this</code>) will be bound to
+	 * <code>oListener</code> if specified, otherwise it will be bound to this
+	 * <code>sap.ui.model.CompositeBinding</code> itself.
 	 *
 	 * @param {function} fnFunction The function to be called, when the event occurs
-	 * @param {object} [oListener] object on which to call the given function
+	 * @param {object} [oListener] Object on which to call the given function
 	 * @protected
 	 */
 	CompositeBinding.prototype.attachChange = function(fnFunction, oListener) {
@@ -581,7 +617,7 @@ sap.ui.define([
 	 * <code>sap.ui.model.CompositeBinding</code>.
 	 *
 	 * @param {function} fnFunction The function to be called, when the event occurs
-	 * @param {object} [oListener] object on which to call the given function
+	 * @param {object} [oListener] Object on which to call the given function
 	 * @protected
 	 */
 	CompositeBinding.prototype.detachChange = function(fnFunction, oListener) {
@@ -595,14 +631,15 @@ sap.ui.define([
 	};
 
 	/**
-	 * Attaches event handler <code>fnFunction</code> to the <code>DataStateChange</code> event of this
-	 * <code>sap.ui.model.CompositeBinding</code>.
+	 * Attaches event handler <code>fnFunction</code> to the <code>DataStateChange</code> event of
+	 * this <code>sap.ui.model.CompositeBinding</code>.
 	 *
-	 * When called, the context of the event handler (its <code>this</code>) will be bound to <code>oListener</code>
-	 * if specified, otherwise it will be bound to this <code>sap.ui.model.CompositeBinding</code> itself.
+	 * When called, the context of the event handler (its <code>this</code>) will be bound to
+	 * <code>oListener</code> if specified, otherwise it will be bound to this
+	 * <code>sap.ui.model.CompositeBinding</code> itself.
 	 *
 	 * @param {function} fnFunction The function to be called, when the event occurs
-	 * @param {object} [oListener] object on which to call the given function
+	 * @param {object} [oListener] Object on which to call the given function
 	 * @protected
 	 */
 	CompositeBinding.prototype.attachDataStateChange = function(fnFunction, oListener) {
@@ -628,7 +665,7 @@ sap.ui.define([
 	 * this <code>sap.ui.model.CompositeBinding</code>.
 	 *
 	 * @param {function} fnFunction The function to be called, when the event occurs
-	 * @param {object} [oListener] object on which to call the given function
+	 * @param {object} [oListener] Object on which to call the given function
 	 * @protected
 	 */
 	CompositeBinding.prototype.detachDataStateChange = function(fnFunction, oListener) {
@@ -642,15 +679,15 @@ sap.ui.define([
 	};
 
 	/**
-	 * Attaches event handler <code>fnFunction</code> to the <code>AggregatedDataStateChange</code> event of this
-	 * <code>sap.ui.model.CompositeBinding</code>.
+	 * Attaches event handler <code>fnFunction</code> to the <code>AggregatedDataStateChange</code>
+	 * event of this <code>sap.ui.model.CompositeBinding</code>.
 	 *
-	 * The <code>AggregatedDataStateChange</code> event is fired asynchronously, meaning that the <code>DataState</code>
-	 * object given as parameter of the event contains all changes that were applied to the <code>DataState</code>
-	 * in the running thread.
+	 * The <code>AggregatedDataStateChange</code> event is fired asynchronously, meaning that the
+	 * <code>DataState</code> object given as parameter of the event contains all changes that were
+	 * applied to the <code>DataState</code> in the running thread.
 	 *
 	 * @param {function} fnFunction The function to be called, when the event occurs
-	 * @param {object} [oListener] object on which to call the given function.
+	 * @param {object} [oListener] Object on which to call the given function
 	 * @protected
 	 */
 	CompositeBinding.prototype.attachAggregatedDataStateChange = function(fnFunction, oListener) {
@@ -676,11 +713,12 @@ sap.ui.define([
 	};
 
 	/**
-	 * Detaches event handler <code>fnFunction</code> from the <code>AggregatedDataStateChange</code>
-	 * event of this <code>sap.ui.model.CompositeBinding</code>.
+	 * Detaches event handler <code>fnFunction</code> from the
+	 * <code>AggregatedDataStateChange</code> event of this
+	 * <code>sap.ui.model.CompositeBinding</code>.
 	 *
 	 * @param {function} fnFunction The function to be called, when the event occurs
-	 * @param {object} [oListener] object on which to call the given function
+	 * @param {object} [oListener] Object on which to call the given function
 	 * @protected
 	 */
 	CompositeBinding.prototype.detachAggregatedDataStateChange = function(fnFunction, oListener) {
@@ -693,11 +731,12 @@ sap.ui.define([
 		}
 	};
 
-
 	/**
-	 * Determines if the property bindings in the composite binding should be updated by calling updateRequired on all property bindings with the specified model.
+	 * Determines if the property bindings in the composite binding should be updated by calling
+	 * updateRequired on all property bindings with the specified model.
+	 *
 	 * @param {object} oModel The model instance to compare against
-	 * @returns {boolean} true if this binding should be updated
+	 * @returns {boolean} Whether this binding should be updated
 	 * @protected
 	 */
 	CompositeBinding.prototype.updateRequired = function(oModel) {
@@ -711,9 +750,11 @@ sap.ui.define([
 	/**
 	 * Initialize the binding. The method should be called when creating a binding.
 	 * The default implementation calls checkUpdate(true).
-	 * Prevent checkUpdate to be triggered while initializing nestend bindings, it is
+	 * Prevent checkUpdate to be triggered while initializing nested bindings, it is
 	 * sufficient to call checkUpdate when all nested bindings are initialized.
 	 *
+	 * @returns {this} A reference to itself
+	 *
 	 * @protected
 	 */
 	CompositeBinding.prototype.initialize = function() {
@@ -732,8 +773,9 @@ sap.ui.define([
 
 
 	/**
-	 * Returns the data state for this binding
-	 * @return {sap.ui.model.CompositeDataState} the data state
+	 * Returns the data state for this binding.
+	 *
+	 * @return {sap.ui.model.CompositeDataState} The data state
 	 */
 	CompositeBinding.prototype.getDataState = function() {
 		if (!this.oDataState) {
@@ -747,9 +789,11 @@ sap.ui.define([
 	/**
 	 * Suspends the binding update. No change events will be fired.
 	 *
-	 * A refresh call with bForceUpdate set to true will also update the binding and fire a change in suspended mode.
-	 * Special operations on bindings, which require updates to work properly (as paging or filtering in list bindings)
-	 * will also update and cause a change event although the binding is suspended.
+	 * A refresh call with bForceUpdate set to true will also update the binding and fire a change
+	 * in suspended mode. Special operations on bindings, which require updates to work properly
+	 * (as paging or filtering in list bindings) will also update and cause a change event although
+	 * the binding is suspended.
+	 *
 	 * @public
 	 */
 	CompositeBinding.prototype.suspend = function() {
@@ -762,9 +806,11 @@ sap.ui.define([
 	/**
 	 * Suspends the binding update. No change events will be fired.
 	 *
-	 * A refresh call with bForceUpdate set to true will also update the binding and fire a change in suspended mode.
-	 * Special operations on bindings, which require updates to work properly (as paging or filtering in list bindings)
-	 * will also update and cause a change event although the binding is suspended.
+	 * A refresh call with bForceUpdate set to true will also update the binding and fire a change
+	 * in suspended mode. Special operations on bindings, which require updates to work properly
+	 * (as paging or filtering in list bindings) will also update and cause a change event although
+	 * the binding is suspended.
+	 *
 	 * @public
 	 */
 	CompositeBinding.prototype.resume = function() {
@@ -779,7 +825,7 @@ sap.ui.define([
 	 * Check whether this Binding would provide new values and in case it changed,
 	 * inform interested parties about this.
 	 *
-	 * @param {boolean} bForceupdate
+	 * @param {boolean} bForceUpdate Whether an update should be forced
 	 *
 	 */
 	CompositeBinding.prototype.checkUpdate = function(bForceUpdate){
@@ -818,5 +864,4 @@ sap.ui.define([
 	};
 
 	return CompositeBinding;
-
 });
\ No newline at end of file
