@@ -1,19 +1,19 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
 //Provides mixin sap.ui.model.odata.v4.ODataParentBinding for classes extending sap.ui.model.Binding
 //with dependent bindings
 sap.ui.define([
+	"./Context",
 	"./ODataBinding",
-	"./SubmitMode",
 	"./lib/_Helper",
 	"sap/base/Log",
 	"sap/ui/base/SyncPromise",
 	"sap/ui/model/ChangeReason"
-], function (asODataBinding, SubmitMode, _Helper, Log, SyncPromise, ChangeReason) {
+], function (Context, asODataBinding, _Helper, Log, SyncPromise, ChangeReason) {
 	"use strict";
 
 	/**
@@ -34,6 +34,8 @@ sap.ui.define([
 		// auto-$expand/$select: promises to wait until child bindings have provided
 		// their path and query options
 		this.aChildCanUseCachePromises = [];
+		// whether the binding has a child with a path to the parent binding via path reduction
+		this.bHasPathReductionToParent = false;
 		// counts the sent but not yet completed PATCHes
 		this.iPatchCounter = 0;
 		// whether all sent PATCHes have been successfully processed
@@ -80,9 +82,10 @@ sap.ui.define([
 	 *   The new value which must be primitive
 	 * @param {sap.ui.model.odata.v4.lib._GroupLock} [oGroupLock]
 	 *   A lock for the group ID to be used for the PATCH request; without a lock, no PATCH is sent
-	 * @returns {sap.ui.base.SyncPromise} <code>undefined</code> for the general case which is
-	 *   handled generically by the caller {@link sap.ui.model.odata.v4.ODataContext#doSetProperty}
-	 *   or a <code>SyncPromise</code> for the exceptional case
+	 * @returns {sap.ui.base.SyncPromise|undefined}
+	 *   <code>undefined</code> for the general case which is handled generically by the caller
+	 *   {@link sap.ui.model.odata.v4.Context#doSetProperty} or a <code>SyncPromise</code> for the
+	 *   exceptional case
 	 *
 	 * @abstract
 	 * @function
@@ -90,6 +93,15 @@ sap.ui.define([
 	 * @private
 	 */
 
+	/**
+	 * Binding specific code for suspend.
+	 *
+	 * @private
+	 */
+	ODataParentBinding.prototype.doSuspend = function () {
+		// nothing to do here
+	};
+
 	/**
 	 * Fire event 'patchCompleted' to attached listeners, if the last PATCH request is completed.
 	 *
@@ -188,8 +200,8 @@ sap.ui.define([
 	 */
 	ODataParentBinding.prototype.aggregateQueryOptions = function (mQueryOptions, sBaseMetaPath,
 			bCacheImmutable) {
-		var mAggregatedQueryOptionsClone
-				= _Helper.merge({}, this.mAggregatedQueryOptions, this.mLateQueryOptions),
+		var mAggregatedQueryOptionsClone = _Helper.merge({},
+				bCacheImmutable && this.mLateQueryOptions || this.mAggregatedQueryOptions),
 			bChanged = false,
 			that = this;
 
@@ -200,10 +212,9 @@ sap.ui.define([
 		 * @param {object} mQueryOptions0 The query options to merge into the aggregated query
 		 *   options
 		 * @param {string} sMetaPath The meta path for the current $expand
-		 * @param {boolean} [bInsideExpand=false] Whether the given query options are inside a
-		 *   $expand
-		 * @param {boolean} [bAdd=false] Whether to add the given query options because they are in
-		 *   a $expand that has not been aggregated yet
+		 * @param {boolean} [bInsideExpand] Whether the given query options are inside a $expand
+		 * @param {boolean} [bAdd] Whether to add the given query options because they are in a
+		 * $expand that has not been aggregated yet
 		 * @returns {boolean} Whether the query options can be fulfilled by this binding
 		 */
 		function merge(mAggregatedQueryOptions, mQueryOptions0, sMetaPath, bInsideExpand, bAdd) {
@@ -253,23 +264,23 @@ sap.ui.define([
 				// merge $count, $expand and $select; check that all others equal the aggregate
 				&& Object.keys(mQueryOptions0).every(function (sName) {
 					switch (sName) {
-					case "$count":
-						if (mQueryOptions0.$count) {
-							mAggregatedQueryOptions.$count = true;
-						}
-						return true;
-					case "$expand":
-						mAggregatedQueryOptions.$expand = mAggregatedQueryOptions.$expand || {};
-						return Object.keys(mQueryOptions0.$expand).every(mergeExpandPath);
-					case "$select":
-						mAggregatedQueryOptions.$select = mAggregatedQueryOptions.$select || [];
-						return mQueryOptions0.$select.every(mergeSelectPath);
-					default:
-						if (bAdd) {
-							mAggregatedQueryOptions[sName] = mQueryOptions0[sName];
+						case "$count":
+							if (mQueryOptions0.$count) {
+								mAggregatedQueryOptions.$count = true;
+							}
 							return true;
-						}
-						return mQueryOptions0[sName] === mAggregatedQueryOptions[sName];
+						case "$expand":
+							mAggregatedQueryOptions.$expand = mAggregatedQueryOptions.$expand || {};
+							return Object.keys(mQueryOptions0.$expand).every(mergeExpandPath);
+						case "$select":
+							mAggregatedQueryOptions.$select = mAggregatedQueryOptions.$select || [];
+							return mQueryOptions0.$select.every(mergeSelectPath);
+						default:
+							if (bAdd) {
+								mAggregatedQueryOptions[sName] = mQueryOptions0[sName];
+								return true;
+							}
+							return mQueryOptions0[sName] === mAggregatedQueryOptions[sName];
 					}
 				});
 		}
@@ -288,8 +299,8 @@ sap.ui.define([
 	/**
 	 * Changes this binding's parameters and refreshes the binding.
 	 *
-	 * If there are pending changes an error is thrown. Use {@link #hasPendingChanges} to check if
-	 * there are pending changes. If there are changes, call
+	 * If there are pending changes that cannot be ignored, an error is thrown. Use
+	 * {@link #hasPendingChanges} to check if there are such pending changes. If there are, call
 	 * {@link sap.ui.model.odata.v4.ODataModel#submitBatch} to submit the changes or
 	 * {@link sap.ui.model.odata.v4.ODataModel#resetChanges} to reset the changes before calling
 	 * {@link #changeParameters}.
@@ -302,9 +313,14 @@ sap.ui.define([
 	 *   Map of binding parameters, see {@link sap.ui.model.odata.v4.ODataModel#bindList} and
 	 *   {@link sap.ui.model.odata.v4.ODataModel#bindContext}
 	 * @throws {Error}
-	 *   If there are pending changes or if <code>mParameters</code> is missing, contains
-	 *   binding-specific or unsupported parameters, contains unsupported values, or contains the
-	 *   property "$expand" or "$select" when the model is in auto-$expand/$select mode.
+	 *   If there are pending changes that cannot be ignored or if <code>mParameters</code> is
+	 *   missing, contains binding-specific or unsupported parameters, contains unsupported values,
+	 *   or contains the property "$expand" or "$select" when the model is in auto-$expand/$select
+	 *   mode. Since 1.90.0, binding-specific parameters are ignored if they are unchanged. Since
+	 *   1.93.0, string values for "$expand" and "$select" are ignored if they are unchanged;
+	 *   pending changes are ignored if all parameters are unchanged. Since 1.97.0, pending changes
+	 *   are ignored if they relate to a
+	 *   {@link sap.ui.model.odata.v4.Context#setKeepAlive kept-alive} context of this binding.
 	 *
 	 * @public
 	 * @since 1.45.0
@@ -315,14 +331,6 @@ sap.ui.define([
 			sKey,
 			that = this;
 
-		function checkExpandSelect(sName) {
-			if (that.oModel.bAutoExpandSelect && sName in mParameters) {
-				throw new Error("Cannot change $expand or $select parameter in "
-					+ "auto-$expand/$select mode: "
-					+ sName + "=" + JSON.stringify(mParameters[sName]));
-			}
-		}
-
 		/*
 		 * Updates <code>sChangeReason</code> depending on the given custom or system query option
 		 * name:
@@ -334,8 +342,16 @@ sap.ui.define([
 		 *
 		 * @param {string} sName
 		 *   The name of a custom or system query option
+		 * @throws {Error}
+		 *   If name is "$expand" or "$select" when the model is in auto-$expand/$select mode
 		 */
 		function updateChangeReason(sName) {
+			if (that.oModel.bAutoExpandSelect && (sName === "$expand" || sName === "$select")) {
+				throw new Error("Cannot change " + sName
+					+ " parameter in auto-$expand/$select mode: "
+					+ JSON.stringify(mParameters[sName])
+					+ " !== " + JSON.stringify(mBindingParameters[sName]));
+			}
 			if (sName === "$filter" || sName === "$search") {
 				sChangeReason = ChangeReason.Filter;
 			} else if (sName === "$orderby" && sChangeReason !== ChangeReason.Filter) {
@@ -348,14 +364,12 @@ sap.ui.define([
 		if (!mParameters) {
 			throw new Error("Missing map of binding parameters");
 		}
-		checkExpandSelect("$expand");
-		checkExpandSelect("$select");
-		if (this.hasPendingChanges()) {
-			throw new Error("Cannot change parameters due to pending changes");
-		}
 
 		for (sKey in mParameters) {
 			if (sKey.startsWith("$$")) {
+				if (mParameters[sKey] === mBindingParameters[sKey]) {
+					continue; // ignore unchanged binding-specific parameters
+				}
 				throw new Error("Unsupported parameter: " + sKey);
 			}
 			if (mParameters[sKey] === undefined && mBindingParameters[sKey] !== undefined) {
@@ -372,6 +386,9 @@ sap.ui.define([
 		}
 
 		if (sChangeReason) {
+			if (this.hasPendingChanges(true)) {
+				throw new Error("Cannot change parameters due to pending changes");
+			}
 			this.applyParameters(mBindingParameters, sChangeReason);
 		}
 	};
@@ -396,7 +413,7 @@ sap.ui.define([
 	 *
 	 * @returns {sap.ui.base.SyncPromise}
 	 *   A promise resolving without a defined result when the check is finished, or rejecting in
-	 *   case of an error (e.g. thrown by the change event handler of a control)
+	 *   case of an error
 	 * @throws {Error} If called with parameters
 	 *
 	 * @private
@@ -419,7 +436,7 @@ sap.ui.define([
 		return this.oCachePromise.then(function (oCache) {
 			if (oCache && that.bRelative) {
 				return that.fetchResourcePath(that.oContext).then(function (sResourcePath) {
-					if (oCache.$resourcePath === sResourcePath) {
+					if (oCache.getResourcePath() === sResourcePath) {
 						return updateDependents();
 					}
 					return that.refreshInternal(""); // entity of context changed
@@ -431,17 +448,17 @@ sap.ui.define([
 
 	/**
 	 * Creates the entity in the cache. If the binding doesn't have a cache, it forwards to the
-	 * parent binding adjusting <code>sPathInCache</code>.
+	 * parent binding.
 	 *
 	 * @param {sap.ui.model.odata.v4.lib._GroupLock} oUpdateGroupLock
 	 *   The group ID to be used for the POST request
 	 * @param {string|sap.ui.base.SyncPromise} vCreatePath
 	 *   The path for the POST request or a SyncPromise that resolves with that path
-	 * @param {string} sPathInCache
-	 *   The path within the cache where to create the entity
+	 * @param {string} sCollectionPath
+	 *   The absolute path to the collection in the cache where to create the entity
 	 * @param {string} sTransientPredicate
 	 *   A (temporary) key predicate for the transient entity: "($uid=...)"
-	 * @param {object} oInitialData
+	 * @param {object} [oInitialData={}]
 	 *   The initial data for the created entity
 	 * @param {function} fnErrorCallback
 	 *   A function which is called with an error object each time a POST request for the create
@@ -455,25 +472,28 @@ sap.ui.define([
 	 * @private
 	 */
 	ODataParentBinding.prototype.createInCache = function (oUpdateGroupLock, vCreatePath,
-			sPathInCache, sTransientPredicate, oInitialData, fnErrorCallback, fnSubmitCallback) {
+			sCollectionPath, sTransientPredicate, oInitialData, fnErrorCallback, fnSubmitCallback) {
 		var that = this;
 
 		return this.oCachePromise.then(function (oCache) {
+			var sPathInCache;
+
 			if (oCache) {
+				sPathInCache = _Helper.getRelativePath(sCollectionPath, that.getResolvedPath());
 				return oCache.create(oUpdateGroupLock, vCreatePath, sPathInCache,
 					sTransientPredicate, oInitialData, fnErrorCallback, fnSubmitCallback
 				).then(function (oCreatedEntity) {
-					if (oCache.$resourcePath) {
+					if (that.mCacheByResourcePath) {
 						// Ensure that cache containing non-transient created entity is recreated
 						// when the parent binding changes to another row and back again.
-						delete that.mCacheByResourcePath[oCache.$resourcePath];
+						delete that.mCacheByResourcePath[oCache.getResourcePath()];
 					}
 					return oCreatedEntity;
 				});
 			}
 			return that.oContext.getBinding().createInCache(oUpdateGroupLock, vCreatePath,
-				_Helper.buildPath(that.oContext.iIndex, that.sPath, sPathInCache),
-				sTransientPredicate, oInitialData, fnErrorCallback, fnSubmitCallback);
+				sCollectionPath, sTransientPredicate, oInitialData, fnErrorCallback,
+				fnSubmitCallback);
 		});
 	};
 
@@ -545,46 +565,41 @@ sap.ui.define([
 	 * Deletes the entity in the cache. If the binding doesn't have a cache, it forwards to the
 	 * parent binding adjusting the path.
 	 *
-	 * @param {sap.ui.model.odata.v4.lib._GroupLock} oGroupLock
-	 *   A lock for the group ID to be used for the DELETE request; if no group ID is specified, it
-	 *   defaults to <code>getUpdateGroupId()</code>()
+	 * @param {sap.ui.model.odata.v4.lib._GroupLock} [oGroupLock]
+	 *   A lock for the group ID to be used for the DELETE request; w/o a lock, no DELETE is sent.
+	 *   For a transient entity, the lock is ignored (use NULL)!
 	 * @param {string} sEditUrl
-	 *   The edit URL to be used for the DELETE request
+	 *   The entity's edit URL to be used for the DELETE request;  w/o a lock, this is mostly
+	 *   ignored.
 	 * @param {string} sPath
 	 *   The path of the entity relative to this binding
 	 * @param {object} [oETagEntity]
 	 *   An entity with the ETag of the binding for which the deletion was requested. This is
 	 *   provided if the deletion is delegated from a context binding with empty path to a list
-	 *   binding.
+	 *   binding. W/o a lock, this is ignored.
+	 * @param {boolean} [bDoNotRequestCount]
+	 *   Whether not to request the new count from the server; useful in case of
+	 *   {@link sap.ui.model.odata.v4.Context#replaceWith} where it is known that the count remains
+	 *   unchanged; w/o a lock this should be true
 	 * @param {function} fnCallback
-	 *   A function which is called after the entity has been deleted from the server and from the
-	 *   cache; the index of the entity is passed as parameter
+	 *   A function which is called after a transient entity has been deleted from the cache or
+	 *   after the entity has been deleted from the server and from the cache; the index of the
+	 *   entity and the entity list are both passed as parameter, or none of them
 	 * @returns {sap.ui.base.SyncPromise}
 	 *   A promise which is resolved without a result in case of success, or rejected with an
-	 *   instance of <code>Error</code> in case of failure
+	 *   instance of <code>Error</code> in case of failure; returns <code>undefined</code> if the
+	 *   cache promise for this binding is not yet fulfilled
 	 * @throws {Error}
-	 *   If the group ID has {@link sap.ui.model.odata.v4.SubmitMode.Auto} or if the cache promise
-	 *   for this binding is not yet fulfilled
+	 *   If the cache is shared
 	 *
 	 * @private
 	 */
 	ODataParentBinding.prototype.deleteFromCache = function (oGroupLock, sEditUrl, sPath,
-			oETagEntity, fnCallback) {
-		var sGroupId;
-
-		if (this.oCache === undefined) {
-			throw new Error("DELETE request not allowed");
-		}
-
-		if (this.oCache) {
-			sGroupId = oGroupLock.getGroupId();
-			if (!this.oModel.isAutoGroup(sGroupId) && !this.oModel.isDirectGroup(sGroupId)) {
-				throw new Error("Illegal update group ID: " + sGroupId);
-			}
-			return this.oCache._delete(oGroupLock, sEditUrl, sPath, oETagEntity, fnCallback);
-		}
-		return this.oContext.getBinding().deleteFromCache(oGroupLock, sEditUrl,
-			_Helper.buildPath(this.oContext.iIndex, this.sPath, sPath), oETagEntity, fnCallback);
+			oETagEntity, bDoNotRequestCount, fnCallback) {
+		return this.withCache(function (oCache, sCachePath) {
+			return oCache._delete(oGroupLock, sEditUrl, sCachePath, oETagEntity, bDoNotRequestCount,
+				fnCallback);
+		}, sPath, /*bSync*/true);
 	};
 
 	/**
@@ -614,37 +629,38 @@ sap.ui.define([
 	 * removing these two navigation properties from the path.
 	 *
 	 * @param {sap.ui.model.odata.v4.Context} oContext
-	 *   The child binding's context, must not be <code>null</code> or <code>undefined</code>. See
-	 *   <code>sap.ui.model.odata.v4.ODataBinding#fetchQueryOptionsForOwnCache</code>.
+	 *   A context of this binding which is the direct or indirect parent of the child binding.
+	 *   Initially it is the child binding's parent context (See
+	 *   {@link sap.ui.model.odata.v4.ODataBinding#fetchQueryOptionsForOwnCache}). When a binding
+	 *   delegates up to its parent binding, it passes its own parent context adjusting
+	 *   <code>sChildPath</code> accordingly.
 	 * @param {string} sChildPath
 	 *   The child binding's binding path relative to <code>oContext</code>
-	 * @param {sap.ui.base.SyncPromise} oChildQueryOptionsPromise
-	 *   Promise resolving with the child binding's (aggregated) query options
+	 * @param {object|sap.ui.base.SyncPromise} vChildQueryOptions
+	 *   The child binding's (aggregated) query options or a promise resolving with them
 	 * @returns {sap.ui.base.SyncPromise}
 	 *   A promise resolved with the reduced path for the child binding if the child binding can use
-	 *   this binding's or an ancestor binding's cache; <code>undefined</code> otherwise.
+	 *   this binding's or an ancestor binding's cache; resolved with <code>undefined</code>
+	 *   otherwise.
 	 *
 	 * @private
 	 * @see sap.ui.model.odata.v4.ODataMetaModel#getReducedPath
 	 */
 	ODataParentBinding.prototype.fetchIfChildCanUseCache = function (oContext, sChildPath,
-			oChildQueryOptionsPromise) {
+			vChildQueryOptions) {
 		// getBaseForPathReduction must be called early, because the (virtual) parent context may be
 		// lost again when the path is needed
 		var sBaseForPathReduction = this.getBaseForPathReduction(),
-			sBaseMetaPath,
+			sBaseMetaPath = _Helper.getMetaPath(oContext.getPath()),
 			bCacheImmutable,
 			oCanUseCachePromise,
-			sFullMetaPath,
+			// whether this binding is an operation or depends on one
+			bDependsOnOperation = oContext.getPath().includes("(...)"),
+			iIndex = oContext.getIndex(),
 			bIsAdvertisement = sChildPath[0] === "#",
 			oMetaModel = this.oModel.getMetaModel(),
 			aPromises,
 			sResolvedChildPath = this.oModel.resolve(sChildPath, oContext),
-			sResolvedPath = oContext.iReturnValueContextId
-				? oContext.getPath()
-				: this.oModel.resolve(this.sPath, this.oContext),
-			// whether this binding is an operation or depends on one
-			bDependsOnOperation = sResolvedPath.indexOf("(...)") >= 0,
 			that = this;
 
 		/*
@@ -658,12 +674,27 @@ sap.ui.define([
 			if (bIsAdvertisement) {
 				// Ensure entity type metadata is loaded even for advertisement so that sync access
 				// to key properties is possible
-				return oMetaModel.fetchObject(sFullMetaPath.slice(0,
-					sFullMetaPath.lastIndexOf("/") + 1));
+				return oMetaModel.fetchObject(sBaseMetaPath + "/");
 			}
 
 			return _Helper.fetchPropertyAndType(that.oModel.oInterface.fetchMetadata,
-				sFullMetaPath);
+				getStrippedMetaPath(sResolvedChildPath));
+		}
+
+		/*
+		 * Returns the meta path corresponding to the given path, with its annotation part stripped
+		 * off.
+		 *
+		 * @param {string} sPath - A path
+		 * @returns {string} The meta path with its annotation part stripped off
+		 */
+		function getStrippedMetaPath(sPath) {
+			var iIndex;
+
+			sPath = _Helper.getMetaPath(sPath);
+			iIndex = sPath.indexOf("@"); // Note: sPath[0] !== "@"
+
+			return iIndex > 0 ? sPath.slice(0, iIndex) : sPath;
 		}
 
 		if (bDependsOnOperation && !sResolvedChildPath.includes("/$Parameter/")
@@ -678,24 +709,24 @@ sap.ui.define([
 		// Note: this.oCachePromise exists for all bindings except operation bindings; it might
 		// become pending again
 		bCacheImmutable = this.oCachePromise.isRejected()
+			|| iIndex !== undefined && iIndex !== Context.VIRTUAL
+			|| oContext.isKeepAlive() // kept-alive contexts have no index when not in aContexts
 			|| this.oCache === null
 			|| this.oCache && this.oCache.hasSentRequest();
-		sBaseMetaPath = oMetaModel.getMetaPath(oContext.getPath());
-		sFullMetaPath = oMetaModel.getMetaPath(sResolvedChildPath);
 		aPromises = [
 			this.doFetchQueryOptions(this.oContext),
 			// After access to complete meta path of property, the metadata of all prefix paths
 			// is loaded so that synchronous access in wrapChildQueryOptions via getObject is
 			// possible
 			fetchPropertyAndType(),
-			oChildQueryOptionsPromise
+			vChildQueryOptions
 		];
 		oCanUseCachePromise = SyncPromise.all(aPromises).then(function (aResult) {
-			var sChildMetaPath,
-				mChildQueryOptions = aResult[2],
+			var mChildQueryOptions = aResult[2],
 				mWrappedChildQueryOptions,
 				mLocalQueryOptions = aResult[0],
 				oProperty = aResult[1],
+				sReducedChildMetaPath,
 				sReducedPath;
 
 			if (Array.isArray(oProperty)) { // Arrays are only used for functions and actions
@@ -704,41 +735,40 @@ sap.ui.define([
 			}
 
 			sReducedPath = oMetaModel.getReducedPath(sResolvedChildPath, sBaseForPathReduction);
+			sReducedChildMetaPath = _Helper.getRelativePath(getStrippedMetaPath(sReducedPath),
+				sBaseMetaPath);
 
-			if (sChildPath === "$count" || sChildPath.endsWith("/$count")
-					|| sChildPath[0] === "@") {
-				return SyncPromise.resolve(sReducedPath);
-			}
-
-			if (_Helper.getRelativePath(sReducedPath, sResolvedPath) === undefined) {
+			if (sReducedChildMetaPath === undefined) {
+				// the child's data does not fit into this bindings's cache, try the parent
+				that.bHasPathReductionToParent = true;
 				return that.oContext.getBinding().fetchIfChildCanUseCache(that.oContext,
 					_Helper.getRelativePath(sResolvedChildPath, that.oContext.getPath()),
-					oChildQueryOptionsPromise);
+					vChildQueryOptions);
 			}
 
-			if (bDependsOnOperation) {
-				return SyncPromise.resolve(sReducedPath);
+			if (bDependsOnOperation || sReducedChildMetaPath === "$count"
+					|| sReducedChildMetaPath.endsWith("/$count")) {
+				return sReducedPath;
 			}
 
-			sChildMetaPath = _Helper.getRelativePath(_Helper.getMetaPath(sReducedPath),
-				sBaseMetaPath);
 			if (that.bAggregatedQueryOptionsInitial) {
 				that.selectKeyProperties(mLocalQueryOptions, sBaseMetaPath);
 				that.mAggregatedQueryOptions = _Helper.clone(mLocalQueryOptions);
 				that.bAggregatedQueryOptionsInitial = false;
 			}
 			if (bIsAdvertisement) {
-				mWrappedChildQueryOptions = {"$select" : [sChildMetaPath.slice(1)]};
+				mWrappedChildQueryOptions = {$select : [sReducedChildMetaPath.slice(1)]};
 				return that.aggregateQueryOptions(mWrappedChildQueryOptions, sBaseMetaPath,
 						bCacheImmutable)
 					? sReducedPath
 					: undefined;
 			}
-			if (sChildMetaPath === ""
+			if (sReducedChildMetaPath === ""
 				|| oProperty
 				&& (oProperty.$kind === "Property" || oProperty.$kind === "NavigationProperty")) {
 				mWrappedChildQueryOptions = _Helper.wrapChildQueryOptions(sBaseMetaPath,
-					sChildMetaPath, mChildQueryOptions, that.oModel.oInterface.fetchMetadata);
+					sReducedChildMetaPath, mChildQueryOptions,
+					that.oModel.oInterface.fetchMetadata);
 				if (mWrappedChildQueryOptions) {
 					return that.aggregateQueryOptions(mWrappedChildQueryOptions, sBaseMetaPath,
 							bCacheImmutable)
@@ -747,21 +777,21 @@ sap.ui.define([
 				}
 				return undefined;
 			}
-			if (sChildMetaPath === "value") { // symbolic name for operation result
+			if (sReducedChildMetaPath === "value") { // symbolic name for operation result
 				return that.aggregateQueryOptions(mChildQueryOptions, sBaseMetaPath,
 						bCacheImmutable)
 					? sReducedPath
 					: undefined;
 			}
 			Log.error("Failed to enhance query options for auto-$expand/$select as the path '"
-					+ sFullMetaPath + "' does not point to a property",
+					+ sResolvedChildPath + "' does not point to a property",
 				JSON.stringify(oProperty), sClassName);
 			return undefined;
 		}).then(function (sReducedPath) {
 			if (that.mLateQueryOptions) {
 				if (that.oCache) {
 					that.oCache.setLateQueryOptions(that.mLateQueryOptions);
-				} else {
+				} else if (that.oCache === null) {
 					return that.oContext.getBinding().fetchIfChildCanUseCache(that.oContext,
 						that.sPath, SyncPromise.resolve(that.mLateQueryOptions))
 						.then(function (sPath) {
@@ -793,7 +823,7 @@ sap.ui.define([
 		// catch the error, but keep the rejected promise
 		this.oCachePromise.catch(function (oError) {
 			that.oModel.reportError(that + ": Failed to enhance query options for "
-				+ "auto-$expand/$select for child " + sChildPath,  sClassName, oError);
+				+ "auto-$expand/$select for child " + sChildPath, sClassName, oError);
 		});
 		return oCanUseCachePromise;
 	};
@@ -833,7 +863,7 @@ sap.ui.define([
 						sMetaPath, sSelectPath, {}, fnFetchMetadata);
 
 				if (mWrappedQueryOptions) {
-					_Helper.aggregateQueryOptions(mConvertedQueryOptions, mWrappedQueryOptions);
+					_Helper.aggregateExpandSelect(mConvertedQueryOptions, mWrappedQueryOptions);
 				} else {
 					_Helper.addToSelect(mConvertedQueryOptions, [sSelectPath]);
 				}
@@ -860,25 +890,42 @@ sap.ui.define([
 			oParentBinding = this.oContext.getBinding();
 			sParentUpdateGroupId = oParentBinding.getUpdateGroupId();
 			if (sParentUpdateGroupId === this.getUpdateGroupId()
-					|| this.oModel.getGroupProperty(sParentUpdateGroupId, "submit")
-						!== SubmitMode.API) {
+					|| !this.oModel.isApiGroup(sParentUpdateGroupId)) {
 				return oParentBinding.getBaseForPathReduction();
 			}
 		}
-		return this.oModel.resolve(this.sPath, this.oContext);
+		return this.getResolvedPath();
 	};
 
 	/**
-	 * Returns the query options used in the cache.
+	 * Returns the query options that can be inherited from this binding, including late query
+	 * options.
 	 *
-	 * @returns {object} The query options
+	 * @returns {object} The inheritable query options
 	 *
 	 * @private
 	 */
-	ODataParentBinding.prototype.getCacheQueryOptions = function () {
+	ODataParentBinding.prototype.getInheritableQueryOptions = function () {
+		if (this.mLateQueryOptions) {
+			return _Helper.merge({}, this.mCacheQueryOptions, this.mLateQueryOptions);
+		}
+
 		return this.mCacheQueryOptions
 			|| _Helper.getQueryOptionsForPath(
-				this.oContext.getBinding().getCacheQueryOptions(), this.sPath);
+				this.oContext.getBinding().getInheritableQueryOptions(), this.sPath);
+	};
+
+	/**
+	 * Returns the unique number of this bindings's generation, or <code>0</code> if it does not
+	 * belong to any specific generation. This number can be inherited from a parent context.
+	 *
+	 * @returns {number}
+	 *   The unique number of this binding's generation, or <code>0</code>
+	 *
+	 * @private
+	 */
+	ODataParentBinding.prototype.getGeneration = function () {
+		return this.bRelative && this.oContext.getGeneration && this.oContext.getGeneration() || 0;
 	};
 
 	/**
@@ -942,13 +989,14 @@ sap.ui.define([
 	 * @override
 	 * @see sap.ui.model.odata.v4.ODataBinding#hasPendingChangesInDependents
 	 */
-	ODataParentBinding.prototype.hasPendingChangesInDependents = function () {
-		var aDependents = this.getDependentBindings();
-
-		return aDependents.some(function (oDependent) {
+	ODataParentBinding.prototype.hasPendingChangesInDependents = function (bIgnoreKeptAlive) {
+		return this.getDependentBindings().some(function (oDependent) {
 			var oCache = oDependent.oCache,
 				bHasPendingChanges;
 
+			if (bIgnoreKeptAlive && oDependent.oContext.isKeepAlive()) {
+				return false;
+			}
 			if (oCache !== undefined) {
 				// Pending changes for this cache are only possible when there is a cache already
 				if (oCache && oCache.hasPendingChangesForPath("")) {
@@ -960,7 +1008,10 @@ sap.ui.define([
 			if (oDependent.mCacheByResourcePath) {
 				bHasPendingChanges = Object.keys(oDependent.mCacheByResourcePath)
 					.some(function (sPath) {
-						return oDependent.mCacheByResourcePath[sPath].hasPendingChangesForPath("");
+						var oCacheForPath = oDependent.mCacheByResourcePath[sPath];
+
+						return oCacheForPath !== oCache // don't ask again
+							&& oCacheForPath.hasPendingChangesForPath("");
 					});
 				if (bHasPendingChanges) {
 					return true;
@@ -970,7 +1021,7 @@ sap.ui.define([
 			return oDependent.hasPendingChangesInDependents();
 		})
 		|| this.oModel.withUnresolvedBindings("hasPendingChangesInCaches",
-				this.oModel.resolve(this.sPath, this.oContext).slice(1));
+				this.getResolvedPath().slice(1));
 	};
 
 	/**
@@ -1010,9 +1061,11 @@ sap.ui.define([
 	 * @param {boolean} [bKeepCacheOnError]
 	 *   If <code>true</code>, the binding data remains unchanged if the refresh fails
 	 * @returns {sap.ui.base.SyncPromise}
-	 *   A promise resolving when all dependent bindings are refreshed; it is rejected if the
-	 *   binding's root binding is suspended and a group ID different from the binding's group ID is
-	 *   given
+	 *   A promise resolving when all dependent bindings are refreshed; it is rejected
+	 *   when the refresh fails; the promise is resolved immediately on a suspended binding
+	 * @throws {Error}
+	 *   If the binding's root binding is suspended and a group ID different from the binding's
+	 *   group ID is given
 	 *
 	 * @private
 	 */
@@ -1028,7 +1081,11 @@ sap.ui.define([
 	 * Recursively refreshes all dependent list bindings that have no own cache.
 	 *
 	 * @returns {sap.ui.base.SyncPromise}
-	 *   A promise resolving when all dependent list bindings without own cache are refreshed
+	 *   A promise resolving when all dependent list bindings without own cache are refreshed; it is
+	 *   rejected when the refresh fails; the promise is resolved immediately on a suspended binding
+	 * @throws {Error}
+	 *   If the binding's root binding is suspended and a group ID different from the binding's
+	 *   group ID is given
 	 *
 	 * @private
 	 */
@@ -1056,60 +1113,6 @@ sap.ui.define([
 		}
 	};
 
-	/**
-	 * Refreshes the binding; expects it to be suspended.
-	 *
-	 * @param {string} sGroupId
-	 *   The group ID to be used for the refresh
-	 * @throws {Error}
-	 *   If a group ID different from the binding's group ID is given
-
-	 * @private
-	 */
-	ODataParentBinding.prototype.refreshSuspended = function (sGroupId) {
-		if (sGroupId && sGroupId !== this.getGroupId()) {
-			throw new Error(this + ": Cannot refresh a suspended binding with group ID '"
-				+ sGroupId  + "' (own group ID is '" + this.getGroupId() + "')");
-		}
-		this.setResumeChangeReason(ChangeReason.Refresh);
-	};
-
-	/**
-	 * Requests side effects for the given absolute paths.
-	 *
-	 * @param {string} sGroupId
-	 *   The effective group ID
-	 * @param {string[]} aAbsolutePaths
-	 *   The absolute paths to request side effects for
-	 * @returns {sap.ui.base.SyncPromise}
-	 *   A promise resolving without a defined result, or rejecting with an error if loading of side
-	 *   effects fails, or <code>undefined</code> if there is nothing to do
-	 *
-	 * @private
-	 */
-	ODataParentBinding.prototype.requestAbsoluteSideEffects = function (sGroupId, aAbsolutePaths) {
-		var aPaths = [],
-			sMetaPath = _Helper.getMetaPath(this.oModel.resolve(this.sPath, this.oContext)),
-			bRefresh;
-
-		bRefresh = aAbsolutePaths.some(function (sAbsolutePath) {
-			var sRelativePath = _Helper.getRelativePath(sAbsolutePath, sMetaPath);
-
-			if (sRelativePath !== undefined) {
-				aPaths.push(sRelativePath);
-			}
-
-			return _Helper.hasPathPrefix(sMetaPath, sAbsolutePath);
-		});
-
-		if (bRefresh) {
-			return this.refreshInternal("", sGroupId);
-		} else if (aPaths.length) {
-			return this.requestSideEffects(sGroupId, aPaths);
-		}
-		// return undefined;
-	};
-
 	/**
 	 * Loads side effects for the given context of this binding.
 	 *
@@ -1178,20 +1181,24 @@ sap.ui.define([
 	 */
 
 	/**
-	 * Resolves and clears the refresh promise created by {@link #createRefreshPromise} with the
-	 * given result if there is one.
+	 * If there is a refresh promise created by {@link #createRefreshPromise}, it is resolved with
+	 * the given promise and cleared. Does not reject the refresh promise with a canceled error.
 	 *
-	 * @param {any} vResult - The result to resolve with
-	 * @returns {any} vResult for chaining
+	 * @param {Promise} oPromise - The promise to resolve with
+	 * @returns {Promise} oPromise for chaining
 	 *
 	 * @private
 	 */
-	ODataParentBinding.prototype.resolveRefreshPromise = function (vResult) {
+	ODataParentBinding.prototype.resolveRefreshPromise = function (oPromise) {
 		if (this.oRefreshPromise) {
-			this.oRefreshPromise.$resolve(vResult);
+			this.oRefreshPromise.$resolve(oPromise.catch(function (oError) {
+				if (!oError.canceled) {
+					throw oError;
+				}
+			}));
 			this.oRefreshPromise = null;
 		}
-		return vResult;
+		return oPromise;
 	};
 
 	/**
@@ -1247,10 +1254,16 @@ sap.ui.define([
 	 * Before 1.53.0, this method was not supported and threw an error.
 	 *
 	 * @throws {Error}
-	 *   If this binding is relative to a {@link sap.ui.model.odata.v4.Context} or if it is an
-	 *   operation binding or if it is not suspended
+	 *   If this binding
+	 *   <ul>
+	 *   <li>is relative to a {@link sap.ui.model.odata.v4.Context},</li>
+	 *   <li>is an operation binding,</li>
+	 *   <li>has {@link sap.ui.model.Binding#isSuspended} set to <code>false</code>,</li>
+	 *   <li>is not a root binding. Use {@link #getRootBinding} to determine the root binding.</li>
+	 *   </ul>
 	 *
 	 * @public
+	 * @see {@link topic:b0f5c531e5034a27952cc748954cbe39 Suspend and Resume}
 	 * @see sap.ui.model.Binding#resume
 	 * @see #suspend
 	 * @since 1.37.0
@@ -1298,14 +1311,23 @@ sap.ui.define([
 
 	/**
 	 * Suspends this binding. A suspended binding does not fire change events nor does it trigger
-	 * data service requests. Call {@link #resume} to resume the binding.
-	 * Before 1.53.0, this method was not supported and threw an error.
+	 * data service requests. Call {@link #resume} to resume the binding. Before 1.53.0, this method
+	 * was not supported and threw an error. Since 1.97.0, pending changes are ignored if they
+	 * relate to a {@link sap.ui.model.odata.v4.Context#setKeepAlive kept-alive} context of this
+	 * binding.
 	 *
 	 * @throws {Error}
-	 *   If this binding is relative to a {@link sap.ui.model.odata.v4.Context} or if it is an
-	 *   operation binding or if it is already suspended or if it has pending changes
+	 *   If this binding
+	 *  <ul>
+	 *   <li>is relative to a {@link sap.ui.model.odata.v4.Context},</li>
+	 *   <li>is an operation binding,</li>
+	 *   <li>has {@link sap.ui.model.Binding#isSuspended} set to <code>true</code>,</li>
+	 *   <li>has pending changes that cannot be ignored,</li>
+	 *   <li>is not a root binding. Use {@link #getRootBinding} to determine the root binding.</li>
+	 *   </ul>
 	 *
 	 * @public
+	 * @see {@link topic:b0f5c531e5034a27952cc748954cbe39 Suspend and Resume}
 	 * @see sap.ui.model.Binding#suspend
 	 * @see sap.ui.model.odata.v4.ODataContextBinding#hasPendingChanges
 	 * @see sap.ui.model.odata.v4.ODataListBinding#hasPendingChanges
@@ -1325,16 +1347,17 @@ sap.ui.define([
 		if (this.bSuspended) {
 			throw new Error("Cannot suspend a suspended binding: " + this);
 		}
-		if (this.hasPendingChanges()) {
+		if (this.hasPendingChanges(true)) {
 			throw new Error("Cannot suspend a binding with pending changes: " + this);
 		}
 
 		this.bSuspended = true;
-		this.oResumePromise = new SyncPromise(function (resolve, reject) {
+		this.oResumePromise = new SyncPromise(function (resolve) {
 			fnResolve = resolve;
 		});
 		this.oResumePromise.$resolve = fnResolve;
 		this.removeReadGroupLock();
+		this.doSuspend();
 	};
 
 	/**
@@ -1409,16 +1432,15 @@ sap.ui.define([
 		}
 	}
 
-	// #doDeregisterChangeListener is still not final, allow for "super" calls
-	asODataParentBinding.prototype.doDeregisterChangeListener
-		= ODataParentBinding.prototype.doDeregisterChangeListener;
-	// #destroy is still not final, allow for "super" calls
-	asODataParentBinding.prototype.destroy = ODataParentBinding.prototype.destroy;
-	// #fetchCache is still not final, allow for "super" calls
-	asODataParentBinding.prototype.fetchCache = ODataParentBinding.prototype.fetchCache;
-	// #hasPendingChangesForPath is still not final, allow for "super" calls
-	asODataParentBinding.prototype.hasPendingChangesForPath
-		= ODataParentBinding.prototype.hasPendingChangesForPath;
+	[
+		"adjustPredicate",
+		"destroy",
+		"doDeregisterChangeListener",
+		"getGeneration",
+		"hasPendingChangesForPath"
+	].forEach(function (sMethod) { // method (still) not final, allow for "super" calls
+		asODataParentBinding.prototype[sMethod] = ODataParentBinding.prototype[sMethod];
+	});
 
 	return asODataParentBinding;
-}, /* bExport= */ false);
\ No newline at end of file
+}, /* bExport= */ false);
