@@ -1,6 +1,6 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
@@ -17,9 +17,10 @@ sap.ui.define([
 	/**
 	 * Creates the base class for the metadata converters.
 	 *
+	 * @alias sap.ui.model.odata.v4.lib._MetadataConverter
 	 * @constructor
 	 */
-	function MetadataConverter() {
+	function _MetadataConverter() {
 		this.aliases = {}; // maps alias -> namespace
 		this.oAnnotatable = null; // the current annotatable, see function annotatable
 		this.entityContainer = null; // the current EntityContainer
@@ -37,11 +38,11 @@ sap.ui.define([
 	/**
 	 * A pattern for "Collection(QualifiedType)"
 	 */
-	MetadataConverter.prototype.rCollection = /^Collection\((.*)\)$/;
+	_MetadataConverter.prototype.rCollection = /^Collection\((.*)\)$/;
 
 	// namespaces
-	MetadataConverter.prototype.sEdmNamespace = "http://docs.oasis-open.org/odata/ns/edm";
-	MetadataConverter.prototype.sEdmxNamespace = "http://docs.oasis-open.org/odata/ns/edmx";
+	_MetadataConverter.prototype.sEdmNamespace = "http://docs.oasis-open.org/odata/ns/edm";
+	_MetadataConverter.prototype.sEdmxNamespace = "http://docs.oasis-open.org/odata/ns/edmx";
 
 	/**
 	 * Adds a name/value pair with the given qualified name and given value to the result. Warns
@@ -52,7 +53,7 @@ sap.ui.define([
 	 * @param {any} vValue
 	 *   Value
 	 */
-	MetadataConverter.prototype.addToResult = function (sQualifiedName, vValue) {
+	_MetadataConverter.prototype.addToResult = function (sQualifiedName, vValue) {
 		if (sQualifiedName in this.result) {
 			Log.warning("Duplicate qualified name " + sQualifiedName, undefined, sClassName);
 		}
@@ -73,7 +74,7 @@ sap.ui.define([
 	 * @param {string} [sQualifier]
 	 *   The qualifier for all annotations
 	 */
-	MetadataConverter.prototype.annotatable = function (vTarget, sPrefix, sQualifier) {
+	_MetadataConverter.prototype.annotatable = function (vTarget, sPrefix, sQualifier) {
 		var oAnnotatable,
 			oAnnotations,
 			sPath;
@@ -114,7 +115,7 @@ sap.ui.define([
 	 * @returns {object}
 	 *   The metadata JSON
 	 */
-	MetadataConverter.prototype.convertXMLMetadata = function (oDocument, sUrl) {
+	_MetadataConverter.prototype.convertXMLMetadata = function (oDocument, sUrl) {
 		var oElement;
 
 		Measurement.average("convertXMLMetadata", "",
@@ -158,8 +159,8 @@ sap.ui.define([
 	 * @returns {any}
 	 *   The value for the JSON
 	 */
-	MetadataConverter.prototype.getAnnotationValue = function (sType, sValue) {
-		var i, vValue, aValues;
+	_MetadataConverter.prototype.getAnnotationValue = function (sType, sValue) {
+		var vValue, aValues, i;
 
 		switch (sType) {
 			case "AnnotationPath":
@@ -209,11 +210,11 @@ sap.ui.define([
 	 * @returns {any}
 	 *   The value for the JSON
 	 */
-	MetadataConverter.prototype.getInlineAnnotationValue = function (oElement) {
+	_MetadataConverter.prototype.getInlineAnnotationValue = function (oElement) {
 		var oAttribute,
 			oAttributeList = oElement.attributes,
-			i,
-			vValue;
+			vValue,
+			i;
 
 		// check the last attribute first, this is typically the one with the annotation value
 		for (i = oAttributeList.length - 1; i >= 0; i -= 1) {
@@ -233,7 +234,7 @@ sap.ui.define([
 	 * @param {string} sProperty The property name
 	 * @returns {any[]} The array at the given property
 	 */
-	MetadataConverter.prototype.getOrCreateArray = function (oParent, sProperty) {
+	_MetadataConverter.prototype.getOrCreateArray = function (oParent, sProperty) {
 		var oResult = oParent[sProperty];
 
 		if (!oResult) {
@@ -249,7 +250,7 @@ sap.ui.define([
 	 * @param {string} sProperty The property name
 	 * @returns {object} The object at the given property
 	 */
-	MetadataConverter.prototype.getOrCreateObject = function (oParent, sProperty) {
+	_MetadataConverter.prototype.getOrCreateObject = function (oParent, sProperty) {
 		var oResult = oParent[sProperty];
 
 		if (!oResult) {
@@ -265,12 +266,12 @@ sap.ui.define([
 	 * @param {Element} oElement The element
 	 * @param {any[]} aResult The results from child elements
 	 */
-	MetadataConverter.prototype.postProcessAnnotation = function (oElement, aResult) {
+	_MetadataConverter.prototype.postProcessAnnotation = function (oElement, aResult) {
 		// this.oAnnotatable is the Annotation itself currently.
 		var oAnnotatable = this.oAnnotatable.parent;
 
-		oAnnotatable.target[oAnnotatable.qualifiedName] =
-			aResult.length ? aResult[0] : this.getInlineAnnotationValue(oElement);
+		oAnnotatable.target[oAnnotatable.qualifiedName]
+			= aResult.length ? aResult[0] : this.getInlineAnnotationValue(oElement);
 	};
 
 	/**
@@ -280,7 +281,7 @@ sap.ui.define([
 	 * @param {any[]} aResult The results from child elements
 	 * @returns {object} The value for the JSON
 	 */
-	MetadataConverter.prototype.postProcessApply = function (oElement, aResult) {
+	_MetadataConverter.prototype.postProcessApply = function (oElement, aResult) {
 		var oResult = this.oAnnotatable.target;
 
 		oResult.$Apply = aResult;
@@ -295,7 +296,7 @@ sap.ui.define([
 	 * @param {any[]} aResult The results from child elements
 	 * @returns {object} The value for the JSON
 	 */
-	MetadataConverter.prototype.postProcessCastOrIsOf = function (oElement, aResult) {
+	_MetadataConverter.prototype.postProcessCastOrIsOf = function (oElement, aResult) {
 		var sName = oElement.localName,
 			oResult = this.oAnnotatable.target;
 
@@ -308,11 +309,11 @@ sap.ui.define([
 	/**
 	 * Post-processing of a Collection element.
 	 *
-	 * @param {Element} oElement The element
+	 * @param {Element} _oElement The element
 	 * @param {any[]} aResult The results from child elements
 	 * @returns {object} The value for the JSON
 	 */
-	MetadataConverter.prototype.postProcessCollection = function (oElement, aResult) {
+	_MetadataConverter.prototype.postProcessCollection = function (_oElement, aResult) {
 		return aResult;
 	};
 
@@ -323,11 +324,12 @@ sap.ui.define([
 	 * @param {any[]} aResult The results from child elements
 	 * @returns {any} The value for the JSON
 	 */
-	MetadataConverter.prototype.postProcessLabeledElement = function (oElement, aResult) {
+	_MetadataConverter.prototype.postProcessLabeledElement = function (oElement, aResult) {
 		var oResult = this.oAnnotatable.target;
 
-		oResult.$LabeledElement = aResult.length ? aResult[0] :
-			this.getInlineAnnotationValue(oElement);
+		oResult.$LabeledElement = aResult.length
+			? aResult[0]
+			: this.getInlineAnnotationValue(oElement);
 		oResult.$Name = oElement.getAttribute("Name");
 		return oResult;
 	};
@@ -336,12 +338,12 @@ sap.ui.define([
 	 * Post-processing of a LabeledElementReference element within an Annotation element.
 	 *
 	 * @param {Element} oElement The element
-	 * @param {any[]} aResult The results from child elements
+	 * @param {any[]} _aRes The results from child elements
 	 * @returns {any} The value for the JSON
 	 */
-	MetadataConverter.prototype.postProcessLabeledElementReference = function (oElement, aResult) {
+	_MetadataConverter.prototype.postProcessLabeledElementReference = function (oElement, _aRes) {
 		return {
-			"$LabeledElementReference" : this.resolveAlias(oElement.textContent)
+			$LabeledElementReference : this.resolveAlias(oElement.textContent)
 		};
 	};
 
@@ -349,21 +351,21 @@ sap.ui.define([
 	 * Post-processing of a leaf element within an Annotation element.
 	 *
 	 * @param {Element} oElement The element
-	 * @param {any[]} aResult The results from child elements
+	 * @param {any[]} _aResult The results from child elements
 	 * @returns {any} The constant value for the JSON
 	 */
-	MetadataConverter.prototype.postProcessLeaf = function (oElement, aResult) {
+	_MetadataConverter.prototype.postProcessLeaf = function (oElement, _aResult) {
 		return this.getAnnotationValue(oElement.localName, oElement.textContent);
 	};
 
 	/**
 	 * Post-processing of a Not element within an Annotation element.
 	 *
-	 * @param {Element} oElement The element
+	 * @param {Element} _oElement The element
 	 * @param {any[]} aResult The results from child elements
 	 * @returns {object} The value for the JSON
 	 */
-	MetadataConverter.prototype.postProcessNot = function (oElement, aResult) {
+	_MetadataConverter.prototype.postProcessNot = function (_oElement, aResult) {
 		var oResult = this.oAnnotatable.target;
 
 		oResult.$Not = aResult[0];
@@ -373,11 +375,11 @@ sap.ui.define([
 	/**
 	 * Post-processing of a Null element within an Annotation element.
 	 *
-	 * @param {Element} oElement The element
-	 * @param {any[]} aResult The results from child elements
+	 * @param {Element} _oElement The element
+	 * @param {any[]} _aResult The results from child elements
 	 * @returns {object} The value for the JSON
 	 */
-	MetadataConverter.prototype.postProcessNull = function (oElement, aResult) {
+	_MetadataConverter.prototype.postProcessNull = function (_oElement, _aResult) {
 		var oAnnotatable = this.oAnnotatable,
 			vResult = null;
 
@@ -395,7 +397,7 @@ sap.ui.define([
 	 * @param {any[]} aResult The results from child elements
 	 * @returns {object} The value for the JSON
 	 */
-	MetadataConverter.prototype.postProcessOperation = function (oElement, aResult) {
+	_MetadataConverter.prototype.postProcessOperation = function (oElement, aResult) {
 		var oResult = this.oAnnotatable.target;
 
 		oResult["$" + oElement.localName] = aResult;
@@ -409,7 +411,7 @@ sap.ui.define([
 	 * @param {any[]} aResult The results from child elements
 	 * @returns {any} The value for the JSON
 	 */
-	MetadataConverter.prototype.postProcessPropertyValue = function (oElement, aResult) {
+	_MetadataConverter.prototype.postProcessPropertyValue = function (oElement, aResult) {
 		return {
 			property : oElement.getAttribute("Property"),
 			value : aResult.length ? aResult[0] : this.getInlineAnnotationValue(oElement)
@@ -423,11 +425,11 @@ sap.ui.define([
 	 * @param {any[]} aResult The results from child elements
 	 * @returns {object} The value for the JSON
 	 */
-	MetadataConverter.prototype.postProcessRecord = function (oElement, aResult) {
-		var i,
-			oPropertyValue,
+	_MetadataConverter.prototype.postProcessRecord = function (oElement, aResult) {
+		var oPropertyValue,
 			oResult = this.oAnnotatable.target,
-			oType = oElement.getAttribute("Type");
+			oType = oElement.getAttribute("Type"),
+			i;
 
 		if (oType) {
 			oResult.$Type = this.resolveAlias(oType);
@@ -442,11 +444,11 @@ sap.ui.define([
 	/**
 	 * Post-processing of a UrlRef element within an Annotation element.
 	 *
-	 * @param {Element} oElement The element
+	 * @param {Element} _oElement The element
 	 * @param {any[]} aResult The results from child elements
 	 * @returns {object} The constant value for the JSON
 	 */
-	MetadataConverter.prototype.postProcessUrlRef = function (oElement, aResult) {
+	_MetadataConverter.prototype.postProcessUrlRef = function (_oElement, aResult) {
 		return {$UrlRef : aResult[0]};
 	};
 
@@ -455,7 +457,7 @@ sap.ui.define([
 	 *
 	 * @param {Element} oElement The element
 	 */
-	MetadataConverter.prototype.processAlias = function (oElement) {
+	_MetadataConverter.prototype.processAlias = function (oElement) {
 		var sAlias = oElement.getAttribute("Alias");
 
 		if (sAlias) {
@@ -466,9 +468,9 @@ sap.ui.define([
 	/**
 	 * Processes an element of an annotatable expression.
 	 *
-	 * @param {Element} oElement The element
+	 * @param {Element} _oElement The element
 	 */
-	MetadataConverter.prototype.processAnnotatableExpression = function (oElement) {
+	_MetadataConverter.prototype.processAnnotatableExpression = function (_oElement) {
 		this.annotatable({});
 	};
 
@@ -477,7 +479,7 @@ sap.ui.define([
 	 *
 	 * @param {Element} oElement The element
 	 */
-	MetadataConverter.prototype.processAnnotation = function (oElement) {
+	_MetadataConverter.prototype.processAnnotation = function (oElement) {
 		var oAnnotatable = this.oAnnotatable,
 			oAnnotations,
 			sQualifiedName = oAnnotatable.prefix + "@"
@@ -506,7 +508,7 @@ sap.ui.define([
 	 *
 	 * @param {Element} oElement The element
 	 */
-	MetadataConverter.prototype.processAnnotations = function (oElement) {
+	_MetadataConverter.prototype.processAnnotations = function (oElement) {
 		this.annotatable(this.resolveAliasInPath(oElement.getAttribute("Target"), true),
 			undefined, // no prefix
 			oElement.getAttribute("Qualifier"));
@@ -523,7 +525,7 @@ sap.ui.define([
 	 * @param {object} oConfig
 	 *   The configuration: a map from attribute name to a function to convert it
 	 */
-	MetadataConverter.prototype.processAttributes = function (oElement, oTarget, oConfig) {
+	_MetadataConverter.prototype.processAttributes = function (oElement, oTarget, oConfig) {
 		var sProperty;
 
 		for (sProperty in oConfig) {
@@ -544,7 +546,7 @@ sap.ui.define([
 	 *
 	 * @abstract
 	 * @function
-	 * @name sap.ui.model.odata.v4.lib._MetadataConverterMetadataConverter#processElement
+	 * @name sap.ui.model.odata.v4.lib._MetadataConverter#processElement
 	 */
 
 	/**
@@ -552,7 +554,7 @@ sap.ui.define([
 	 *
 	 * @param {Element} oElement The element
 	 */
-	MetadataConverter.prototype.processInclude = function (oElement) {
+	_MetadataConverter.prototype.processInclude = function (oElement) {
 		var oInclude = this.getOrCreateArray(this.reference, "$Include");
 
 		oInclude.push(oElement.getAttribute("Namespace") + ".");
@@ -563,18 +565,18 @@ sap.ui.define([
 	 *
 	 * @param {Element} oElement The element
 	 */
-	MetadataConverter.prototype.processIncludeAnnotations = function (oElement) {
+	_MetadataConverter.prototype.processIncludeAnnotations = function (oElement) {
 		var oReference = this.reference,
 			oIncludeAnnotation = {
-				"$TermNamespace" : oElement.getAttribute("TermNamespace") + "."
+				$TermNamespace : oElement.getAttribute("TermNamespace") + "."
 			},
 			aIncludeAnnotations = this.getOrCreateArray(oReference, "$IncludeAnnotations");
 
 		this.processAttributes(oElement, oIncludeAnnotation, {
-			"TargetNamespace" : function setValue(sValue) {
+			TargetNamespace : function setValue(sValue) {
 				return sValue ? sValue + "." : sValue;
 			},
-			"Qualifier" : this.setValue
+			Qualifier : this.setValue
 		});
 
 		aIncludeAnnotations.push(oIncludeAnnotation);
@@ -585,7 +587,7 @@ sap.ui.define([
 	 *
 	 * @param {Element} oElement The element
 	 */
-	MetadataConverter.prototype.processPropertyValue = function (oElement) {
+	_MetadataConverter.prototype.processPropertyValue = function (oElement) {
 		this.annotatable(this.oAnnotatable.target, oElement.getAttribute("Property"));
 	};
 
@@ -594,7 +596,7 @@ sap.ui.define([
 	 *
 	 * @param {Element} oElement The element
 	 */
-	MetadataConverter.prototype.processReference = function (oElement) {
+	_MetadataConverter.prototype.processReference = function (oElement) {
 		var oReference = this.getOrCreateObject(this.result, "$Reference");
 
 		this.reference = oReference[oElement.getAttribute("Uri")] = {};
@@ -604,11 +606,11 @@ sap.ui.define([
 	/**
 	 * Resolves an alias in the given qualified name or full name.
 	 *
-	 * @param {string} sName The name
+	 * @param {string} [sName] The name
 	 * @returns {string} The name with the alias resolved (if there was one)
 	 */
-	MetadataConverter.prototype.resolveAlias = function (sName) {
-		var iDot = sName.indexOf("."),
+	_MetadataConverter.prototype.resolveAlias = function (sName) {
+		var iDot = sName ? sName.indexOf(".") : -1,
 			sNamespace;
 
 		if (iDot >= 0 && !sName.includes(".", iDot + 1)) { // if there is exactly one dot
@@ -627,9 +629,9 @@ sap.ui.define([
 	 *   Whether parentheses in the path segment should be handled specially for alias replacement,
 	 *   for example to address a bound action's specific overload
 	 * @param {string} sSegment The path segment
-	 * @returns {string} The path segment with aliases resolved (if there were any)
+	 * @returns {string|undefined} The path segment with aliases resolved (if there were any)
 	 */
-	MetadataConverter.prototype.resolveAliasInParentheses = function (bHandleParentheses,
+	_MetadataConverter.prototype.resolveAliasInParentheses = function (bHandleParentheses,
 			sSegment) {
 		var iParentheses = bHandleParentheses ? sSegment.indexOf("(") : -1;
 
@@ -649,13 +651,14 @@ sap.ui.define([
 	 * Resolves all aliases in the given path.
 	 *
 	 * @param {string} sPath The path
-	 * @param {boolean} [bHandleParentheses=false]
+	 * @param {boolean} [bHandleParentheses]
 	 *   Whether parentheses in a path segment should be handled specially for alias replacement,
 	 *   for example to address a bound action's specific overload
 	 * @returns {string} The path with aliases resolved (if there were any)
 	 */
-	MetadataConverter.prototype.resolveAliasInPath = function (sPath, bHandleParentheses) {
-		var iAt, sTerm = "";
+	_MetadataConverter.prototype.resolveAliasInPath = function (sPath, bHandleParentheses) {
+		var iAt,
+			sTerm = "";
 
 		if (!sPath.includes(".")) {
 			return sPath; // no dot -> nothing to do
@@ -676,7 +679,7 @@ sap.ui.define([
 	 * @param {string} sValue The attribute value in the element
 	 * @returns {boolean} false or undefined
 	 */
-	MetadataConverter.prototype.setIfFalse = function (sValue) {
+	_MetadataConverter.prototype.setIfFalse = function (sValue) {
 		return sValue === "false" ? false : undefined;
 	};
 
@@ -687,7 +690,7 @@ sap.ui.define([
 	 * @param {string} sValue The attribute value in the element
 	 * @returns {boolean} true or undefined
 	 */
-	MetadataConverter.prototype.setIfTrue = function (sValue) {
+	_MetadataConverter.prototype.setIfTrue = function (sValue) {
 		return sValue === "true" ? true : undefined;
 	};
 
@@ -695,9 +698,9 @@ sap.ui.define([
 	 * Helper for processAttributes, returns sValue converted to a number.
 	 *
 	 * @param {string} sValue The attribute value in the element
-	 * @returns {number} The value as number or undefined
+	 * @returns {number|undefined} The value as number or <code>undefined</code>
 	 */
-	MetadataConverter.prototype.setNumber = function (sValue) {
+	_MetadataConverter.prototype.setNumber = function (sValue) {
 		return sValue ? parseInt(sValue) : undefined;
 	};
 
@@ -707,7 +710,7 @@ sap.ui.define([
 	 * @param {string} sValue The attribute value in the element
 	 * @returns {string} sValue
 	 */
-	MetadataConverter.prototype.setValue = function (sValue) {
+	_MetadataConverter.prototype.setValue = function (sValue) {
 		return sValue;
 	};
 
@@ -728,26 +731,25 @@ sap.ui.define([
 	 *     known children.
 	 *   * All other properties are known child elements, the value is the configuration for
 	 *     that child element.
-	 * @param {boolean} [bUseProcessElementHook=false]
+	 * @param {boolean} [bUseProcessElementHook]
 	 *   If true, the hook processElement at the aggregate is used, otherwise the processor is
 	 *   called directly
 	 * @returns {any}
-	 *   The return value from __postProcessor or undefined if there is none
+	 *   The return value from __postProcessor or <code>undefined</code> if there is none
 	 */
-	MetadataConverter.prototype.traverse = function (oElement, oConfig, bUseProcessElementHook) {
+	_MetadataConverter.prototype.traverse = function (oElement, oConfig, bUseProcessElementHook) {
 		var oAnnotatable = this.oAnnotatable, // "push" oAnnotatable to the recursion stack
 			oChildConfig,
 			oChildList = oElement.childNodes,
 			oChildNode,
 			vChildResult,
-			i,
 			aIncludes,
-			j,
 			sName,
 			sPreviousNamespace = this.xmlns,
 			vResult,
 			aResult = [],
-			sXmlNamespace = oConfig.__xmlns || this.xmlns;
+			sXmlNamespace = oConfig.__xmlns || this.xmlns,
+			i, j;
 
 		if (sXmlNamespace && sXmlNamespace !== oElement.namespaceURI) {
 			// Ignore this element because the namespace is not as expected
@@ -776,8 +778,8 @@ sap.ui.define([
 					}
 				}
 				if (oChildConfig) {
-					vChildResult =
-						this.traverse(oChildNode, oChildConfig, bUseProcessElementHook);
+					vChildResult
+						= this.traverse(oChildNode, oChildConfig, bUseProcessElementHook);
 					if (vChildResult !== undefined && oConfig.__postProcessor) {
 						// only push if the element is interested in the results and if the
 						// child element returns anything (it might be another Annotation which
@@ -809,23 +811,23 @@ sap.ui.define([
 
 		// All Annotations elements that don't have expressions as child (leaf, non-recursive)
 		oAnnotationLeafConfig = {
-			"AnnotationPath" : {__postProcessor : $$.postProcessLeaf},
-			"Binary" : {__postProcessor : $$.postProcessLeaf},
-			"Bool" : {__postProcessor : $$.postProcessLeaf},
-			"Date" : {__postProcessor : $$.postProcessLeaf},
-			"DateTimeOffset" : {__postProcessor : $$.postProcessLeaf},
-			"Decimal" : {__postProcessor : $$.postProcessLeaf},
-			"Duration" : {__postProcessor : $$.postProcessLeaf},
-			"EnumMember" : {__postProcessor : $$.postProcessLeaf},
-			"Float" : {__postProcessor : $$.postProcessLeaf},
-			"Guid" : {__postProcessor : $$.postProcessLeaf},
-			"Int" : {__postProcessor : $$.postProcessLeaf},
-			"LabeledElementReference" : {__postProcessor : $$.postProcessLabeledElementReference},
-			"NavigationPropertyPath" : {__postProcessor : $$.postProcessLeaf},
-			"Path" : {__postProcessor : $$.postProcessLeaf},
-			"PropertyPath" : {__postProcessor : $$.postProcessLeaf},
-			"String" : {__postProcessor : $$.postProcessLeaf},
-			"TimeOfDay" : {__postProcessor : $$.postProcessLeaf}
+			AnnotationPath : {__postProcessor : $$.postProcessLeaf},
+			Binary : {__postProcessor : $$.postProcessLeaf},
+			Bool : {__postProcessor : $$.postProcessLeaf},
+			Date : {__postProcessor : $$.postProcessLeaf},
+			DateTimeOffset : {__postProcessor : $$.postProcessLeaf},
+			Decimal : {__postProcessor : $$.postProcessLeaf},
+			Duration : {__postProcessor : $$.postProcessLeaf},
+			EnumMember : {__postProcessor : $$.postProcessLeaf},
+			Float : {__postProcessor : $$.postProcessLeaf},
+			Guid : {__postProcessor : $$.postProcessLeaf},
+			Int : {__postProcessor : $$.postProcessLeaf},
+			LabeledElementReference : {__postProcessor : $$.postProcessLabeledElementReference},
+			NavigationPropertyPath : {__postProcessor : $$.postProcessLeaf},
+			Path : {__postProcessor : $$.postProcessLeaf},
+			PropertyPath : {__postProcessor : $$.postProcessLeaf},
+			String : {__postProcessor : $$.postProcessLeaf},
+			TimeOfDay : {__postProcessor : $$.postProcessLeaf}
 		};
 
 		// When oAnnotationExpressionConfig is defined, it is added to this array for the recursion
@@ -833,7 +835,7 @@ sap.ui.define([
 
 		// The configuration for an <Annotation> element to be included into other configurations
 		$$.oAnnotationConfig = {
-			"Annotation" : {
+			Annotation : {
 				__xmlns : $$.sEdmNamespace,
 				__processor : $$.processAnnotation,
 				__postProcessor : $$.postProcessAnnotation,
@@ -848,60 +850,60 @@ sap.ui.define([
 			__include : aAnnotatableExpressionInclude
 		};
 		oAnnotationExpressionConfig = {
-			"And" : oOperatorConfig,
-			"Apply" : {
+			And : oOperatorConfig,
+			Apply : {
 				__processor : $$.processAnnotatableExpression,
 				__postProcessor : $$.postProcessApply,
 				__include : aAnnotatableExpressionInclude
 			},
-			"Cast" : {
+			Cast : {
 				__processor : $$.processAnnotatableExpression,
 				__postProcessor : $$.postProcessCastOrIsOf,
 				__include : aAnnotatableExpressionInclude
 			},
-			"Collection" : {
+			Collection : {
 				__postProcessor : $$.postProcessCollection,
 				__include : aExpressionInclude
 			},
-			"Eq" : oOperatorConfig,
-			"Ge" : oOperatorConfig,
-			"Gt" : oOperatorConfig,
-			"If" : oOperatorConfig,
-			"IsOf" : {
+			Eq : oOperatorConfig,
+			Ge : oOperatorConfig,
+			Gt : oOperatorConfig,
+			If : oOperatorConfig,
+			IsOf : {
 				__processor : $$.processAnnotatableExpression,
 				__postProcessor : $$.postProcessCastOrIsOf,
 				__include : aAnnotatableExpressionInclude
 			},
-			"LabeledElement" : {
+			LabeledElement : {
 				__processor : $$.processAnnotatableExpression,
 				__postProcessor : $$.postProcessLabeledElement,
 				__include : aAnnotatableExpressionInclude
 			},
-			"Le" : oOperatorConfig,
-			"Lt" : oOperatorConfig,
-			"Ne" : oOperatorConfig,
-			"Null" : {
+			Le : oOperatorConfig,
+			Lt : oOperatorConfig,
+			Ne : oOperatorConfig,
+			Null : {
 				__processor : $$.processAnnotatableExpression,
 				__postProcessor : $$.postProcessNull,
 				__include : [$$.oAnnotationConfig]
 			},
-			"Not" : {
+			Not : {
 				__processor : $$.processAnnotatableExpression,
 				__postProcessor : $$.postProcessNot,
 				__include : aAnnotatableExpressionInclude
 			},
-			"Or" : oOperatorConfig,
-			"Record" : {
+			Or : oOperatorConfig,
+			Record : {
 				__processor : $$.processAnnotatableExpression,
 				__postProcessor : $$.postProcessRecord,
 				__include : [$$.oAnnotationConfig],
-				"PropertyValue" : {
+				PropertyValue : {
 					__processor : $$.processPropertyValue,
 					__postProcessor : $$.postProcessPropertyValue,
 					__include : aAnnotatableExpressionInclude
 				}
 			},
-			"UrlRef" : {
+			UrlRef : {
 				__postProcessor : $$.postProcessUrlRef,
 				__include : aExpressionInclude
 			}
@@ -909,7 +911,7 @@ sap.ui.define([
 
 		// The configuration for an <Annotations> element to be included into other configurations
 		$$.oAnnotationsConfig = {
-			"Annotations" : {
+			Annotations : {
 				__processor : $$.processAnnotations,
 				__include : [$$.oAnnotationConfig]
 			}
@@ -925,20 +927,19 @@ sap.ui.define([
 		 * The configuration for a <Reference> element to be included into other configurations
 		 */
 		$$.oReferenceInclude = {
-			"Reference" : {
+			Reference : {
 				__xmlns : $$.sEdmxNamespace,
 				__processor : $$.processReference,
 				__include : [$$.oAnnotationConfig],
-				"Include" : {
+				Include : {
 					__processor : $$.processInclude
 				},
-				"IncludeAnnotations" : {
+				IncludeAnnotations : {
 					__processor : $$.processIncludeAnnotations
 				}
 			}
 		};
+	})(_MetadataConverter.prototype);
 
-	})(MetadataConverter.prototype);
-
-	return MetadataConverter;
-}, /* bExport= */false);
\ No newline at end of file
+	return _MetadataConverter;
+}, /* bExport= */false);
