@@ -1,6 +1,6 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
@@ -20,7 +20,7 @@ function(
 	 * @extends sap.ui.rta.toolbar.Adaptation
 	 *
 	 * @author SAP SE
-	 * @version 1.82.2
+	 * @version 1.98.0
 	 *
 	 * @constructor
 	 * @private
@@ -29,9 +29,12 @@ function(
 	 * @experimental Since 1.48. This class is experimental. API might be changed in future.
 	 */
 	var Standalone = Adaptation.extend("sap.ui.rta.toolbar.Standalone", {
-		renderer: 'sap.ui.rta.toolbar.AdaptationRenderer',
-		type: 'standalone'
+		metadata: {
+			library: "sap.ui.rta"
+		},
+		renderer: "sap.ui.rta.toolbar.AdaptationRenderer",
+		type: "standalone"
 	});
 
 	return Standalone;
-}, true);
+});
