@@ -1,13 +1,11 @@
 /*!
 * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
 */
-/**
-* @typedef {object} Event Certain event that's fired by the user action in the browser
-*/
+
 sap.ui.define([
-	"jquery.sap.global",
+	"sap/base/Log",
 	"sap/ui/base/ManagedObject",
 	"sap/ui/core/Element",
 	"sap/ui/core/Component",
@@ -25,7 +23,7 @@ sap.ui.define([
 	"sap/ui/support/supportRules/RuleSerializer",
 	"sap/ui/support/library"
 ],
-function (jQuery, ManagedObject, Element, Component, Analyzer, CoreFacade,
+function (Log, ManagedObject, Element, Component, Analyzer, CoreFacade,
 		  ExecutionScope, Highlighter, CommunicationBus,
 		  IssueManager, History, DataCollector, channelNames,
 		  constants, RuleSetLoader, RuleSerializer, library) {
@@ -59,7 +57,7 @@ function (jQuery, ManagedObject, Element, Component, Analyzer, CoreFacade,
 				var evt = document.createEvent("CustomEvent");
 				evt.initCustomEvent("supportToolLoaded", true, true, {});
 			} else {
-				jQuery.sap.log.warning("Only one support tool allowed");
+				Log.warning("Only one support tool allowed");
 
 				return oMain;
 			}
@@ -217,6 +215,7 @@ function (jQuery, ManagedObject, Element, Component, Analyzer, CoreFacade,
 
 		CommunicationBus.subscribe(channelNames.OPEN_URL, function (url) {
 			var win = window.open(url, "_blank");
+			win.opener = null;
 			win.focus();
 		}, this);
 
@@ -322,7 +321,7 @@ function (jQuery, ManagedObject, Element, Component, Analyzer, CoreFacade,
 			vPresetOrRules = library.SystemPresets[vPresetOrRules];
 
 			if (!vPresetOrRules) {
-				jQuery.sap.log.error("System preset ID is not valid");
+				Log.error("System preset ID is not valid");
 				return;
 			}
 		}
@@ -344,7 +343,7 @@ function (jQuery, ManagedObject, Element, Component, Analyzer, CoreFacade,
 			vRuleDescriptors = vPresetOrRules.selections;
 
 			if (!vPresetOrRules.id || !vPresetOrRules.title) {
-				jQuery.sap.log.error("The preset must have an ID and a title");
+				Log.error("The preset must have an ID and a title");
 				return;
 			}
 
@@ -399,7 +398,7 @@ function (jQuery, ManagedObject, Element, Component, Analyzer, CoreFacade,
 			i;
 
 		if (ExecutionScope.possibleScopes.indexOf(oExecutionScope.type) === -1) {
-			jQuery.sap.log.error("Invalid execution scope type. Type must be one of the following: "
+			Log.error("Invalid execution scope type. Type must be one of the following: "
 				+ ExecutionScope.possibleScopes.join(", "));
 			return false;
 		}
@@ -408,8 +407,8 @@ function (jQuery, ManagedObject, Element, Component, Analyzer, CoreFacade,
 
 			if (oExecutionScope.parentId) {
 				aSelectors.push(oExecutionScope.parentId);
-			} else if (jQuery.isArray(oExecutionScope.selectors)) {
-				jQuery.merge(aSelectors, oExecutionScope.selectors);
+			} else if (Array.isArray(oExecutionScope.selectors)) {
+				aSelectors = aSelectors.concat(oExecutionScope.selectors);
 			} else if (oExecutionScope.selectors) {
 				aSelectors.push(oExecutionScope.selectors);
 			}
@@ -462,20 +461,20 @@ function (jQuery, ManagedObject, Element, Component, Analyzer, CoreFacade,
 				mRules;
 
 			if (!oRuleDescriptor.libName || !oRuleDescriptor.ruleId) {
-				jQuery.sap.log.error("[" + constants.SUPPORT_ASSISTANT_NAME + "] Invalid Rule Descriptor.");
+				Log.error("[" + constants.SUPPORT_ASSISTANT_NAME + "] Invalid Rule Descriptor.");
 				return;
 			}
 
 			oRuleset = RuleSetLoader.getRuleSet(oRuleDescriptor.libName);
 
 			if (!oRuleset || !oRuleset.ruleset) {
-				jQuery.sap.log.error("[" + constants.SUPPORT_ASSISTANT_NAME + "] Could not find Ruleset for library " + oRuleDescriptor.libName);
+				Log.error("[" + constants.SUPPORT_ASSISTANT_NAME + "] Could not find Ruleset for library " + oRuleDescriptor.libName);
 				return;
 			}
 
 			mRules = oRuleset.ruleset.getRules();
 			if (!mRules || !mRules[oRuleDescriptor.ruleId]) {
-				jQuery.sap.log.error("[" + constants.SUPPORT_ASSISTANT_NAME + "] Could not find Rule with id " +
+				Log.error("[" + constants.SUPPORT_ASSISTANT_NAME + "] Could not find Rule with id " +
 					oRuleDescriptor.ruleId + " for library " + oRuleDescriptor.libName);
 				return;
 			}
@@ -673,7 +672,7 @@ function (jQuery, ManagedObject, Element, Component, Analyzer, CoreFacade,
 			},
 			analysisDuration: this._oAnalyzer.getElapsedTimeString(),
 			analysisDurationTitle: oReportConstants.analysisDurationTitle,
-			abap: History.getFormattedHistory(sap.ui.support.HistoryFormats.Abap),
+			abap: History.getFormattedHistory(library.HistoryFormats.Abap),
 			name: constants.SUPPORT_ASSISTANT_NAME
 		};
 	};
@@ -715,7 +714,7 @@ function (jQuery, ManagedObject, Element, Component, Analyzer, CoreFacade,
 	Main.prototype.getLastAnalysisHistory = function () {
 		var aHistory = this.getAnalysisHistory();
 
-		if (jQuery.isArray(aHistory) && aHistory.length > 0) {
+		if (Array.isArray(aHistory) && aHistory.length > 0) {
 			return aHistory[aHistory.length - 1];
 		} else {
 			return null;
