@@ -1,6 +1,6 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
@@ -14,21 +14,21 @@ sap.ui.define([
 	"sap/ui/support/supportRules/ui/models/Documentation",
 	"sap/ui/support/supportRules/util/Utils",
 	"sap/m/GroupHeaderListItem",
-	"sap/ui/thirdparty/jquery",
-	"sap/ui/core/library",
-	"sap/ui/support/library"
-], function (BaseController,
-			 SelectionUtils,
-			 PresetsUtils,
-			 Fragment,
-			 MessageToast,
-			 MessageBox,
-			 Documentation,
-			 Utils,
-			 GroupHeaderListItem,
-			 jQuery,
-			 coreLibrary,
-			 library) {
+	"sap/base/util/deepExtend",
+	"sap/ui/core/library"
+], function (
+	BaseController,
+	SelectionUtils,
+	PresetsUtils,
+	Fragment,
+	MessageToast,
+	MessageBox,
+	Documentation,
+	Utils,
+	GroupHeaderListItem,
+	deepExtend,
+	coreLibrary
+) {
 	"use strict";
 
 	// shortcut for sap.ui.core.ValueState
@@ -89,7 +89,7 @@ sap.ui.define([
 	 *
 	 * @extends sap.ui.support.supportRules.ui.controllers.BaseController
 	 * @author SAP SE
-	 * @version 1.82.2
+	 * @version 1.98.0
 	 * @private
 	 * @alias sap.ui.support.supportRules.ui.controllers.PresetsController
 	 */
@@ -109,24 +109,28 @@ sap.ui.define([
 		oBtn.focus();
 
 		if (!this._oPresetsPopover) {
-			this._oPresetsPopover = sap.ui.xmlfragment(
-				Constants.SELECT_FRAGMENT_ID,
-				"sap.ui.support.supportRules.ui.views.Presets",
-				this
-			);
-			this.oView.addDependent(this._oPresetsPopover);
+			this._oPresetsPopover = Fragment.load({
+				id: Constants.SELECT_FRAGMENT_ID,
+				name: "sap.ui.support.supportRules.ui.views.Presets",
+				controller: this
+			}).then(function (oPresetsPopover) {
+				this.oView.addDependent(oPresetsPopover);
+				return oPresetsPopover;
+			}.bind(this));
 		}
 
-		if (!this._oPresetsPopover.isOpen()) {
-			// set correct focus in the popover
-			this._oPresetsPopover.setInitialFocus(
-				Fragment.byId(Constants.SELECT_FRAGMENT_ID, "select").getSelectedItem().getId()
-			);
+		this._oPresetsPopover.then(function (oPresetsPopover) {
+			if (!oPresetsPopover.isOpen()) {
+				// set correct focus in the popover
+				oPresetsPopover.setInitialFocus(
+					Fragment.byId(Constants.SELECT_FRAGMENT_ID, "select").getSelectedItem().getId()
+				);
 
-			this._oPresetsPopover.openBy(oBtn);
-		} else {
-			this._oPresetsPopover.close();
-		}
+				oPresetsPopover.openBy(oBtn);
+			} else {
+				oPresetsPopover.close();
+			}
+		});
 	};
 
 	/**
@@ -145,7 +149,7 @@ sap.ui.define([
 	 * Closes the variant select when an item is clicked
 	 */
 	PresetsController.prototype.onPresetItemPress = function () {
-		this._oPresetsPopover.close();
+		Fragment.byId(Constants.SELECT_FRAGMENT_ID, "presetsPopover").close();
 	};
 
 	/**
@@ -207,18 +211,21 @@ sap.ui.define([
 	PresetsController.prototype.onPresetItemReset = function (oEvent) {
 		var sPath = oEvent.getSource().getBindingContext().getPath(),
 			oPreset = this.oModel.getProperty(sPath),
-			aPresets = oPreset.isSystemPreset ?  PresetsUtils.getSystemPresets() : this.oModel.getProperty("/customPresets");
+			aPresets = oPreset.isSystemPreset ? PresetsUtils.getSystemPresets() : this.oModel.getProperty("/customPresets"),
+			oCLI = oEvent.getSource().getParent().getParent().getParent();
 
-		aPresets.some(function (oInitialPreset) {
+		// We hide the focused item (the button), so we have to restore the focus manually,
+		// because the ResponsivePopover can't restore it on Chrome.
+		// This way the popover is kept open on all browsers, which provides consistency.
+		oCLI.focus();
+
+		aPresets.forEach(function (oInitialPreset) {
 			if (oInitialPreset.id === oPreset.id) {
-				oPreset.title = oInitialPreset.title;
-				oPreset.selections = oInitialPreset.selections;
-				oPreset.isModified = false;
-				return true;
+				this.oModel.setProperty(sPath + "/title", oInitialPreset.title);
+				this.oModel.setProperty(sPath + "/selections", oInitialPreset.selections);
+				this.oModel.setProperty(sPath + "/isModified", false);
 			}
-		});
-
-		this.oModel.refresh();
+		}.bind(this));
 
 		if (oPreset.selected) {
 			this._applyPreset(oPreset);
@@ -230,15 +237,19 @@ sap.ui.define([
 	 */
 	PresetsController.prototype.onImportPress = function () {
 		if (!this._oImportDialog) {
-			this._oImportDialog = sap.ui.xmlfragment(
-				Constants.IMPORT_FRAGMENT_ID,
-				"sap.ui.support.supportRules.ui.views.PresetImport",
-				this
-			);
-			this.oView.addDependent(this._oImportDialog);
+			this._oImportDialog = Fragment.load({
+				id: Constants.IMPORT_FRAGMENT_ID,
+				name: "sap.ui.support.supportRules.ui.views.PresetImport",
+				controller: this
+			}).then(function (oImportDialog) {
+				this.oView.addDependent(oImportDialog);
+				return oImportDialog;
+			}.bind(this));
 		}
 
-		this._oImportDialog.open();
+		this._oImportDialog.then(function (oImportDialog) {
+			oImportDialog.open();
+		});
 	};
 
 	/**
@@ -316,7 +327,7 @@ sap.ui.define([
 	 * Handles the pressing of the cancel button on import
 	 */
 	PresetsController.prototype.onImportCancelPress = function () {
-		this._oImportDialog.close();
+		Fragment.byId(Constants.IMPORT_FRAGMENT_ID, "importDialog").close();
 	};
 
 	/**
@@ -334,7 +345,7 @@ sap.ui.define([
 				+ "\"I agree to use local storage persistency\" from Support Assistant settings.";
 		}
 
-		this._oImportDialog.close();
+		Fragment.byId(Constants.IMPORT_FRAGMENT_ID, "importDialog").close();
 
 		MessageToast.show(sMessage, { width: "50%" });
 	};
@@ -370,20 +381,19 @@ sap.ui.define([
 		});
 
 		if (!this._oExportDialog) {
-			this._oExportDialog = sap.ui.xmlfragment(
-				Constants.EXPORT_FRAGMENT_ID,
-				"sap.ui.support.supportRules.ui.views.PresetExport",
-				this
-			);
-			this._oExportDialog.attachAfterClose(function () {
-				this._clearValidationState();
+			this._oExportDialog = Fragment.load({
+				id: Constants.EXPORT_FRAGMENT_ID,
+				name: "sap.ui.support.supportRules.ui.views.PresetExport",
+				controller: this
+			}).then(function (oExportDialog) {
+				this.oView.addDependent(oExportDialog);
+				return oExportDialog;
 			}.bind(this));
-			this.oView.addDependent(this._oExportDialog);
-
-			this.initializeExportValidations();
 		}
 
-		this._oExportDialog.open();
+		this._oExportDialog.then(function (oExportDialog) {
+			oExportDialog.open();
+		});
 	};
 
 	/**
@@ -493,7 +503,7 @@ sap.ui.define([
 	 * Cancels an export
 	 */
 	PresetsController.prototype.onExportCancelPress = function () {
-		this._oExportDialog.close();
+		Fragment.byId(Constants.EXPORT_FRAGMENT_ID, "exportDialog").close();
 	};
 
 	/**
@@ -520,8 +530,7 @@ sap.ui.define([
 		);
 
 		MessageToast.show("The Rule Preset \"" + title + "\" was successfully exported.", {width: "50%"});
-
-		this._oExportDialog.close();
+		Fragment.byId(Constants.EXPORT_FRAGMENT_ID, "exportDialog").close();
 	};
 
 	/**
@@ -649,7 +658,7 @@ sap.ui.define([
 		aSelectedPresets.push(oPresetOptions);
 
 		// keep the original version of the preset
-		aCustomPresets.push(jQuery.extend(true, {}, oPresetOptions));
+		aCustomPresets.push(deepExtend({}, oPresetOptions));
 
 		if (PresetsUtils.isPersistingAllowed()) {
 			PresetsUtils.persistCustomPresets();
