@@ -1,13 +1,13 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
 //Provides default renderer for control sap.ui.table.Table
-sap.ui.define(['sap/ui/core/Control', 'sap/ui/core/theming/Parameters', 'sap/ui/Device', './library', "./Column", './utils/TableUtils', "./extensions/ExtensionBase",
+sap.ui.define(['sap/ui/core/Control', 'sap/ui/Device', './library', "./Column", './utils/TableUtils', "./extensions/ExtensionBase",
 			   'sap/ui/core/Renderer', 'sap/ui/core/IconPool', "sap/base/Log"],
-	function(Control, Parameters, Device, library, Column, TableUtils, ExtensionBase, Renderer, IconPool, Log) {
+	function(Control, Device, library, Column, TableUtils, ExtensionBase, Renderer, IconPool, Log) {
 	"use strict";
 
 
@@ -95,7 +95,7 @@ sap.ui.define(['sap/ui/core/Control', 'sap/ui/core/theming/Parameters', 'sap/ui/
 			rm.class("sapUiTableRowNavIndicator");
 		}
 
-		if (TableUtils.isNoDataVisible(oTable) && !TableUtils.hasPendingRequests(oTable)) {
+		if (TableUtils.isNoDataVisible(oTable) && !oTable._hasPendingRequests()) {
 			rm.class("sapUiTableEmpty"); // no data!
 		}
 
@@ -122,6 +122,9 @@ sap.ui.define(['sap/ui/core/Control', 'sap/ui/core/theming/Parameters', 'sap/ui/
 
 		this.renderTabElement(rm, "sapUiTableOuterBefore");
 
+		rm.openStart("div", oTable.getId() + "-before");
+		rm.openEnd();
+
 		rm.renderControl(oTable.getAggregation("_messageStrip"));
 
 		if (oTable.getTitle()) {
@@ -136,11 +139,16 @@ sap.ui.define(['sap/ui/core/Control', 'sap/ui/core/theming/Parameters', 'sap/ui/
 			this.renderExtensions(rm, oTable, oTable.getExtension());
 		}
 
+		rm.close("div");
+
 		rm.openStart("div", oTable.getId() + "-sapUiTableCnt");
 		rm.class("sapUiTableCnt");
 
 		// Define group for F6 handling
 		rm.attr("data-sap-ui-fastnavgroup", "true");
+		// Define the paste region for the paste event
+		rm.attr("data-sap-ui-pasteregion", "true");
+
 		oTable._getAccRenderExtension().writeAriaAttributesFor(rm, oTable, "CONTAINER");
 		rm.openEnd();
 
@@ -155,7 +163,7 @@ sap.ui.define(['sap/ui/core/Control', 'sap/ui/core/theming/Parameters', 'sap/ui/
 		rm.close("div");
 
 		var oCreationRow = oTable.getCreationRow();
-		if (oCreationRow) {
+		if (oCreationRow && oCreationRow.getVisible()) {
 			rm.renderControl(oCreationRow);
 
 			// If the table has a creation row, the horizontal scrollbar needs to be rendered outside the element covered by the busy indicator.
@@ -174,6 +182,9 @@ sap.ui.define(['sap/ui/core/Control', 'sap/ui/core/theming/Parameters', 'sap/ui/
 
 		rm.close("div");
 
+		rm.openStart("div", oTable.getId() + "-after");
+		rm.openEnd();
+
 		if (oTable.getFooter()) {
 			this.renderFooter(rm, oTable, oTable.getFooter());
 		}
@@ -186,6 +197,8 @@ sap.ui.define(['sap/ui/core/Control', 'sap/ui/core/theming/Parameters', 'sap/ui/
 		// TODO: Move to "renderTableChildAtBottom" hook in row modes
 		this.renderBottomPlaceholder(rm, oTable);
 
+		rm.close("div");
+
 		//oTable._getRowMode().renderTableChildAtBottom(rm);
 		this.renderTabElement(rm, "sapUiTableOuterAfter");
 		rm.close("div");
@@ -250,24 +263,23 @@ sap.ui.define(['sap/ui/core/Control', 'sap/ui/core/theming/Parameters', 'sap/ui/
 	};
 
 	TableRenderer.renderTable = function(rm, oTable) {
-		this.renderTabElement(rm, "sapUiTableCtrlBefore");
+		var bHasRows = oTable.getRows().length > 0;
+
+		this.renderTabElement(rm, "sapUiTableCtrlBefore", bHasRows ? "0" : "-1");
+
 		rm.openStart("div", oTable.getId() + "-tableCCnt");
 		oTable._getRowMode().applyRowContainerStyles(rm);
-
 		rm.class("sapUiTableCCnt");
 		rm.openEnd();
 
 		this.renderTableCCnt(rm, oTable);
 		rm.close("div");
-		this.renderTabElement(rm, "sapUiTableCtrlAfter");
 
-		if (!oTable._getScrollExtension().isVerticalScrollbarExternal()) {
-			this.renderVSbBackground(rm, oTable);
-			this.renderVSb(rm, oTable);
-		}
+		this.renderTabElement(rm, "sapUiTableCtrlAfter", bHasRows ? "0" : "-1");
+		this.renderTabElement(rm, null, "-1", oTable.getId() + "-focusDummy");
 
 		var oCreationRow = oTable.getCreationRow();
-		if (!oCreationRow) {
+		if (!oCreationRow || !oCreationRow.getVisible()) {
 			this.renderHSbBackground(rm, oTable);
 			this.renderHSb(rm, oTable);
 		}
@@ -278,6 +290,10 @@ sap.ui.define(['sap/ui/core/Control', 'sap/ui/core/theming/Parameters', 'sap/ui/
 		this.renderRowHdr(rm, oTable);
 		this.renderRowActions(rm, oTable);
 
+		if (!oTable._getScrollExtension().isVerticalScrollbarExternal()) {
+			this.renderVSb(rm, oTable);
+		}
+
 		rm.openStart("div", oTable.getId() + "-noDataCnt");
 		rm.class("sapUiTableCtrlEmpty");
 		rm.attr("tabindex", "0");
@@ -446,7 +462,11 @@ sap.ui.define(['sap/ui/core/Control', 'sap/ui/core/theming/Parameters', 'sap/ui/
 
 		rm.attr("tabindex", "-1");
 
-		oTable._getAccRenderExtension().writeAriaAttributesFor(rm, oTable, "COLUMNROWHEADER", {enabled: bEnabled, checked: bSelAll});
+		var oParams = {
+			enabled: bEnabled,
+			checked: bSelAll
+		};
+		oTable._getAccRenderExtension().writeAriaAttributesFor(rm, oTable, "COLUMNROWHEADER", oParams);
 
 		rm.openEnd();
 
@@ -482,6 +502,7 @@ sap.ui.define(['sap/ui/core/Control', 'sap/ui/core/theming/Parameters', 'sap/ui/
 			sHeaderId = sHeaderId + "_" + iHeader;
 			rm.openStart("td", sHeaderId);
 		}
+		rm.attr('data-sap-ui-related', oColumn.getId());
 		rm.attr('data-sap-ui-colid', oColumn.getId());
 		rm.attr("data-sap-ui-colindex", iIndex);
 
@@ -646,7 +667,13 @@ sap.ui.define(['sap/ui/core/Control', 'sap/ui/core/theming/Parameters', 'sap/ui/
 		var bRowSelected = oTable._getSelectionPlugin().isIndexSelected(oRow.getIndex());
 
 		rm.openStart("div");
-		oTable._getAccRenderExtension().writeAriaAttributesFor(rm, oTable, "TR", {index: iRowIndex, rowHidden: oRow.isEmpty()});
+		var oRowSettings = oRow.getAggregation("_settings");
+		var oParams = {
+			index: iRowIndex,
+			rowHidden: oRow.isEmpty(),
+			rowNavigated: oRowSettings ? oRowSettings.getNavigated() : false
+		};
+		oTable._getAccRenderExtension().writeAriaAttributesFor(rm, oTable, "TR", oParams);
 		rm.attr("data-sap-ui-related", oRow.getId());
 		rm.attr("data-sap-ui-rowindex", iRowIndex);
 
@@ -659,7 +686,7 @@ sap.ui.define(['sap/ui/core/Control', 'sap/ui/core/theming/Parameters', 'sap/ui/
 			rm.class("sapUiTableRowSel");
 		}
 
-		if (iRowIndex % 2 != 0 && oTable.getAlternateRowColors() && !TableUtils.Grouping.isTreeMode(oTable)) {
+		if (iRowIndex % 2 != 0 && oTable.getAlternateRowColors() && !TableUtils.Grouping.isInTreeMode(oTable)) {
 			rm.class("sapUiTableRowAlternate");
 		}
 
@@ -676,7 +703,11 @@ sap.ui.define(['sap/ui/core/Control', 'sap/ui/core/theming/Parameters', 'sap/ui/
 
 		rm.attr("tabindex", "-1");
 
-		oTable._getAccRenderExtension().writeAriaAttributesFor(rm, oTable, bHeader ? "ROWHEADER" : "ROWACTION", {rowSelected: bRowSelected, rowHidden: oRow.isEmpty()});
+		oParams = {
+			rowSelected: bRowSelected,
+			rowHidden: oRow.isEmpty()
+		};
+		oTable._getAccRenderExtension().writeAriaAttributesFor(rm, oTable, bHeader ? "ROWHEADER" : "ROWACTION", oParams);
 
 		rm.openEnd();
 		if (bHeader) {
@@ -892,8 +923,10 @@ sap.ui.define(['sap/ui/core/Control', 'sap/ui/core/theming/Parameters', 'sap/ui/
 				return oDragDropInfo.getMetadata().isInstanceOf("sap.ui.core.dnd.IDragInfo") && oDragDropInfo.getSourceAggregation() === "rows";
 			});
 
+			var iLastFixedColumnIndex = this.getLastFixedColumnIndex(oTable);
+
 			for (row = iStartRow, count = iEndRow; row < count; row++) {
-				this.renderTableRow(rm, oTable, aRows[row], row, bFixedTable, iStartColumn, iEndColumn, false, aVisibleColumns, bRenderDummyColumn, mTooltipTexts, bSelectOnCellsAllowed, bRowsDraggable);
+				this.renderTableRow(rm, oTable, aRows[row], row, bFixedTable, iStartColumn, iEndColumn, false, aVisibleColumns, iLastFixedColumnIndex, bRenderDummyColumn, mTooltipTexts, bSelectOnCellsAllowed, bRowsDraggable);
 			}
 		}
 		rm.close("tbody");
@@ -903,7 +936,7 @@ sap.ui.define(['sap/ui/core/Control', 'sap/ui/core/theming/Parameters', 'sap/ui/
 	TableRenderer.writeRowSelectorContent = function(rm, oTable, oRow, iRowIndex) {
 		oTable._getAccRenderExtension().writeAccRowSelectorText(rm, oTable, oRow, iRowIndex);
 
-		if (TableUtils.Grouping.isGroupMode(oTable)) {
+		if (TableUtils.Grouping.isInGroupMode(oTable)) {
 			rm.openStart("div");
 			rm.class("sapUiTableGroupShield");
 			rm.openEnd();
@@ -980,15 +1013,10 @@ sap.ui.define(['sap/ui/core/Control', 'sap/ui/core/theming/Parameters', 'sap/ui/
 		//
 		// Render header cells
 		//
-		var aColumns,
+		var aColumns = this.getColumnsToRender(oTable, iStartColumn, iEndColumn),
 			nSpan = 0,
 			iLastVisibleCol = -1;
 
-		// get columns to render
-		aColumns = oTable.getColumns().slice(iStartColumn, iEndColumn).filter(function(oColumn) {
-			return oColumn && oColumn.shouldRender();
-		});
-
 		// collect header spans and find the last visible column header
 		function collectHeaderSpans(oColumn, index, aCols) {
 			var colSpan = ColumnUtils.getHeaderSpan(oColumn, iRow),
@@ -1037,7 +1065,7 @@ sap.ui.define(['sap/ui/core/Control', 'sap/ui/core/theming/Parameters', 'sap/ui/
 		rm.close("tr");
 	};
 
-	TableRenderer.renderTableRow = function(rm, oTable, oRow, iRowIndex, bFixedTable, iStartColumn, iEndColumn, bFixedRow, aVisibleColumns, bHasOnlyFixedColumns, mTooltipTexts, bSelectOnCellsAllowed, bDraggable) {
+	TableRenderer.renderTableRow = function(rm, oTable, oRow, iRowIndex, bFixedTable, iStartColumn, iEndColumn, bFixedRow, aVisibleColumns, iLastFixedColumnIndex, bHasOnlyFixedColumns, mTooltipTexts, bSelectOnCellsAllowed, bDraggable) {
 		if (!oRow) {
 			return;
 		}
@@ -1067,7 +1095,7 @@ sap.ui.define(['sap/ui/core/Control', 'sap/ui/core/theming/Parameters', 'sap/ui/
 			}
 		}
 
-		if (iRowIndex % 2 != 0 && oTable.getAlternateRowColors() && !TableUtils.Grouping.isTreeMode(oTable)) {
+		if (iRowIndex % 2 != 0 && oTable.getAlternateRowColors() && !TableUtils.Grouping.isInTreeMode(oTable)) {
 			rm.class("sapUiTableRowAlternate");
 		}
 
@@ -1076,7 +1104,13 @@ sap.ui.define(['sap/ui/core/Control', 'sap/ui/core/theming/Parameters', 'sap/ui/
 		rm.attr("data-sap-ui-rowindex", iRowIndex);
 		oTable._getRowMode().renderRowStyles(rm);
 
-		oTable._getAccRenderExtension().writeAriaAttributesFor(rm, oTable, "TR", {index: iRowIndex, rowHidden: oRow.isEmpty()});
+		var oRowSettings = oRow.getAggregation("_settings");
+		var oParams = {
+			index: iRowIndex,
+			rowHidden: oRow.isEmpty(),
+			rowNavigated: oRowSettings ? oRowSettings.getNavigated() : false
+		};
+		oTable._getAccRenderExtension().writeAriaAttributesFor(rm, oTable, "TR", oParams);
 
 		rm.openEnd();
 
@@ -1084,7 +1118,7 @@ sap.ui.define(['sap/ui/core/Control', 'sap/ui/core/theming/Parameters', 'sap/ui/
 		var aCells = oRow.getCells();
 
 		for (var cell = 0, count = aCells.length; cell < count; cell++) {
-			this.renderTableCell(rm, oTable, oRow, aCells[cell], cell, bFixedTable, iStartColumn, iEndColumn, aVisibleColumns, bSelected);
+			this.renderTableCell(rm, oTable, oRow, aCells[cell], cell, bFixedTable, iStartColumn, iEndColumn, aVisibleColumns, iLastFixedColumnIndex, bSelected);
 		}
 		if (!bFixedTable && bHasOnlyFixedColumns && aCells.length > 0) {
 			rm.openStart("td").class("sapUiTableCellDummy");
@@ -1095,10 +1129,9 @@ sap.ui.define(['sap/ui/core/Control', 'sap/ui/core/theming/Parameters', 'sap/ui/
 		rm.close("tr");
 	};
 
-	TableRenderer.renderTableCell = function(rm, oTable, oRow, oCell, iCellIndex, bFixedTable, iStartColumn, iEndColumn, aVisibleColumns, bSelected) {
+	TableRenderer.renderTableCell = function(rm, oTable, oRow, oCell, iCellIndex, bFixedTable, iStartColumn, iEndColumn, aVisibleColumns, iLastFixedColumnIndex, bSelected) {
 		var oColumn = Column.ofCell(oCell);
 		var iColIndex = oColumn.getIndex();
-		var oLastFixedColumn = oTable.getColumns()[ColumnUtils.getFixedColumnCount(oTable, true) - 1];
 
 		if (oColumn.shouldRender() && iStartColumn <= iColIndex && iEndColumn > iColIndex) {
 			var sId = oRow.getId() + "-col" + iCellIndex;
@@ -1109,15 +1142,16 @@ sap.ui.define(['sap/ui/core/Control', 'sap/ui/core/theming/Parameters', 'sap/ui/
 			var nColumns = aVisibleColumns.length;
 			var bIsFirstColumn = nColumns > 0 && aVisibleColumns[0] === oColumn;
 			var bIsLastColumn = nColumns > 0 && aVisibleColumns[nColumns - 1] === oColumn;
-			var bIsLastFixedColumn = bFixedTable & oLastFixedColumn === oColumn;
+			var bIsLastFixedColumn = bFixedTable && iLastFixedColumnIndex === iColIndex;
 
-			oTable._getAccRenderExtension().writeAriaAttributesFor(rm, oTable, "DATACELL", {
+			var oParams = {
 				index: iColIndex,
 				column: oColumn,
 				row: oRow,
 				fixed: bFixedTable,
 				rowSelected: bSelected
-			});
+			};
+			oTable._getAccRenderExtension().writeAriaAttributesFor(rm, oTable, "DATACELL", oParams);
 
 			var sTextAlign = Renderer.getTextAlign(oColumn.getHAlign());
 			if (sTextAlign) {
@@ -1136,7 +1170,7 @@ sap.ui.define(['sap/ui/core/Control', 'sap/ui/core/theming/Parameters', 'sap/ui/
 			if (bIsLastColumn) {
 				rm.class("sapUiTableCellLast");
 			}
-			if (bIsFirstColumn && TableUtils.Grouping.isTreeMode(oTable)) {
+			if (bIsFirstColumn && TableUtils.Grouping.isInTreeMode(oTable)) {
 				rm.class("sapUiTableCellFlex"); // without flex, icon pushes contents too wide
 			}
 
@@ -1156,7 +1190,7 @@ sap.ui.define(['sap/ui/core/Control', 'sap/ui/core/theming/Parameters', 'sap/ui/
 	};
 
 	TableRenderer.renderTableCellControl = function(rm, oTable, oCell, bIsFirstColumn) {
-		if (bIsFirstColumn && TableUtils.Grouping.isTreeMode(oTable) && !oTable._bFlatMode) {
+		if (bIsFirstColumn && TableUtils.Grouping.isInTreeMode(oTable)) {
 			var oRow = oCell.getParent();
 			rm.openStart("span", oRow.getId() + "-treeicon");
 			rm.class("sapUiTableTreeIcon");
@@ -1169,38 +1203,39 @@ sap.ui.define(['sap/ui/core/Control', 'sap/ui/core/theming/Parameters', 'sap/ui/
 	};
 
 	TableRenderer.renderVSb = function(rm, oTable, mConfig) {
-		mConfig = Object.assign({
-			cssClass: "sapUiTableVSb",
-			tabIndex: true,
-			hidden: true
-		}, mConfig);
-		mConfig.id = oTable.getId() + "-vsb";
-
 		var oScrollExtension = oTable._getScrollExtension();
+		var mRowCounts = oTable._getRowCounts();
 
-		rm.openStart("div", mConfig.id);
-		rm.class(mConfig.cssClass);
-		if (mConfig.hidden) {
+		mConfig = Object.assign({
+			tabIndex: true
+		}, mConfig);
+
+		rm.openStart("div");
+		rm.class("sapUiTableVSbContainer");
+		if (!oScrollExtension.isVerticalScrollbarRequired()) {
 			rm.class("sapUiTableHidden");
 		}
-		if (mConfig.tabIndex) {
-			rm.attr("tabindex", "-1"); // Avoid focusing of the scrollbar in Firefox with tab.
-		}
-		rm.style("max-height", oScrollExtension.getVerticalScrollbarHeight() + "px");
-
-		var mRowCounts = oTable._getRowCounts();
-		if (mRowCounts.fixedTop > 0) {
-			oTable._iVsbTop = mRowCounts.fixedTop * oTable._getBaseRowHeight() - 1;
-			rm.style("top", oTable._iVsbTop  + 'px');
-		}
-
+		rm.class(mConfig.cssClass);
 		rm.openEnd();
 
-		rm.openStart("div", mConfig.id + "-content");
+		rm.openStart("div", oTable.getId() + "-vsb");
+		rm.class("sapUiTableVSb");
+		rm.style("max-height", oScrollExtension.getVerticalScrollbarHeight() + "px");
+		if (mRowCounts.fixedTop > 0) {
+			rm.style("top", mRowCounts.fixedTop * oTable._getBaseRowHeight() - 1  + "px");
+		}
+		if (mConfig.tabIndex) {
+			// https://bugzilla.mozilla.org/show_bug.cgi?id=1069739
+			// Avoid focusing of the scrollbar in Firefox with tab.
+			rm.attr("tabindex", "-1");
+		}
+		rm.openEnd();
+		rm.openStart("div");
 		rm.class("sapUiTableVSbContent");
 		rm.style("height", oScrollExtension.getVerticalScrollHeight() + "px");
 		rm.openEnd();
 		rm.close("div");
+		rm.close("div");
 
 		rm.close("div");
 	};
@@ -1216,12 +1251,6 @@ sap.ui.define(['sap/ui/core/Control', 'sap/ui/core/theming/Parameters', 'sap/ui/
 		}
 	};
 
-	TableRenderer.renderVSbBackground = function(rm, oTable) {
-		rm.openStart("div", oTable.getId() + "-vsb-bg");
-		rm.class("sapUiTableVSbBg");
-		rm.openEnd().close("div");
-	};
-
 	TableRenderer.renderHSb = function(rm, oTable, mConfig) {
 		mConfig = Object.assign({
 			id: oTable.getId() + "-hsb",
@@ -1282,15 +1311,47 @@ sap.ui.define(['sap/ui/core/Control', 'sap/ui/core/theming/Parameters', 'sap/ui/
 	 * Renders an empty area with tabindex=0 and the given class and id.
 	 * @private
 	 */
-	TableRenderer.renderTabElement = function(rm, sClass) {
+	TableRenderer.renderTabElement = function(rm, sClass, sTabIndex, sId) {
 		rm.openStart("div");
 		if (sClass) {
 			rm.class(sClass);
 		}
-		rm.attr("tabindex", "0");
+		if (sId) {
+			rm.attr("id", sId);
+		}
+		rm.attr("tabindex", sTabIndex == null ? "0" : sTabIndex);
 		rm.openEnd().close("div");
 	};
 
+	/**
+	* Returns the columns with indices in the range between iStartIndex and iEndIndex that should be rendered.
+	 * @private
+	 */
+	TableRenderer.getColumnsToRender = function(oTable, iStartIndex, iEndIndex) {
+		return oTable.getColumns().slice(iStartIndex, iEndIndex).filter(function(oColumn) {
+			return oColumn && oColumn.shouldRender();
+		});
+	};
+
+	/**
+	 * Returns the index of the last fixed column
+	 * @private
+	 */
+	TableRenderer.getLastFixedColumnIndex = function(oTable) {
+		var iFixedColumnCount = oTable.getComputedFixedColumnCount();
+		var aCols = oTable.getColumns();
+		var oColumn, iLastFixedColumnIndex;
+
+		for (var i = iFixedColumnCount - 1; i >= 0; i--) {
+			oColumn = aCols[i];
+			if (oColumn.shouldRender()) {
+				iLastFixedColumnIndex = i;
+				break;
+			}
+		}
+		return iLastFixedColumnIndex;
+	};
+
 	return TableRenderer;
 
 }, /* bExport= */ true);
