@@ -1,6 +1,6 @@
 /*
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 sap.ui.define([
@@ -52,6 +52,7 @@ sap.ui.define([
 	 * @alias sap.ui.table.plugins.MultiSelectionPlugin
 	 */
 	var MultiSelectionPlugin = SelectionPlugin.extend("sap.ui.table.plugins.MultiSelectionPlugin", {metadata : {
+		library: "sap.ui.table",
 		properties : {
 			/**
 			 * Number of indices which can be selected in a range.
@@ -113,7 +114,7 @@ sap.ui.define([
 	MultiSelectionPlugin.prototype.init = function() {
 		SelectionPlugin.prototype.init.apply(this, arguments);
 
-		var oIcon = new Icon({src: IconPool.getIconURI(TableUtils.ThemeParameters.resetIcon), useIconTooltip: false});
+		var oIcon = new Icon({src: IconPool.getIconURI(TableUtils.ThemeParameters.clearSelectionIcon), useIconTooltip: false});
 		oIcon.addStyleClass("sapUiTableSelectClear");
 
 		this._bLimitReached = false;
@@ -475,7 +476,7 @@ sap.ui.define([
 
 		return new Promise(function(resolve) {
 			if (bExpectRowsUpdatedEvent) {
-				oTable.attachEventOnce("_rowsUpdated", resolve);
+				oTable.attachEventOnce("rowsUpdated", resolve);
 			} else {
 				resolve();
 			}
@@ -567,7 +568,7 @@ sap.ui.define([
 	}
 
 	function loadContexts(oBinding, iStartIndex, iLength, fResolve) {
-		var aContexts = oBinding.getContexts(iStartIndex, iLength);
+		var aContexts = oBinding.getContexts(iStartIndex, iLength, 0, true);
 		var bLoadItems = false;
 
 		for (var i = 0; i < aContexts.length; i++) {
@@ -725,7 +726,7 @@ sap.ui.define([
 	};
 
 	MultiSelectionPlugin.prototype.onThemeChanged = function() {
-		this.oDeselectAllIcon.setSrc(IconPool.getIconURI(TableUtils.ThemeParameters.resetIcon));
+		this.oDeselectAllIcon.setSrc(IconPool.getIconURI(TableUtils.ThemeParameters.clearSelectionIcon));
 	};
 
 	return MultiSelectionPlugin;
