@@ -1,13 +1,12 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
 sap.ui.define([
-    "sap/ui/test/selectors/_Selector",
-    "sap/ui/test/_OpaLogger"
-], function (_Selector, _OpaLogger) {
+    "sap/ui/test/selectors/_Selector"
+], function (_Selector) {
 	"use strict";
 
     var _ControlType = _Selector.extend("sap.ui.test.selectors._ControlType", {
