@@ -1,6 +1,6 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
@@ -32,6 +32,12 @@ sap.ui.define([
 			preferViewId: false,
 			formatAsPOMethod: true,
 			multipleSnippets: false
+		},
+		elementTree: {
+			search: "",
+			filter: false,
+			attributes: false,
+			namespaces: true
 		}
 	});
 
