@@ -1,6 +1,6 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
@@ -162,7 +162,7 @@ sap.ui.define([
 			// search Locale for containing "en-US", since sometimes
 			// when any user settings have been defined, subtag "sapufmt" is added to the locale name
 			// this is described inside sap.ui.core.Configuration file
-			if (oLocale && (oLocale.getLanguage() == 'en' && oLocale.getRegion() == 'US')) {
+			if (oLocale && oLocale.getLanguage() === "en" && (oLocale.getRegion() === "US" || !oLocale.getRegion())) {
 				/*
 				 * in US the week starts with Sunday
 				 * The first week of the year starts with January 1st. But Dec. 31 is still in the last year
@@ -332,25 +332,25 @@ sap.ui.define([
 		 * @private
 		 */
 		CalendarUtils._updateUTCDate = function(oDate, iYear, iMonth, iDate, iHours, iMinutes, iSeconds, iMilliseconds) {
-			if (jQuery.isNumeric(iYear)) {
+			if (iYear != null) {
 				oDate.setUTCFullYear(iYear);
 			}
-			if (jQuery.isNumeric(iMonth)) {
+			if (iMonth != null) {
 				oDate.setUTCMonth(iMonth);
 			}
-			if (jQuery.isNumeric(iDate)) {
+			if (iDate != null) {
 				oDate.setUTCDate(iDate);
 			}
-			if (jQuery.isNumeric(iHours)) {
+			if (iHours != null) {
 				oDate.setUTCHours(iHours);
 			}
-			if (jQuery.isNumeric(iMinutes)) {
+			if (iMinutes != null) {
 				oDate.setUTCMinutes(iMinutes);
 			}
-			if (jQuery.isNumeric(iSeconds)) {
+			if (iSeconds != null) {
 				oDate.setUTCSeconds(iSeconds);
 			}
-			if (jQuery.isNumeric(iMilliseconds)) {
+			if (iMilliseconds != null) {
 				oDate.setUTCMilliseconds(iMilliseconds);
 			}
 		};
@@ -374,7 +374,7 @@ sap.ui.define([
 		 * @private
 		 */
 		CalendarUtils._checkYearInValidRange = function(iYear) {
-			if (!jQuery.isNumeric(iYear) || (iYear < 1 || iYear > 9999)) {
+			if (typeof iYear !== "number" || iYear < 1 || iYear > 9999) {
 				throw new Error("Year must be in valid range (between year 0001 and year 9999).");
 			}
 		};
@@ -478,6 +478,16 @@ sap.ui.define([
 			return Math.abs((oNewFirstDate.getTime() - oNewSecondDate.getTime()) / (1000 * 60 * 60));
 		};
 
+		/**
+		 * Evaluates whether a given date time part indicates midniht.
+		 *
+		 * @param {Object} oDate - JavaScript date
+		 * @returns {boolean}
+		 */
+		CalendarUtils._isMidnight = function(oDate) {
+			return oDate.getHours() === 0 && oDate.getMinutes() === 0 && oDate.getSeconds() === 0 && oDate.getMilliseconds() === 0;
+		};
+
 		 // Utilities for working with sap.ui.unified.calendar.CalendarDate
 
 		/**
