@@ -1,12 +1,12 @@
 /*!
  * OpenUI5
- * (c) Copyright 2009-2020 SAP SE or an SAP affiliate company.
+ * (c) Copyright 2009-2022 SAP SE or an SAP affiliate company.
  * Licensed under the Apache License, Version 2.0 - see LICENSE.txt.
  */
 
 sap.ui.define(['sap/ui/unified/calendar/CalendarUtils', 'sap/ui/unified/calendar/CalendarDate', 'sap/ui/unified/CalendarLegend', 'sap/ui/unified/CalendarLegendRenderer',
-	'sap/ui/core/library', 'sap/ui/unified/library', "sap/base/Log", 'sap/ui/core/InvisibleText'],
-	function(CalendarUtils, CalendarDate, CalendarLegend, CalendarLegendRenderer, coreLibrary, library, Log, InvisibleText) {
+	'sap/ui/core/library', 'sap/ui/unified/library', "sap/base/Log", 'sap/ui/core/InvisibleText', "sap/ui/core/format/DateFormat", "sap/ui/core/Locale"],
+	function(CalendarUtils, CalendarDate, CalendarLegend, CalendarLegendRenderer, coreLibrary, library, Log, InvisibleText, DateFormat, Locale) {
 	"use strict";
 
 
@@ -199,7 +199,7 @@ sap.ui.define(['sap/ui/unified/calendar/CalendarUtils', 'sap/ui/unified/calendar
 		}
 		var aWeekDaysWide = oLocaleData.getDaysStandAlone("wide", sCalendarType);
 
-		if (oMonth.getShowWeekNumbers()) {
+		if (oMonth.getShowWeekNumbers() && sCalendarType !== CalendarType.Islamic) { // on Islamic primary calendar week numbers are not shown, do not add dummy cell
 			this.renderDummyCell(oRm, "sapUiCalWH", true, "columnheader");
 		}
 
@@ -270,13 +270,13 @@ sap.ui.define(['sap/ui/unified/calendar/CalendarUtils', 'sap/ui/unified/calendar
 				oRm.openEnd();
 
 				if (bWeekNum) {
-					this._renderWeekNumber(oRm, aDays[i], oHelper);
+					this._renderWeekNumber(oRm, aDays[i], oHelper, oMonth);
 				}
 			}
 
 			this.renderDay(oRm, oMonth, aDays[i], oHelper, true, bWeekNum, -1);
 
-			if (i % 7 === 6) {
+			if (i % 7 === 6 || i === iLength - 1) {
 				oRm.close("div");
 			}
 		}
@@ -301,7 +301,7 @@ sap.ui.define(['sap/ui/unified/calendar/CalendarUtils', 'sap/ui/unified/calendar
 		oRm.class("sapUiCalDummy");
 		oRm.style("visibility", bVisible ? "visible" : "hidden");
 		oRm.attr("role", sRole);
-		oRm.attr("tabindex", "-1");
+		oRm.attr("aria-label", sap.ui.getCore().getLibraryResourceBundle("sap.ui.unified").getText("CALENDAR_WEEK"));
 		oRm.openEnd();
 		oRm.close('div');
 	};
@@ -330,6 +330,7 @@ sap.ui.define(['sap/ui/unified/calendar/CalendarUtils', 'sap/ui/unified/calendar
 				oToday: CalendarDate.fromLocalJSDate(new Date(), oMonth.getPrimaryCalendarType()),
 				sId: oMonth.getId(),
 				oFormatLong: oMonth._getFormatLong(),
+				sPrimaryCalendarType: oMonth.getPrimaryCalendarType(),
 				sSecondaryCalendarType: oMonth._getSecondaryCalendarType(),
 				oLegend: undefined
 			};
@@ -383,7 +384,7 @@ sap.ui.define(['sap/ui/unified/calendar/CalendarUtils', 'sap/ui/unified/calendar
 		var aDayTypes = oMonth._getDateTypes(oDay);
 		var bEnabled = oMonth._checkDateEnabled(oDay);
 		var i = 0;
-
+		var bShouldBeMarkedAsSpecialDate = oMonth._isSpecialDateMarkerEnabled(oDay);
 		// Days before 0001.01.01 should be disabled.
 		if (bBeforeFirstYear) {
 			bEnabled = false;
@@ -428,20 +429,23 @@ sap.ui.define(['sap/ui/unified/calendar/CalendarUtils', 'sap/ui/unified/calendar
 			mAccProps["describedby"] = mAccProps["describedby"] + " " + oHelper.sId + "-End";
 		}
 
-		aDayTypes.forEach(function(oDayType) {
-			if (oDayType.type !== CalendarDayType.None) {
-				if (oDayType.type === CalendarDayType.NonWorking) {
-					oRm.class("sapUiCalItemWeekEnd");
-					sNonWorkingDayText = this._addNonWorkingDayText(mAccProps);
-					return;
+		if (bShouldBeMarkedAsSpecialDate) {
+			aDayTypes.forEach(function(oDayType) {
+				if (oDayType.type !== CalendarDayType.None) {
+					if (oDayType.type === CalendarDayType.NonWorking) {
+						oRm.class("sapUiCalItemWeekEnd");
+						sNonWorkingDayText = this._addNonWorkingDayText(mAccProps);
+						return;
+					}
+					oRm.class("sapUiCalItem" + oDayType.type);
+					sAriaType = oDayType.type;
+					if (oDayType.tooltip) {
+						oRm.attr('title', oDayType.tooltip);
+					}
 				}
-				oRm.class("sapUiCalItem" + oDayType.type);
-				sAriaType = oDayType.type;
-				if (oDayType.tooltip) {
-					oRm.attr('title', oDayType.tooltip);
-				}
-			}
-		}.bind(this));
+			}.bind(this));
+		}
+
 
 		if (!sNonWorkingDayText) { // if sNonWorkingDayText exists, it is already included above as specialDate of type NonWorking
 			if (oHelper.aNonWorkingDays) { // check if there are nonWorkingDays passed and add text to them
@@ -498,7 +502,7 @@ sap.ui.define(['sap/ui/unified/calendar/CalendarUtils', 'sap/ui/unified/calendar
 		oRm.accessibilityState(null, mAccProps);
 		oRm.openEnd(); // div element
 
-		if (aDayTypes[0]){ //if there's a special date, render it
+		if (aDayTypes[0] && bShouldBeMarkedAsSpecialDate){ //if there's a special date inside current month, render it
 			oRm.openStart("div");
 			oRm.class("sapUiCalSpecialDate");
 			if (aDayTypes[0].color) { // if there's a custom color, render it
@@ -511,7 +515,7 @@ sap.ui.define(['sap/ui/unified/calendar/CalendarUtils', 'sap/ui/unified/calendar
 
 		oRm.openStart("span");
 		oRm.class("sapUiCalItemText");
-		if (!!aDayTypes[0] && aDayTypes[0].color) {
+		if (aDayTypes[0] && aDayTypes[0].color) {
 			oRm.class("sapUiCalItemTextCustomColor");
 		}
 		oRm.openEnd(); // span
@@ -554,9 +558,9 @@ sap.ui.define(['sap/ui/unified/calendar/CalendarUtils', 'sap/ui/unified/calendar
 		return sText;
 	};
 
-	MonthRenderer._renderWeekNumber = function(oRm, oDay, oHelper) {
-		var iWeekNumber = CalendarUtils.calculateWeekNumber(oDay.toUTCJSDate(), oHelper.iYear, oHelper.sLocale, oHelper.oLocaleData),
-			sId = oHelper.sId + "-WNum-" + iWeekNumber;
+	MonthRenderer._renderWeekNumber = function(oRm, oDay, oHelper, oMonth) {
+		var iWeekNumber = oMonth._calculateWeekNumber(oDay);
+		var sId = oHelper.sId + "-WNum-" + iWeekNumber;
 
 		// add week number - inside first day of the week to allow better position and make it easier for ItemNavigation
 		oRm.openStart("div", sId);
